#
# spec file for package qemu
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# !! IMPORTANT !! See README.PACKAGING before modifying package in any way

%define _buildshell /bin/bash

%define build_in_tree 0
%define build_x86_firmware_from_source 0
%define build_skiboot_from_source 0
%define build_slof_from_source 0
%define build_opensbi_from_source 0
%define kvm_available 0
%define legacy_qemu_kvm 0
%define force_fit_virtio_pxe_rom 1
%define provide_edk2_firmware 0

%define build_rom_arch %ix86 x86_64 aarch64

%if "%{?distribution}" == ""
%define distro private-build
%else
%define distro %{distribution}
%endif

%ifarch %{build_rom_arch}
# choice of building all from source or using provided binary x86 blobs
%define build_x86_firmware_from_source 1
%endif

%ifarch ppc64
%define build_skiboot_from_source 1
%define build_slof_from_source 1
%endif

%ifarch ppc64le
%define build_skiboot_from_source 1
%define build_slof_from_source 1
%endif

%ifarch riscv64
%define build_opensbi_from_source 1
%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390x armv7hl aarch64
%define kvm_available 1
%endif

%ifarch %ix86 x86_64 s390x
%define legacy_qemu_kvm 1
%endif

%if 0%{?is_opensuse}
%define with_glusterfs 1
%endif

%ifarch x86_64 aarch64 ppc64le s390x
%define with_rbd 1
%endif

# qemu, qemu-linux-user, and qemu-testsuite "flavors" are enabled via OBS Multibuild
%global flavor %{nil}
%define name_suffix %{nil}
%if "%flavor" == "testsuite"
%define name_suffix -testsuite
%endif
%if "%flavor" == "linux-user"
%define name_suffix -linux-user
%define summary_string CPU emulator for user space
%else
%define summary_string Machine emulator and virtualizer
%endif

%bcond_with system_membarrier

%define qemuver 4.2.1
%define srcver  4.2.1
%define sbver   1.12.1+
%define srcname qemu
Name:           qemu%{name_suffix}
URL:            https://www.qemu.org/
Summary:        %{summary_string}
License:        BSD-2-Clause AND BSD-3-Clause AND GPL-2.0-only AND GPL-2.0-or-later AND LGPL-2.1-or-later AND MIT
Group:          System/Emulators/PC
Version:        %qemuver
Release:        lp152.9.20.2
Source:         https://wiki.qemu.org/download/%{srcname}-%{srcver}.tar.xz
Source99:       https://wiki.qemu.org/download/%{srcname}-%{srcver}.tar.xz.sig
Source100:      %{srcname}.keyring
Source1:        80-kvm.rules
Source2:        kvm.conf
Source3:        qemu-ifup
Source4:        bridge.conf
Source5:        qemu-kvm.1.gz
Source6:        ksm.service
Source7:        qemu-ga@.service
Source8:        80-qemu-ga.rules
Source9:        qemu-supportconfig
Source10:       supported.arm.txt
Source11:       supported.ppc.txt
Source12:       supported.x86.txt
Source13:       supported.s390.txt
Source14:       50-seabios-256k.json
Source15:       60-seabios-128k.json
Source200:      qemu-rpmlintrc
Source201:      pkg-split.txt
Source300:      bundles.tar.xz
Source301:      update_git.sh
Source302:      config.sh
Source303:      README.PACKAGING
# Upstream First -- https://wiki.qemu.org/Contribute/SubmitAPatch
# This patch queue is auto-generated - see README.PACKAGING for process

# Patches applied in base project:
Patch00000:     i386-Add-MSR-feature-bit-for-MDS-NO.patch
Patch00001:     i386-Add-macro-for-stibp.patch
Patch00002:     i386-Add-new-CPU-model-Cooperlake.patch
Patch00003:     linux-headers-Update-against-Linux-5.5-1.patch
Patch00004:     iotests-Skip-test-060-if-it-is-not-possi.patch
Patch00005:     iotests-Skip-test-079-if-it-is-not-possi.patch
Patch00006:     iotests-Provide-a-function-for-checking-.patch
Patch00007:     virtio-don-t-enable-notifications-during.patch
Patch00008:     numa-Extend-CLI-to-provide-initiator-inf.patch
Patch00009:     numa-Extend-CLI-to-provide-memory-latenc.patch
Patch00010:     numa-Extend-CLI-to-provide-memory-side-c.patch
Patch00011:     hmat-acpi-Build-Memory-Proximity-Domain-.patch
Patch00012:     hmat-acpi-Build-System-Locality-Latency-.patch
Patch00013:     hmat-acpi-Build-Memory-Side-Cache-Inform.patch
Patch00014:     tests-numa-Add-case-for-QMP-build-HMAT.patch
Patch00015:     linux-headers-Update-against-Linux-5.5-r.patch
Patch00016:     target-i386-Add-new-bit-definitions-of-M.patch
Patch00017:     target-i386-Add-missed-features-to-Coope.patch
Patch00018:     i386-acpi-Remove-_HID-from-the-SMBus-ACP.patch
Patch00019:     vnc-prioritize-ZRLE-compression-over-ZLI.patch
Patch00020:     target-i386-add-a-ucode-rev-property.patch
Patch00021:     target-i386-kvm-initialize-microcode-rev.patch
Patch00022:     target-i386-fix-TCG-UCODE_REV-access.patch
Patch00023:     target-i386-check-for-availability-of-MS.patch
Patch00024:     target-i386-enable-monitor-and-ucode-rev.patch
Patch00025:     linux-headers-update-against-Linux-5.6-r.patch
Patch00026:     aio-wait-delegate-polling-of-main-AioCon.patch
Patch00027:     async-use-explicit-memory-barriers.patch
Patch00028:     block-iscsi-fix-heap-buffer-overflow-in-.patch
Patch00029:     virtio-net-fix-rsc_ext-compat-handling.patch
Patch00030:     linux-headers-update-against-Linux-5.7-r.patch
Patch00031:     audio-fix-wavcapture-segfault.patch
Patch00032:     sm501-Convert-printf-abort-to-qemu_log_m.patch
Patch00033:     sm501-Shorten-long-variable-names-in-sm5.patch
Patch00034:     sm501-Use-BIT-x-macro-to-shorten-constan.patch
Patch00035:     sm501-Clean-up-local-variables-in-sm501_.patch
Patch00036:     sm501-Replace-hand-written-implementatio.patch
Patch00037:     megasas-use-unsigned-type-for-reply_queu.patch
Patch00038:     exec-set-map-length-to-zero-when-returni.patch
Patch00039:     Linux-headers-update-against-Linux-5.8-r.patch
Patch00040:     hw-net-xgmac-Fix-buffer-overflow-in-xgma.patch
Patch00041:     s390x-protvirt-allow-to-IPL-secure-guest.patch
Patch00042:     hw-net-net_tx_pkt-fix-assertion-failure-.patch
Patch00043:     hw-xhci-check-return-value-of-usb_packet.patch
Patch00044:     hw-ehci-check-return-value-of-usb_packet.patch
Patch00045:     usb-fix-setup_len-init-CVE-2020-14364.patch
Patch00046:     hw-usb-hcd-ohci-check-len-and-frame_numb.patch
Patch00047:     hw-usb-hcd-ohci-check-for-processed-TD-b.patch
Patch00048:     linux-headers-sync-to-5.9-rc4.patch
Patch00049:     pc-bios-s390-ccw-fix-off-by-one-error.patch
Patch00050:     pc-bios-s390-ccw-break-loop-if-a-null-bl.patch
Patch00051:     linux-headers-sync-to-5.9-rc7.patch
Patch00052:     s390x-s390-virtio-ccw-Reset-PCI-devices-.patch
Patch00053:     linux-headers-update-against-5.10-rc1.patch
Patch00054:     vfio-Create-shared-routine-for-scanning-.patch
Patch00055:     vfio-Find-DMA-available-capability.patch
Patch00056:     s390x-pci-Add-routine-to-get-the-vfio-dm.patch
Patch00057:     s390x-pci-Honor-DMA-limits-set-by-vfio.patch
Patch00058:     ati-check-x-y-display-parameter-values.patch
Patch00059:     s390x-fix-build-for-without-default-devi.patch
Patch00060:     net-remove-an-assert-call-in-eth_get_gso.patch
Patch00061:     hw-net-e1000e-advance-desc_offset-in-cas.patch
Patch00062:     ide-atapi-assert-that-the-buffer-pointer.patch
Patch00063:     memory-clamp-cached-translation-in-case-.patch
Patch00064:     virtio-scsi-trace-events.patch
Patch00065:     9pfs-Fully-restart-unreclaim-loop-CVE-20.patch
Patch00066:     hw-intc-arm_gic-Fix-interrupt-ID-in-GICD.patch
Patch00067:     hw-pci-host-add-pci-intack-write-method.patch
Patch00068:     pci-host-designware-add-pcie-msi-read-me.patch
Patch00069:     vfio-add-quirk-device-write-method.patch
Patch00070:     prep-add-ppc-parity-write-method.patch
Patch00071:     nvram-add-nrf51_soc-flash-read-method.patch
Patch00072:     spapr_pci-add-spapr-msi-read-method.patch
Patch00073:     tz-ppc-add-dummy-read-write-methods.patch
Patch00074:     imx7-ccm-add-digprog-mmio-write-method.patch
Patch00075:     e1000-fail-early-for-evil-descriptor.patch
Patch00076:     net-introduce-qemu_receive_packet.patch
Patch00077:     e1000-switch-to-use-qemu_receive_packet-.patch
Patch00078:     dp8393x-switch-to-use-qemu_receive_packe.patch
Patch00079:     sungem-switch-to-use-qemu_receive_packet.patch
Patch00080:     tx_pkt-switch-to-use-qemu_receive_packet.patch
Patch00081:     rtl8139-switch-to-use-qemu_receive_packe.patch
Patch00082:     pcnet-switch-to-use-qemu_receive_packet-.patch
Patch00083:     cadence_gem-switch-to-use-qemu_receive_p.patch
Patch00084:     lan9118-switch-to-use-qemu_receive_packe.patch
Patch00085:     hw-isa-piix4-Migrate-Reset-Control-Regis.patch
Patch00086:     net-vmxnet3-validate-configuration-value.patch
Patch00087:     XXX-dont-dump-core-on-sigabort.patch
Patch00088:     qemu-binfmt-conf-Modify-default-path.patch
Patch00089:     qemu-cvs-gettimeofday.patch
Patch00090:     qemu-cvs-ioctl_debug.patch
Patch00091:     qemu-cvs-ioctl_nodirection.patch
Patch00092:     linux-user-add-binfmt-wrapper-for-argv-0.patch
Patch00093:     PPC-KVM-Disable-mmu-notifier-check.patch
Patch00094:     linux-user-binfmt-support-host-binaries.patch
Patch00095:     linux-user-Fake-proc-cpuinfo.patch
Patch00096:     linux-user-use-target_ulong.patch
Patch00097:     Make-char-muxer-more-robust-wrt-small-FI.patch
Patch00098:     linux-user-lseek-explicitly-cast-non-set.patch
Patch00099:     AIO-Reduce-number-of-threads-for-32bit-h.patch
Patch00100:     xen_disk-Add-suse-specific-flush-disable.patch
Patch00101:     qemu-bridge-helper-reduce-security-profi.patch
Patch00102:     qemu-binfmt-conf-use-qemu-ARCH-binfmt.patch
Patch00103:     linux-user-properly-test-for-infinite-ti.patch
Patch00104:     roms-Makefile-pass-a-packaging-timestamp.patch
Patch00105:     Raise-soft-address-space-limit-to-hard-l.patch
Patch00106:     increase-x86_64-physical-bits-to-42.patch
Patch00107:     vga-Raise-VRAM-to-16-MiB-for-pc-0.15-and.patch
Patch00108:     i8254-Fix-migration-from-SLE11-SP2.patch
Patch00109:     acpi_piix4-Fix-migration-from-SLE11-SP2.patch
Patch00110:     Switch-order-of-libraries-for-mpath-supp.patch
Patch00111:     Make-installed-scripts-explicitly-python.patch
Patch00112:     hw-smbios-handle-both-file-formats-regar.patch
Patch00113:     xen-add-block-resize-support-for-xen-dis.patch
Patch00114:     tests-qemu-iotests-Triple-timeout-of-i-o.patch
Patch00115:     tests-Fix-block-tests-to-be-compatible-w.patch
Patch00116:     xen-ignore-live-parameter-from-xen-save-.patch
Patch00117:     Conditionalize-ui-bitmap-installation-be.patch
Patch00118:     tests-change-error-message-in-test-162.patch
Patch00119:     hw-usb-hcd-xhci-Fix-GCC-9-build-warning.patch
Patch00120:     hw-usb-dev-mtp-Fix-GCC-9-build-warning.patch
Patch00121:     hw-intc-exynos4210_gic-provide-more-room.patch
Patch00122:     configure-only-populate-roms-if-softmmu.patch
Patch00123:     pc-bios-s390-ccw-net-avoid-warning-about.patch
Patch00124:     roms-change-cross-compiler-naming-to-be-.patch
Patch00125:     tests-Disable-some-block-tests-for-now.patch
Patch00126:     test-add-mapping-from-arch-of-i686-to-qe.patch
Patch00127:     roms-Makefile-enable-cross-compile-for-b.patch
Patch00128:     hw-i386-disable-smbus-migration-for-xenf.patch
Patch00129:     s390x-Don-t-do-a-normal-reset-on-the-ini.patch
Patch00130:     s390x-Move-reset-normal-to-shared-reset-.patch
Patch00131:     s390x-Move-initial-reset.patch
Patch00132:     s390x-Move-clear-reset.patch
Patch00133:     s390x-kvm-Make-kvm_sclp_service_call-voi.patch
Patch00134:     s390x-ipl-Consolidate-iplb-validity-chec.patch
Patch00135:     s390x-Beautify-diag308-handling.patch
Patch00136:     s390x-Add-missing-vcpu-reset-functions.patch
Patch00137:     s390x-Move-diagnose-308-subcodes-and-rcs.patch
Patch00138:     vhost-correctly-turn-on-VIRTIO_F_IOMMU_P.patch
Patch00139:     Sync-pv.patch
Patch00140:     s390x-protvirt-Support-unpack-facility.patch
Patch00141:     s390x-protvirt-Add-migration-blocker.patch
Patch00142:     s390x-protvirt-Inhibit-balloon-when-swit.patch
Patch00143:     s390x-protvirt-KVM-intercept-changes.patch
Patch00144:     s390x-Add-SIDA-memory-ops.patch
Patch00145:     s390x-protvirt-Move-STSI-data-over-SIDAD.patch
Patch00146:     s390x-protvirt-SCLP-interpretation.patch
Patch00147:     s390x-protvirt-Set-guest-IPL-PSW.patch
Patch00148:     s390x-protvirt-Move-diag-308-data-over-S.patch
Patch00149:     s390x-protvirt-Disable-address-checks-fo.patch
Patch00150:     s390x-protvirt-Move-IO-control-structure.patch
Patch00151:     s390x-protvirt-Handle-SIGP-store-status-.patch
Patch00152:     s390x-Add-unpack-facility-feature-to-GA1.patch
Patch00153:     s390x-s390-virtio-ccw-Fix-build-on-syste.patch
Patch00154:     configure-remove-pkgversion-from-CONFIG_.patch
Patch00155:     gcc10-maybe-uninitialized.patch
Patch00156:     Revert-meson-build-file-back-to-Make.obj.patch
Patch00157:     scsi-make-io_timeout-settable.patch
Patch00158:     scsi-add-tracing-for-SG_IO-commands.patch
Patch00159:     scsi-disk-set-default-I-O-timeout-to-30-.patch
Patch00160:     virtio-scsi-translate-SG_IO-host-status.patch
Patch00161:     scsi-generic-check-for-additional-SG_IO-.patch
Patch00162:     scsi-disk-fold-SG_IO-errors-back-into-re.patch
Patch00163:     scsi-disk-trace-rw-errors.patch
Patch00164:     virtio-scsi-change-DID-TIMEOUT-handling.patch
Patch00165:     pc-bios-s390-ccw-don-t-try-to-read-the-n.patch
Patch00166:     hw-sd-sdhci-Fix-DMA-Transfer-Block-Size-.patch
Patch00167:     qom-make-object_ref-unref-use-a-void-ins.patch
Patch00168:     rcu-Implement-drain_call_rcu.patch
Patch00169:     qdev-add-check-if-address-free-callback-.patch
Patch00170:     scsi-scsi_bus-switch-search-direction-in.patch
Patch00171:     device_core-use-drain_call_rcu-in-in-qmp.patch
Patch00172:     device-core-use-RCU-for-list-of-children.patch
Patch00173:     scsi-switch-to-bus-check_address.patch
Patch00174:     device-core-use-atomic_set-on-.realized-.patch
Patch00175:     scsi-scsi-bus-scsi_device_find-don-t-ret.patch
Patch00176:     scsi-scsi_bus-Add-scsi_device_get.patch
Patch00177:     virtio-scsi-use-scsi_device_get.patch
Patch00178:     scsi-scsi_bus-fix-races-in-REPORT-LUNS.patch
Patch00179:     xen-block-Fix-removal-of-backend-instanc.patch
Patch00180:     migration-migration.c-Fix-hang-in-ram_sa.patch
Patch00181:     vhost-user-gpu-fix-memory-disclosure-in-.patch
Patch00182:     vhost-user-gpu-fix-resource-leak-in-vg_r.patch
Patch00183:     vhost-user-gpu-fix-memory-leak-in-vg_res.patch
Patch00184:     vhost-user-gpu-fix-memory-leak-while-cal.patch
Patch00185:     vhost-user-gpu-fix-leak-in-virgl_cmd_res.patch
Patch00186:     vhost-user-gpu-fix-leak-in-virgl_resourc.patch
Patch00187:     vhost-user-gpu-fix-OOB-write-in-virgl_cm.patch
Patch00188:     vhost-user-gpu-abstract-vg_cleanup_mappi.patch
Patch00189:     blockjob-Fix-crash-with-IOthread-when-bl.patch
Patch00190:     tests-add-migration-helpers-unit.patch
Patch00191:     qtest-rename-qtest_qmp_receive-to-qtest_.patch
Patch00192:     qtest-Reintroduce-qtest_qmp_receive-with.patch
Patch00193:     qtest-remove-qtest_qmp_receive_success.patch
Patch00194:     device-plug-test-use-qtest_qmp-to-send-t.patch
Patch00195:     qtest-switch-users-back-to-qtest_qmp_rec.patch
Patch00196:     qtest-check-that-drives-are-really-appea.patch
Patch00197:     qemu-iotests-qtest-rewrite-test-067-as-a.patch
Patch00198:     qom-code-hardening-have-bound-checking-w.patch
Patch00199:     hw-rdma-Fix-possible-mremap-overflow-in-.patch
Patch00200:     pvrdma-Ensure-correct-input-on-ring-init.patch
Patch00201:     pvrdma-Fix-the-ring-init-error-flow-CVE-.patch
Patch00202:     esp-always-check-current_req-is-not-NULL.patch
Patch00203:     esp-ensure-cmdfifo-is-not-empty-and-curr.patch
Patch00204:     esp-don-t-reset-async_len-directly-in-es.patch
Patch00205:     esp-ensure-that-do_cmd-is-set-to-zero-be.patch
Patch00206:     hw-scsi-megasas-check-for-NULL-frame-in-.patch
Patch00207:     net-eepro100-validate-various-address-va.patch
Patch00208:     hw-usb-host-stub-Remove-unused-header.patch
Patch00209:     usb-hid-avoid-dynamic-stack-allocation.patch
Patch00210:     usb-redir-avoid-dynamic-stack-allocation.patch
Patch00211:     usb-mtp-avoid-dynamic-stack-allocation.patch
Patch00212:     usb-limit-combined-packets-to-1-MiB-CVE-.patch
Patch00213:     usbredir-fix-free-call.patch
# Patches applied in roms/seabios/:
Patch01000:     seabios-use-python2-explicitly-as-needed.patch
Patch01001:     seabios-switch-to-python3-as-needed.patch
Patch01002:     enable-cross-compilation-on-ARM.patch
Patch01003:     vga-fix-cirrus-bios.patch
# Patches applied in roms/ipxe/:
Patch02000:     stub-out-the-SAN-req-s-in-int13.patch
Patch02001:     ipxe-Makefile-fix-issues-of-build-reprod.patch
Patch02002:     Fix-s-directive-argument-is-null-error.patch
Patch02003:     Workaround-compilation-error-with-gcc-9..patch
Patch02004:     Do-not-apply-WORKAROUND_CFLAGS-for-host-.patch
# Patches applied in roms/sgabios/:
Patch03000:     sgabios-Makefile-fix-issues-of-build-rep.patch
Patch03001:     roms-sgabios-Fix-csum8-to-be-built-by-ho.patch
# Patches applied in ui/keycodemapdb/:
Patch08000:     Make-keycode-gen-output-reproducible-use.patch
# Patches applied in slirp/:
Patch09000:     slirp-check-pkt_len-before-reading-proto.patch
Patch09001:     Drop-bogus-IPv6-messages.patch
Patch09002:     Add-mtod_check.patch
Patch09003:     bootp-limit-vendor-specific-area-to-inpu.patch
Patch09004:     bootp-check-bootp_input-buffer-size.patch
Patch09005:     upd6-check-udp6_input-buffer-size.patch
Patch09006:     tftp-check-tftp_input-buffer-size.patch
Patch09007:     tftp-introduce-a-header-structure.patch
Patch09008:     udp-check-upd_input-buffer-size.patch
Patch09009:     dhcp-Always-send-DHCP_OPT_LEN-bytes-in-o.patch
# Patches applied in roms/qboot/:
Patch12000:     ensure-headers-included-are-compatible-w.patch
Patch12001:     Enable-cross-compile-prefix-for-C-compil.patch

# Please do not add patches manually here.

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if "%{name}" == "qemu-linux-user"
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel-static
BuildRequires:  glibc-devel-static
BuildRequires:  makeinfo
BuildRequires:  pcre-devel-static
BuildRequires:  python3-base
BuildRequires:  zlib-devel-static
# we must not install the qemu-linux-user package when under QEMU build
%if 0%{?qemu_user_space_build:1}
#!BuildIgnore:  post-build-checks
%endif

%description
QEMU provides CPU emulation along with other related capabilities. This package
provides programs to run user space binaries and libraries meant for another
architecture. The syscall interface is intercepted and execution below the
syscall layer occurs on the native hardware and operating system.

# above section is for qemu-linux-user
# ------------------------------------------------------------------------
%else
%if %{build_x86_firmware_from_source}
BuildRequires:  acpica
%endif
BuildRequires:  alsa-devel
%if %{build_x86_firmware_from_source}
BuildRequires:  binutils-devel
%endif
BuildRequires:  bison
BuildRequires:  bluez-devel
BuildRequires:  brlapi-devel
%ifnarch %{ix86} aarch64 %arm
BuildRequires:  cross-aarch64-binutils
BuildRequires:  cross-aarch64-gcc%gcc_version
%endif
%ifnarch %{ix86} %arm
BuildRequires:  cross-arm-binutils
BuildRequires:  cross-arm-gcc%gcc_version
%endif
%if %{build_x86_firmware_from_source}
%ifnarch %{ix86} x86_64
# We must cross-compile on non-x86*
BuildRequires:  cross-i386-binutils
BuildRequires:  cross-i386-gcc%gcc_version
BuildRequires:  cross-x86_64-binutils
BuildRequires:  cross-x86_64-gcc%gcc_version
%endif
%endif
BuildRequires:  curl-devel
BuildRequires:  cyrus-sasl-devel
%if %{build_x86_firmware_from_source}
BuildRequires:  dos2unix
%endif
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel >= 2.48
%if %{build_x86_firmware_from_source}
%endif
%if 0%{?with_glusterfs}
BuildRequires:  glusterfs-devel >= 3
%endif
BuildRequires:  gtk3-devel >= 3.16
BuildRequires:  libaio-devel
BuildRequires:  libattr-devel
BuildRequires:  libbz2-devel
%if 0%{?is_opensuse}
BuildRequires:  libcacard-devel >= 2.5.1
%endif
BuildRequires:  libcap-devel
BuildRequires:  libcap-ng-devel
BuildRequires:  libdrm-devel
BuildRequires:  libepoxy-devel
BuildRequires:  libfdt-devel >= 1.4.2
BuildRequires:  libgbm-devel
BuildRequires:  libgcrypt-devel >= 1.5.0
BuildRequires:  libgnutls-devel >= 3.1.18
BuildRequires:  libiscsi-devel >= 1.9.0
BuildRequires:  libjpeg-devel
%if 0%{?is_opensuse}
BuildRequires:  libnfs-devel >= 1.9.3
%endif
%ifnarch %arm s390x
BuildRequires:  libnuma-devel
%endif
BuildRequires:  libpixman-1-0-devel >= 0.21.8
%ifarch x86_64
BuildRequires:  libpmem-devel
%endif
BuildRequires:  libpng-devel
BuildRequires:  libpulse-devel
%if 0%{?with_rbd}
BuildRequires:  librbd-devel
%endif
%if 0%{?is_opensuse}
BuildRequires:  libSDL2-devel
BuildRequires:  libSDL2_image-devel
%endif
BuildRequires:  libseccomp-devel >= 2.3.0
BuildRequires:  libspice-server-devel >= 0.12.5
BuildRequires:  libssh-devel >= 0.8
BuildRequires:  libusb-1_0-devel >= 1.0.13
BuildRequires:  libvdeplug-devel
BuildRequires:  pkgconfig(libudev)
%if 0%{?is_opensuse}
BuildRequires:  lzfse-devel
%endif
BuildRequires:  Mesa-devel
BuildRequires:  libxkbcommon-devel
BuildRequires:  lzo-devel
BuildRequires:  makeinfo
BuildRequires:  multipath-tools-devel
%if %{build_x86_firmware_from_source}
BuildRequires:  nasm
%endif
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  pwdutils
BuildRequires:  python-base
BuildRequires:  python3-Sphinx
BuildRequires:  python3-base
BuildRequires:  rdma-core-devel
BuildRequires:  snappy-devel
BuildRequires:  spice-protocol-devel >= 0.12.3
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}
%if %{kvm_available}
BuildRequires:  pkgconfig(udev)
%endif
BuildRequires:  usbredir-devel >= 0.6
BuildRequires:  virglrenderer-devel >= 0.4.1
BuildRequires:  vte-devel
%ifarch x86_64
BuildRequires:  xen-devel >= 4.2
%endif
BuildRequires:  xfsprogs-devel
%if %{build_x86_firmware_from_source}
BuildRequires:  xz-devel
%endif
BuildRequires:  zlib-devel
%if "%{name}" == "qemu-testsuite"
BuildRequires:  bc
BuildRequires:  python-base
BuildRequires:  qemu-arm = %{qemuver}
BuildRequires:  qemu-audio-alsa = %{qemuver}
BuildRequires:  qemu-audio-pa = %{qemuver}
%if 0%{?is_opensuse}
BuildRequires:  qemu-audio-sdl = %{qemuver}
%endif
BuildRequires:  qemu-block-curl = %{qemuver}
BuildRequires:  qemu-block-dmg = %{qemuver}
%if 0%{?with_glusterfs}
BuildRequires:  qemu-block-gluster = %{qemuver}
%endif
BuildRequires:  qemu-block-iscsi = %{qemuver}
%if 0%{?is_opensuse}
BuildRequires:  qemu-block-nfs = %{qemuver}
%endif
%if 0%{?with_rbd}
BuildRequires:  qemu-block-rbd = %{qemuver}
%endif
BuildRequires:  qemu-block-ssh = %{qemuver}
%if %{provide_edk2_firmware}
BuildRequires:  qemu-edk2 = %{qemuver}
%endif
BuildRequires:  qemu-extra = %{qemuver}
BuildRequires:  qemu-guest-agent = %{qemuver}
BuildRequires:  qemu-ipxe = 1.0.0+
%if 0%{?is_opensuse}
BuildRequires:  qemu-ksm = %{qemuver}
%endif
BuildRequires:  qemu-lang = %{qemuver}
BuildRequires:  qemu-ppc   = %{qemuver}
BuildRequires:  qemu-s390  = %{qemuver}
BuildRequires:  qemu-seabios = %{sbver}
BuildRequires:  qemu-sgabios = 8
BuildRequires:  qemu-tools = %{qemuver}
BuildRequires:  qemu-ui-curses = %{qemuver}
BuildRequires:  qemu-ui-gtk = %{qemuver}
%if 0%{?is_opensuse}
BuildRequires:  qemu-ui-sdl = %{qemuver}
%endif
BuildRequires:  qemu-ui-spice-app = %{qemuver}
BuildRequires:  qemu-vgabios = %{sbver}
BuildRequires:  qemu-x86    = %{qemuver}
%endif
Requires(pre):  shadow
Requires(post): coreutils
%if %{kvm_available}
Requires(post): acl
Requires(post): udev
%ifarch s390x
Requires(post): procps
%endif
Recommends:     kvm_stat
%endif
Recommends:     qemu-block-curl
Recommends:     qemu-tools
Recommends:     qemu-ui-curses
Recommends:     qemu-ui-gtk
%if 0%{?is_opensuse}
Recommends:     qemu-ui-sdl
%else
Obsoletes:      qemu-audio-sdl <= %{qemuver}
Obsoletes:      qemu-ui-sdl    <= %{qemuver}
%endif
Recommends:     qemu-ui-spice-app
Recommends:     qemu-x86
%ifarch ppc ppc64 ppc64le
Recommends:     qemu-ppc
%else
Suggests:       qemu-ppc
%endif
%ifarch s390x
Recommends:     qemu-s390
%else
Suggests:       qemu-s390
%endif
%ifarch %arm aarch64
Recommends:     qemu-arm
%else
Suggests:       qemu-arm
%endif
Suggests:       qemu-block-dmg
%if 0%{?with_glusterfs}
Suggests:       qemu-block-gluster
%endif
Suggests:       qemu-block-iscsi
%if 0%{?is_opensuse}
Suggests:       qemu-block-nfs
%endif
%if 0%{?with_rbd}
Suggests:       qemu-block-rbd
%endif
Suggests:       qemu-block-ssh
Suggests:       qemu-extra
Suggests:       qemu-lang
%if 0%{?is_opensuse}
Recommends:     qemu-ksm = %{qemuver}
%endif
Suggests:       qemu-microvm
Suggests:       qemu-vhost-user-gpu
Provides:       qemu-audio-oss = %{qemuver}
Obsoletes:      qemu-audio-oss < %{qemuver}

%define generic_qemu_description QEMU provides full machine emulation and cross architecture usage. It closely\
integrates with KVM and Xen virtualization, allowing for excellent performance.\
Many options are available for defining the emulated environment, including\
traditional devices, direct host device access, and interfaces specific to\
virtualization.

%description
%{generic_qemu_description}

This package acts as an umbrella package to the other QEMU sub-packages.

%if "%{name}" != "qemu-testsuite"

%package x86
Summary:        Machine emulator and virtualizer for x86 architectures
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
Requires:       %name = %{qemuver}
Requires:       qemu-ipxe
Requires:       qemu-seabios
Requires:       qemu-sgabios
Requires:       qemu-vgabios
Recommends:     ovmf
Recommends:     qemu-microvm
Recommends:     qemu-ovmf-x86_64

%description x86
%{generic_qemu_description}

This package provides i386 and x86_64 emulation.

%package ppc
Summary:        Machine emulator and virtualizer for Power architectures
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
Requires:       %name = %{qemuver}
Recommends:     qemu-ipxe
Recommends:     qemu-vgabios

%description ppc
%{generic_qemu_description}

This package provides ppc and ppc64 emulation.

%package s390
Summary:        Machine emulator and virtualizer for S/390 architectures
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
Requires:       %name = %{qemuver}

%description s390
%{generic_qemu_description}

This package provides s390x emulation.

%package arm
Summary:        Machine emulator and virtualizer for ARM architectures
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
Requires:       %name = %{qemuver}
Recommends:     ovmf
Recommends:     qemu-ipxe
Recommends:     qemu-uefi-aarch64
Recommends:     qemu-vgabios

%description arm
%{generic_qemu_description}

This package provides arm emulation.

%package extra
Summary:        Machine emulator and virtualizer for "extra" architectures
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
Requires:       %name = %{qemuver}
Recommends:     qemu-ipxe
Recommends:     qemu-vgabios

%description extra
%{generic_qemu_description}

This package provides some lesser used emulations, including alpha, m68k,
mips, moxie, sparc, and xtensa. (The term "extra" is juxtapositioned against
more popular QEMU packages which are dedicated to a single architecture.)

%if %{legacy_qemu_kvm}
%package kvm
Summary:        Wrapper to enable KVM acceleration under QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%ifarch %ix86 x86_64
Requires:       qemu-x86 = %{qemuver}
%endif
%ifarch s390x
Requires:       qemu-s390 = %{qemuver}
%endif
Provides:       kvm = %{qemuver}
Obsoletes:      kvm < %{qemuver}

%description kvm
%{generic_qemu_description}

This package simply provides a shell script wrapper for the QEMU program which
does the actual machine emulation and virtualization for this architecture. The
wrapper simply adds command-line parameters to ensure that the KVM accelerator
is invoked. It provides no additional benefit, and is considered deprecated.
%endif

%package lang
Summary:        Translations for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2

%description lang
This package contains a few language translations, particularly for the
graphical user interface components that come with QEMU. The bulk of strings
in QEMU are not localized.

# Modules need to match {qemu-system-*,qemu-img} version.
# We cannot have qemu and qemu-tools require them in the right version,
# as that would drag in the dependencies the modules are supposed to avoid.
# Nor can we have modules require the right version of qemu and qemu-tools
# as Xen reuses our qemu-tools but does not want our qemu and qemu-x86.
%define qemu_module_conflicts \
Conflicts:      %name < %{qemuver}-%{release} \
Conflicts:      %name > %{qemuver}-%{release} \
Conflicts:      qemu-tools < %{qemuver}-%{release} \
Conflicts:      qemu-tools > %{qemuver}-%{release}

%package block-curl
Summary:        cURL block support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
Provides:       %name:%_libdir/%name/block-curl.so
%{qemu_module_conflicts}

%description block-curl
This package contains a module for accessing network-based image files over
a network connection from qemu-img tool and QEMU system emulation.

%package block-dmg
Summary:        DMG block support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description block-dmg
This package contains a module for accessing Mac OS X image files from
qemu-img tool and QEMU system emulation.

%if 0%{?with_glusterfs}
%package block-gluster
Summary:        GlusterFS block support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description block-gluster
This package contains a module for accessing network-based image files over a
GlusterFS network connection from qemu-img tool and QEMU system emulation.
%endif

%package block-iscsi
Summary:        iSCSI block support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description block-iscsi
This package contains a module for accessing network-based image files over an
iSCSI network connection from qemu-img tool and QEMU system emulation.

%if 0%{?is_opensuse}
%package block-nfs
Summary:        direct Network File System support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description block-nfs
This package contains a module for directly accessing nfs based image files.
%endif

%if 0%{?with_rbd}
%package block-rbd
Summary:        Rados Block Device (Ceph) support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description block-rbd
This package contains a module for accessing ceph (rbd,rados) image files.
%endif

%package block-ssh
Summary:        SSH (SFTP) block support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description block-ssh
This package contains a module for accessing network-based image files over an
SSH network connection from qemu-img tool and QEMU system emulation.

%package ui-curses
Summary:        Curses based UI support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description ui-curses
This package contains a module for doing curses based UI for QEMU.

%package ui-gtk
Summary:        GTK based UI support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description ui-gtk
This package contains a module for doing GTK based UI for QEMU.

%if 0%{?is_opensuse}
%package ui-sdl
Summary:        SDL based UI support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description ui-sdl
This package contains a module for doing SDL based UI for QEMU.
%endif

%package ui-spice-app
Summary:        Spice UI support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description ui-spice-app
This package contains a module for doing Spice based UI for QEMU.

%package audio-alsa
Summary:        ALSA based audio support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description audio-alsa
This package contains a module for ALSA based audio support for QEMU.

%package audio-pa
Summary:        Pulse Audio based audio support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description audio-pa
This package contains a module for Pulse Audio based audio support for QEMU.

%if 0%{?is_opensuse}
%package audio-sdl
Summary:        SDL based audio support for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description audio-sdl
This package contains a module for SDL based audio support for QEMU.
%endif

%package vhost-user-gpu
Summary:        Vhost user mode virtio-gpu 2D/3D rendering backend for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
%{qemu_module_conflicts}

%description vhost-user-gpu
This package contains a vhost user mode virtio-gpu 2D/3D rendering backend for QEMU

%package tools
Summary:        Tools for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
Provides:       %name:%_libexecdir/qemu-bridge-helper
Requires(pre):  permissions
Requires(pre):  shadow
Recommends:     multipath-tools
Recommends:     qemu-block-curl
%if 0%{?with_rbd}
Recommends:     qemu-block-rbd
%endif

%description tools
This package contains various QEMU related tools, including a bridge helper,
a virtfs helper, ivshmem, disk utilities and scripts for various purposes.

%package guest-agent
Summary:        Guest agent for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
Provides:       %name:%_bindir/qemu-ga
Requires(pre):  shadow
Requires(post): udev
Supplements:    modalias(acpi*:QEMU0002%3A*)
Supplements:    modalias(pci:v00005853d00000001sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v0000FFFDd00000101sv*sd*bc*sc*i*)
%{?systemd_ordering}

%description guest-agent
This package contains the QEMU guest agent. It is installed in the linux guest
to provide information and control at the guest OS level.

%ifarch %{build_rom_arch}
%package microvm
Summary:        x86 MicroVM firmware for QEMU
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
BuildArch:      noarch

%description microvm
This package provides minimal x86 firmware for booting certain guests.
qboot based bios-microvm provides the minimum resources needed to boot PVH and
bzImages.

%package seabios
Summary:        x86 Legacy BIOS for QEMU
Group:          System/Emulators/PC
Version:        %{sbver}
Release:        lp152.9.20.2
BuildArch:      noarch
Conflicts:      %name < 1.6.0

%description seabios
SeaBIOS is an open source implementation of a 16bit x86 BIOS. SeaBIOS
is the default and legacy BIOS for QEMU.

%package vgabios
Summary:        VGA BIOSes for QEMU
Group:          System/Emulators/PC
Version:        %{sbver}
Release:        lp152.9.20.2
BuildArch:      noarch
Conflicts:      %name < 1.6.0

%description vgabios
VGABIOS provides the video ROM BIOSes for the following variants of VGA
emulated devices: Std VGA, QXL, Cirrus CLGD 5446 and VMware emulated
video card.

%package sgabios
Summary:        Serial Graphics Adapter BIOS for QEMU
Group:          System/Emulators/PC
Version:        8
Release:        lp152.9.20.2
BuildArch:      noarch
Conflicts:      %name < 1.6.0

%description sgabios
The Google Serial Graphics Adapter BIOS or SGABIOS provides a means for legacy
x86 software to communicate with an attached serial console as if a video card
were attached.

%package ipxe
Summary:        PXE ROMs for QEMU NICs
Group:          System/Emulators/PC
Version:        1.0.0+
Release:        lp152.9.20.2
BuildArch:      noarch
Conflicts:      %name < 1.6.0

%description ipxe
Provides Preboot Execution Environment (PXE) ROM support for various emulated
network adapters available with QEMU.
%endif

%if %{provide_edk2_firmware}
%package edk2
Summary:        EDK II based firmware
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
BuildArch:      noarch

%description edk2
Provides EDK II based firmware.
%endif

%if 0%{?is_opensuse}
%package ksm
Summary:        Kernel Samepage Merging services
Group:          System/Emulators/PC
Version:        %{qemuver}
Release:        lp152.9.20.2
Requires(pre):  coreutils
Requires(post): coreutils

%description ksm
Kernel Samepage Merging (KSM) is a memory-saving de-duplication feature, that
merges anonymous (private) pages (not pagecache ones).

This package provides a service file for starting and stopping KSM.
%endif

# above is for qemu
%endif
# above section is for qemu and qemu-testsuite
%endif

# ========================================================================

%prep
%setup -q -n %{srcname}-%{expand:%%(SV=%{srcver};echo ${SV%%%%+git*})}
%patch00000 -p1
%patch00001 -p1
%patch00002 -p1
%patch00003 -p1
%patch00004 -p1
%patch00005 -p1
%patch00006 -p1
%patch00007 -p1
%patch00008 -p1
%patch00009 -p1
%patch00010 -p1
%patch00011 -p1
%patch00012 -p1
%patch00013 -p1
%patch00014 -p1
%patch00015 -p1
%patch00016 -p1
%patch00017 -p1
%patch00018 -p1
%patch00019 -p1
%patch00020 -p1
%patch00021 -p1
%patch00022 -p1
%patch00023 -p1
%patch00024 -p1
%patch00025 -p1
%patch00026 -p1
%patch00027 -p1
%patch00028 -p1
%patch00029 -p1
%patch00030 -p1
%patch00031 -p1
%patch00032 -p1
%patch00033 -p1
%patch00034 -p1
%patch00035 -p1
%patch00036 -p1
%patch00037 -p1
%patch00038 -p1
%patch00039 -p1
%patch00040 -p1
%patch00041 -p1
%patch00042 -p1
%patch00043 -p1
%patch00044 -p1
%patch00045 -p1
%patch00046 -p1
%patch00047 -p1
%patch00048 -p1
%patch00049 -p1
%patch00050 -p1
%patch00051 -p1
%patch00052 -p1
%patch00053 -p1
%patch00054 -p1
%patch00055 -p1
%patch00056 -p1
%patch00057 -p1
%patch00058 -p1
%patch00059 -p1
%patch00060 -p1
%patch00061 -p1
%patch00062 -p1
%patch00063 -p1
%patch00064 -p1
%patch00065 -p1
%patch00066 -p1
%patch00067 -p1
%patch00068 -p1
%patch00069 -p1
%patch00070 -p1
%patch00071 -p1
%patch00072 -p1
%patch00073 -p1
%patch00074 -p1
%patch00075 -p1
%patch00076 -p1
%patch00077 -p1
%patch00078 -p1
%patch00079 -p1
%patch00080 -p1
%patch00081 -p1
%patch00082 -p1
%patch00083 -p1
%patch00084 -p1
%patch00085 -p1
%patch00086 -p1
%patch00087 -p1
%patch00088 -p1
%patch00089 -p1
%patch00090 -p1
%patch00091 -p1
%patch00092 -p1
%patch00093 -p1
%patch00094 -p1
%patch00095 -p1
%patch00096 -p1
%patch00097 -p1
%patch00098 -p1
%patch00099 -p1
%patch00100 -p1
%patch00101 -p1
%patch00102 -p1
%patch00103 -p1
%patch00104 -p1
%patch00105 -p1
%patch00106 -p1
%patch00107 -p1
%patch00108 -p1
%patch00109 -p1
%patch00110 -p1
%patch00111 -p1
%patch00112 -p1
%patch00113 -p1
%patch00114 -p1
%patch00115 -p1
%patch00116 -p1
%patch00117 -p1
%patch00118 -p1
%patch00119 -p1
%patch00120 -p1
%patch00121 -p1
%patch00122 -p1
%patch00123 -p1
%patch00124 -p1
%patch00125 -p1
%patch00126 -p1
%patch00127 -p1
%patch00128 -p1
%patch00129 -p1
%patch00130 -p1
%patch00131 -p1
%patch00132 -p1
%patch00133 -p1
%patch00134 -p1
%patch00135 -p1
%patch00136 -p1
%patch00137 -p1
%patch00138 -p1
%patch00139 -p1
%patch00140 -p1
%patch00141 -p1
%patch00142 -p1
%patch00143 -p1
%patch00144 -p1
%patch00145 -p1
%patch00146 -p1
%patch00147 -p1
%patch00148 -p1
%patch00149 -p1
%patch00150 -p1
%patch00151 -p1
%patch00152 -p1
%patch00153 -p1
%patch00154 -p1
%patch00155 -p1
%patch00156 -p1
%patch00157 -p1
%patch00158 -p1
%patch00159 -p1
%patch00160 -p1
%patch00161 -p1
%patch00162 -p1
%patch00163 -p1
%patch00164 -p1
%patch00165 -p1
%patch00166 -p1
%patch00167 -p1
%patch00168 -p1
%patch00169 -p1
%patch00170 -p1
%patch00171 -p1
%patch00172 -p1
%patch00173 -p1
%patch00174 -p1
%patch00175 -p1
%patch00176 -p1
%patch00177 -p1
%patch00178 -p1
%patch00179 -p1
%patch00180 -p1
%patch00181 -p1
%patch00182 -p1
%patch00183 -p1
%patch00184 -p1
%patch00185 -p1
%patch00186 -p1
%patch00187 -p1
%patch00188 -p1
%patch00189 -p1
%patch00190 -p1
%patch00191 -p1
%patch00192 -p1
%patch00193 -p1
%patch00194 -p1
%patch00195 -p1
%patch00196 -p1
%patch00197 -p1
%patch00198 -p1
%patch00199 -p1
%patch00200 -p1
%patch00201 -p1
%patch00202 -p1
%patch00203 -p1
%patch00204 -p1
%patch00205 -p1
%patch00206 -p1
%patch00207 -p1
%patch00208 -p1
%patch00209 -p1
%patch00210 -p1
%patch00211 -p1
%patch00212 -p1
%patch00213 -p1
%patch01000 -p1
%patch01001 -p1
%patch01002 -p1
%patch01003 -p1
%if 0%{?patch-possibly-applied-elsewhere}
%patch02000 -p1
%endif
%patch02001 -p1
%patch02002 -p1
%patch02003 -p1
%ifarch aarch64
%patch02004 -p1
%endif
%patch03000 -p1
%patch03001 -p1
%patch08000 -p1
%patch09000 -p1
%patch09001 -p1
%patch09002 -p1
%patch09003 -p1
%patch09004 -p1
%patch09005 -p1
%patch09006 -p1
%patch09007 -p1
%patch09008 -p1
%patch09009 -p1
%patch12000 -p1
%patch12001 -p1

%if "%{name}" != "qemu-linux-user"
# for the record, this set of firmware files is installed, but we don't
# build (yet): bamboo.dtb canyonlands.dtb hppa-firmware.img openbios-ppc openbios-sparc32
# openbios-sparc64 palcode-clipper petalogix-ml605.dtb petalogix-s3adsp1800.dtb ppc_rom.bin
# QEMU,cgthree.bin QEMU,tcx.bin qemu_vga.ndrv u-boot.e500 u-boot-sam460-20100605.bin
# opensbi-riscv32-virt-fw_jump.bin

# This first list group isn't specific to what this instance builds
%define ppc_default_firmware {%nil}
%define ppc_extra_firmware {skiboot.lid slof.bin}
%define ppc64_only_default_firmware {%nil}
%define ppc64_only_extra_firmware {%nil}
%define riscv64_default_firmware {opensbi-riscv64-sifive_u-fw_jump.bin \
opensbi-riscv64-virt-fw_jump.bin}
%define riscv64_extra_firmware {%nil}
%define s390x_default_firmware {s390-ccw.img s390-netboot.img}
%define s390x_extra_firmware {%nil}
%define x86_default_firmware {linuxboot.bin linuxboot_dma.bin multiboot.bin \
kvmvapic.bin pvh.bin}
%define x86_extra_firmware {bios.bin bios-256k.bin bios-microvm.bin \
pxe-e1000.rom pxe-eepro100.rom pxe-ne2k_pci.rom pxe-pcnet.rom pxe-rtl8139.rom \
pxe-virtio.rom sgabios.bin vgabios-ati.bin vgabios-bochs-display.bin \
vgabios.bin vgabios-cirrus.bin vgabios-qxl.bin vgabios-ramfb.bin \
vgabios-stdvga.bin vgabios-virtio.bin vgabios-vmware.bin}
%define x86_64_only_default_firmware {%nil}
%define x86_64_only_extra_firmware {edk2-aarch64-code.fd.bz2 \
edk2-arm-code.fd.bz2 edk2-arm-vars.fd.bz2 edk2-i386-code.fd.bz2 \
edk2-i386-secure-code.fd.bz2 edk2-i386-vars.fd.bz2 edk2-x86_64-code.fd.bz2 \
edk2-x86_64-secure-code.fd.bz2 efi-e1000.rom efi-e1000e.rom efi-eepro100.rom \
efi-ne2k_pci.rom efi-pcnet.rom efi-rtl8139.rom efi-virtio.rom efi-vmxnet3.rom}

%define firmware { \
%{?ppc_default_firmware} %{?ppc_extra_firmware} \
%{?ppc64_only_default_firmware} %{?ppc64_only_extra_firmware} \
%{?riscv64_default_firmware} %{?riscv64_extra_firmware} \
%{?s390x_default_firmware} %{?s390x_extra_firmware} \
%{?x86_default_firmware} %{?x86_extra_firmware} \
%{?x86_64_only_default_firmware} %{?x86_64_only_extra_firmware} }

# This second list group is specific to what this instance builds
%define ppc_default_built_firmware %{ppc_default_firmware}
%if %{build_skiboot_from_source} && %{build_slof_from_source}
%define ppc_extra_built_firmware %{ppc_extra_firmware}
%else
%if %{build_skiboot_from_source}
%define ppc_extra_built_firmware {skiboot.lid}
%endif
%if %{build_slof_from_source}
%define ppc_extra_built_firmware {slof.bin}
%endif
%endif

%ifarch ppc64
%define ppc64_only_default_built_firmware %{ppc64_only_default_firmware}
%define ppc64_only_extra_built_firmware %{ppc64_only_extra_firmware}
%endif

%ifarch riscv64
%define riscv64_default_built_firmware %{riscv64_default_firmware}
%define riscv64_extra_built_firmware %{riscv64_extra_firmware}
%endif

%ifarch s390x
%define s390x_default_built_firmware %{s390x_default_firmware}
%define s390x_extra_built_firmware %{s390x_extra_firmware}
%endif

%ifarch %ix86 x86_64
%define x86_default_built_firmware %{x86_default_firmware}
%ifarch x86_64
%define x86_64_only_default_built_firmware %{x86_64_only_default_firmware}
%endif
%endif

%if %{build_x86_firmware_from_source}
%define x86_extra_built_firmware %{x86_extra_firmware}
%ifarch x86_64
%define x86_64_only_extra_built_firmware %{x86_64_only_extra_firmware}
%endif
%endif

%define built_firmware { \
%{?ppc_default_built_firmware} %{?ppc_extra_built_firmware} \
%{?ppc64_only_default_built_firmware} %{?ppc64_only_extra_built_firmware} \
%{?riscv64_default_built_firmware} %{?riscv64_extra_built_firmware} \
%{?s390x_default_built_firmware} %{?s390x_extra_built_firmware} \
%{?x86_default_built_firmware} %{?x86_extra_built_firmware} \
%{?x86_64_only_default_built_firmware} %{?x86_64_only_extra_built_firmware} }

%if "%{name}" != "qemu-testsuite"

# delete the firmware files that we intend to build
for i in %built_firmware
do
  unlink pc-bios/$i
done

# ------------------------------------------------------------------------
%else

# delete the firmware files that we intend to link from built packages
for i in %firmware
do
  if [[ $i =~ .*[.]bz2 ]]; then
    echo "Skipping %i"
  else
    unlink pc-bios/$i
  fi
done

%endif
# above section is for qemu and qemu-testsuite
%endif

# ========================================================================

%build
%define _lto_cflags %{nil}

%if %build_in_tree
%define mybuilddir %{_builddir}/%buildsubdir
%else
%define mybuilddir %{_builddir}/mybuilddir
mkdir -p %mybuilddir
cd %mybuilddir
%endif

../%buildsubdir/configure \
	--prefix=%_prefix \
	--sysconfdir=%_sysconfdir \
	--libdir=%_libdir \
	--libexecdir=%_libexecdir \
	--localstatedir=%_localstatedir \
	--docdir=%_docdir/%name \
	--firmwarepath=%_datadir/%name \
        --python=%_bindir/python3 \
	--extra-cflags="%{optflags}" \
	--disable-stack-protector \
	--disable-strip \
%if "%{name}" != "qemu-linux-user"
	--with-pkgversion="%(echo '%{distro}' | sed 's/ (.*)//')" \
	--with-default-devices \
	--enable-system --disable-linux-user \
	--enable-tools --enable-guest-agent \
	--enable-modules \
	--enable-pie \
	--enable-docs \
%if 0%{?is_opensuse}
	--audio-drv-list="pa alsa sdl" \
%else
	--audio-drv-list="pa alsa" \
%endif
	--enable-attr \
	--disable-auth-pam \
	--enable-bluez \
	--enable-bochs \
	--enable-brlapi \
	--enable-bzip2 \
	--enable-cap-ng \
	--disable-capstone \
	--enable-cloop \
	--enable-coroutine-pool \
	--disable-crypto-afalg \
	--enable-curl \
	--enable-curses \
	--enable-dmg \
	--enable-fdt \
	--enable-gcrypt \
%if 0%{?with_glusterfs}
	--enable-glusterfs \
%else
	--disable-glusterfs \
%endif
	--enable-gnutls \
	--enable-gtk \
	--disable-hax \
	--disable-hvf \
	--enable-iconv \
	--disable-jemalloc \
%if %{kvm_available}
	--enable-kvm \
%else
	--disable-kvm \
%endif
	--enable-libiscsi \
%if 0%{?is_opensuse}
	--enable-libnfs \
%else
	--disable-libnfs \
%endif
%ifarch x86_64
	--enable-libpmem \
%else
	--disable-libpmem \
%endif
	--enable-libssh \
	--enable-libusb \
	--disable-libxml2 \
	--enable-linux-aio \
%if 0%{?is_opensuse}
	--enable-lzfse \
%else
	--disable-lzfse \
%endif
	--enable-lzo \
	--disable-malloc-trim \
%if %{with system_membarrier}
	--enable-membarrier \
%else
	--disable-membarrier \
%endif
	--enable-mpath \
	--disable-netmap \
	--disable-nettle \
%ifarch %arm s390x
	--disable-numa \
%else
	--enable-numa \
%endif
	--enable-opengl \
	--enable-parallels \
	--disable-plugins \
	--enable-pvrdma \
	--enable-qcow1 \
	--enable-qed \
%if 0%{?with_rbd}
	--enable-rbd \
%else
	--disable-rbd \
%endif
	--enable-rdma \
	--enable-replication \
	--disable-sanitizers \
%if 0%{?is_opensuse}
	--enable-sdl \
	--enable-sdl-image \
%else
	--disable-sdl \
	--disable-sdl-image \
%endif
	--enable-seccomp \
	--enable-sheepdog \
%if 0%{?is_opensuse}
	--enable-smartcard \
%else
	--disable-smartcard \
%endif
	--enable-snappy \
	--enable-spice \
	--disable-tcmalloc \
	--enable-tpm \
	--enable-usb-redir \
	--enable-vde \
	--enable-vdi \
	--enable-vhost-crypto \
	--enable-vhost-kernel \
	--enable-vhost-net \
	--enable-vhost-scsi \
	--enable-vhost-user \
        --enable-vhost-user-fs \
	--enable-vhost-vsock \
	--enable-virglrenderer \
	--enable-virtfs \
	--enable-vnc \
	--enable-vnc-jpeg \
	--enable-vnc-png \
	--enable-vnc-sasl \
	--enable-vte \
	--enable-vvfat \
	--enable-werror \
	--disable-whpx \
%ifarch x86_64
	--enable-xen \
	--enable-xen-pci-passthrough \
%else
	--disable-xen \
%endif
	--enable-xfsctl \
        --enable-xkbcommon \
# above section is for qemu and qemu-testsuite
# ------------------------------------------------------------------------
%else
	--without-default-devices \
	--disable-system --enable-linux-user \
	--disable-tools --disable-guest-agent \
	--static \
	--disable-modules \
	--disable-pie \
	--disable-docs \
	--audio-drv-list="" \
	--disable-blobs \
	--disable-bochs \
	--disable-capstone \
	--disable-cloop \
	--enable-coroutine-pool \
	--disable-dmg \
	--disable-fdt \
	--disable-iconv \
	--disable-kvm \
	--disable-malloc-trim \
%if %{with system_membarrier}
	--enable-membarrier \
%else
	--disable-membarrier \
%endif
	--disable-parallels \
	--disable-plugins \
	--disable-qcow1 \
	--disable-qed \
	--disable-replication \
	--disable-sheepdog \
	--disable-slirp \
	--disable-tpm \
	--disable-vdi \
	--disable-vhost-crypto \
	--disable-vhost-kernel \
	--disable-vhost-net \
	--disable-vhost-scsi \
	--disable-vhost-user \
        --disable-vhost-user-fs \
	--disable-vhost-vsock \
	--disable-vnc \
	--disable-vvfat \
        --disable-xkbcommon \

# above section is for qemu-linux-user
%endif

%if "%{name}" == "qemu"

make %{?_smp_mflags} V=1

# Firmware

%ifarch s390x
for i in %s390x_default_built_firmware
do
  cp pc-bios/s390-ccw/$i %{_builddir}/%buildsubdir/pc-bios/
done
%endif

%ifarch ppc64
for i in %ppc64_only_default_built_firmware
do
  cp pc-bios/spapr-rtas/$i %{_builddir}/%buildsubdir/pc-bios/
done
%endif

%ifarch %ix86 x86_64
for i in %x86_default_built_firmware
do
  cp pc-bios/optionrom/$i %{_builddir}/%buildsubdir/pc-bios/
done
%ifarch x86_64
for i in %x86_64_only_default_built_firmware
do
  cp pc-bios/optionrom/$i %{_builddir}/%buildsubdir/pc-bios/
done
%endif
%endif

%if %{build_x86_firmware_from_source}
%ifnarch %{ix86} x86_64
export CC=x86_64-suse-linux-gcc
export LD=x86_64-suse-linux-ld
%endif

make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms bios \
  SEABIOS_EXTRAVERSION="-rebuilt.opensuse.org" \
%ifnarch %ix86 x86_64
  HOSTCC=cc \
%endif

make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms bios-microvm

%ifnarch %ix86
%if %{provide_edk2_firmware}
make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms efi \
  EDK2_BASETOOLS_OPTFLAGS='-fPIE'
%endif
%endif

make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms seavgabios \
%ifnarch %ix86 x86_64
  HOSTCC=cc \
%endif

make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms seavgabios-ati \
%ifnarch %ix86 x86_64
  HOSTCC=cc \
%endif

make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms pxerom

%ifnarch %ix86
make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms efirom \
  EDK2_BASETOOLS_OPTFLAGS='-fPIE'
%endif

make                 -C %{_builddir}/%buildsubdir/roms sgabios \
  HOSTCC=cc

%if %{force_fit_virtio_pxe_rom}
pushd %{_builddir}/%buildsubdir
patch -p1 < %_sourcedir/stub-out-the-SAN-req-s-in-int13.patch
popd
make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms pxerom_variants=virtio pxerom_targets=1af41000 pxerom
%endif

# enforce pxe rom sizes for migration compatability from SLE 11 SP3 forward
# the following need to be > 64K
%define supported_nics_large {e1000 rtl8139}
# the following need to be <= 64K
%define supported_nics_small {virtio}
# Though not required, make unsupported pxe roms migration compatable as well
%define unsupported_nics {eepro100 ne2k_pci pcnet}

for i in %supported_nics_large %unsupported_nics
  do
    if test "`stat -c '%s' %{_builddir}/%buildsubdir/pc-bios/pxe-$i.rom`" -gt "131072" ; then
    echo "pxe rom is too large"
    exit 1
  fi
  if test "`stat -c '%s' %{_builddir}/%buildsubdir/pc-bios/pxe-$i.rom`" -le "65536" ; then
    ./%{_builddir}/%buildsubdir/roms/ipxe/src/util/padimg.pl %{_builddir}/%buildsubdir/pc-bios/pxe-$i.rom -s 65536 -b 255
    echo -ne "SEGMENT OVERAGE\0" >> %{_builddir}/%buildsubdir/pc-bios/pxe-$i.rom
  fi
done
for i in %supported_nics_small
  do
    if test "`stat -c '%s' %{_builddir}/%buildsubdir/pc-bios/pxe-$i.rom`" -gt "65536" ; then
    echo "pxe rom is too large"
    exit 1
  fi
done
%ifnarch %{ix86} x86_64
unset CC
unset LD
%endif
%endif

%if %{build_skiboot_from_source}
make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms skiboot CROSS=
%endif

%if %{build_slof_from_source}
make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms slof
%endif

%if %{build_opensbi_from_source}
make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms opensbi64-virt CROSS_COMPILE=
make %{?_smp_mflags} -C %{_builddir}/%buildsubdir/roms opensbi64-sifive_u CROSS_COMPILE=
%endif

# above section is for qemu
%endif
# ------------------------------------------------------------------------
%if "%{name}" == "qemu-testsuite"

# TODO: Some of these are actually overwritten during the following make's
ln -s %_bindir/qemu-img qemu-img
ln -s %_bindir/qemu-ga qemu-ga
ln -s %_bindir/qemu-io qemu-io
ln -s %_bindir/elf2map elf2map
ln -s %_bindir/qemu-nbd qemu-nbd
ln -s %_bindir/qemu-edid qemu-edid
ln -s %_bindir/qemu-keymap qemu-keymap
ln -s %_bindir/ivshmem-client ivshmem-client
ln -s %_bindir/ivshmem-server ivshmem-server
ln -s %_bindir/qemu-pr-helper scsi/qemu-pr-helper
ln -s %_bindir/virtfs-proxy-helper fsdev/virtfs-proxy-helper

for i in %firmware
do
  if [[ $i =~ .*[.]bz2 ]]; then
    echo "Skipping $i"
  else
    ln -s %_datadir/qemu/$i pc-bios/$i
  fi
done

for conf in %{_builddir}/%buildsubdir/default-configs/*-softmmu.mak; do
  arch=`echo "$conf" | sed -e 's|%{_builddir}/%buildsubdir/default-configs/\(.*\)-softmmu.mak|\1|g'`
  ln -s %_bindir/qemu-system-$arch $arch-softmmu/qemu-system-$arch
done

# Compile the QOM test binary first, so that ...
touch -r config-host.mak pc-bios
make %{?_smp_mflags} tests/qom-test %{?_smp_mflags} V=1
# ... make comes in fresh and has lots of address space (needed for 32bit, bsc#957379)
make %{?_smp_mflags} check-report.tap V=1

%endif
# ------------------------------------------------------------------------
%if "%{name}" == "qemu-linux-user"

make %{?_smp_mflags} V=1

%ifarch %ix86
%define qemu_arch i386
%endif
%ifarch x86_64
%define qemu_arch x86_64
%endif
%ifarch %arm
%define qemu_arch arm
%endif
%ifarch aarch64
%define qemu_arch aarch64
%endif
%ifarch ppc
%define qemu_arch ppc
%endif
%ifarch ppc64
%define qemu_arch ppc64
%endif
%ifarch ppc64le
%define qemu_arch ppc64le
%endif
%ifarch s390x
%define qemu_arch s390x
%endif

%endif

# ========================================================================

%check
cd %mybuilddir
%if "%{name}" == "qemu-testsuite"

export QEMU_PROG=%_bindir/qemu-system-x86_64
export QEMU_IMG_PROG=%_bindir/qemu-img
export QEMU_IO_PROG=%_bindir/qemu-io
export QEMU_NBD_PROG=%_bindir/qemu-nbd
make %{?_smp_mflags} check-block V=1

%endif
# ------------------------------------------------------------------------
%if "%{name}" == "qemu-linux-user"

%ifarch %ix86 x86_64 %arm aarch64 ppc ppc64 ppc64le s390x
%{qemu_arch}-linux-user/qemu-%{qemu_arch} %_bindir/ls > /dev/null
make %{?_smp_mflags} check-softfloat
%endif

%endif

# ========================================================================

%install
cd %mybuilddir

%if "%{name}" == "qemu-testsuite"

install -D -m 0644 check-report.tap %{buildroot}%_datadir/qemu/check-report.tap

%endif
# ------------------------------------------------------------------------
%if "%{name}" == "qemu-linux-user"

make %{?_smp_mflags} install DESTDIR=%{buildroot}
rm -rf %{buildroot}%_datadir/qemu/keymaps
unlink %{buildroot}%_datadir/qemu/trace-events-all
install -d -m 755 %{buildroot}%_sbindir
install -m 755 scripts/qemu-binfmt-conf.sh %{buildroot}%_sbindir
%fdupes -s %{buildroot}

%endif
# ------------------------------------------------------------------------
%if "%{name}" == "qemu"

make %{?_smp_mflags} install DESTDIR=%{buildroot}
%ifnarch %{build_rom_arch}
for f in %{x86_extra_firmware} \
         %{x86_64_only_extra_firmware}; do
  unlink %{buildroot}%_datadir/%name/${f%.bz2}
done
%define do_more_edk2_unlinks 1
%else
%ifarch %ix86 aarch64
unlink %{buildroot}%_datadir/%name/edk2-aarch64-code.fd
unlink %{buildroot}%_datadir/%name/edk2-arm-code.fd
unlink %{buildroot}%_datadir/%name/edk2-arm-vars.fd
unlink %{buildroot}%_datadir/%name/edk2-i386-code.fd
unlink %{buildroot}%_datadir/%name/edk2-i386-secure-code.fd
unlink %{buildroot}%_datadir/%name/edk2-i386-vars.fd
unlink %{buildroot}%_datadir/%name/edk2-licenses.txt || true
unlink %{buildroot}%_datadir/%name/edk2-x86_64-code.fd
unlink %{buildroot}%_datadir/%name/edk2-x86_64-secure-code.fd
%endif
install -D -m 0644 %{SOURCE14} %{buildroot}%_datadir/%name/firmware/50-seabios-256k.json
install -D -m 0644 %{SOURCE15} %{buildroot}%_datadir/%name/firmware/60-seabios-128k.json
%endif
%if 0%{?do_more_edk2_unlinks} || %{provide_edk2_firmware} == 0
unlink %{buildroot}%_datadir/%name/edk2-licenses.txt || true
unlink %{buildroot}%_datadir/%name/firmware/50-edk2-i386-secure.json
unlink %{buildroot}%_datadir/%name/firmware/50-edk2-x86_64-secure.json
unlink %{buildroot}%_datadir/%name/firmware/60-edk2-aarch64.json
unlink %{buildroot}%_datadir/%name/firmware/60-edk2-arm.json
unlink %{buildroot}%_datadir/%name/firmware/60-edk2-i386.json
unlink %{buildroot}%_datadir/%name/firmware/60-edk2-x86_64.json
%endif
%find_lang %name
install -d -m 0755 %{buildroot}%_datadir/%name/firmware
install -d -m 0755 %{buildroot}%_libexecdir/supportconfig/plugins
install -d -m 0755 %{buildroot}%_sysconfdir/%name/firmware
install -D -m 0644 %{SOURCE4} %{buildroot}%_sysconfdir/%name/bridge.conf
install -D -m 0755 %{SOURCE3} %{buildroot}%_datadir/%name/qemu-ifup
install -D -p -m 0644 %{SOURCE8} %{buildroot}/usr/lib/udev/rules.d/80-qemu-ga.rules
install -D -m 0755 scripts/analyze-migration.py  %{buildroot}%_bindir/analyze-migration.py
install -D -m 0755 scripts/vmstate-static-checker.py  %{buildroot}%_bindir/vmstate-static-checker.py
install -D -m 0755 %{SOURCE9} %{buildroot}%_libexecdir/supportconfig/plugins/%name
%if 0%{?is_opensuse} == 0
install -D -m 0644 %{SOURCE10} %{buildroot}%_docdir/qemu-arm/supported.txt
install -D -m 0644 %{SOURCE11} %{buildroot}%_docdir/qemu-ppc/supported.txt
install -D -m 0644 %{SOURCE12} %{buildroot}%_docdir/qemu-x86/supported.txt
install -D -m 0644 %{SOURCE13} %{buildroot}%_docdir/qemu-s390/supported.txt
%endif
%if %{legacy_qemu_kvm}
cat > %{buildroot}%_bindir/qemu-kvm << 'EOF'
#!/bin/sh

%ifarch s390x
exec %_bindir/qemu-system-s390x -machine accel=kvm "$@"
%else
exec %_bindir/qemu-system-x86_64 -machine accel=kvm "$@"
%endif
EOF
chmod 755 %{buildroot}%_bindir/qemu-kvm
install -D -m 0644 %{SOURCE5} %{buildroot}%_mandir/man1/qemu-kvm.1.gz
%if 0%{?is_opensuse} == 0
install -d %{buildroot}%_docdir/qemu-kvm
%ifarch s390x
ln -s ../qemu-s390/supported.txt %{buildroot}%_docdir/qemu-kvm/kvm-supported.txt
%else
ln -s ../qemu-x86/supported.txt %{buildroot}%_docdir/qemu-kvm/kvm-supported.txt
%endif
%endif
%endif
%if %{kvm_available}
install -D -m 0644 %{SOURCE1} %{buildroot}/usr/lib/udev/rules.d/80-kvm.rules
%endif
install -D -p -m 0644 %{SOURCE7} %{buildroot}%{_unitdir}/qemu-ga@.service
%if 0%{?is_opensuse}
install -D -p -m 0644 %{SOURCE6} %{buildroot}%{_unitdir}/ksm.service
%endif
%ifarch s390x
install -D -m 0644 %{SOURCE2} %{buildroot}%_libexecdir/modules-load.d/kvm.conf
%endif
install -D -m 0644 %{SOURCE201} %{buildroot}%_datadir/%name/forsplits/pkg-split.txt
for X in 00 01 02 03 04 05 06 07 08 09 10 11 12 13
do
  ln -s pkg-split.txt %{buildroot}%_datadir/%name/forsplits/$X
done
%fdupes -s %{buildroot}

# ========================================================================
# (qemu alone has pre* and post* sections for itself and subpackages):

%pre
%_bindir/getent group kvm >/dev/null || %_sbindir/groupadd -r kvm
%_bindir/getent group qemu >/dev/null || %_sbindir/groupadd -r qemu
%_bindir/getent passwd qemu >/dev/null ||
  %_sbindir/useradd -r -g qemu -G kvm -d / -s /sbin/nologin \
  -c "qemu user" qemu

%if %{kvm_available}
%post
# Do not execute operations affecting host devices while running in a chroot
if [ $(stat -L -c "%i" /proc/1/root/) = $(stat -L -c "%i" /) ]; then
  setfacl --remove-all /dev/kvm &> /dev/null || :
%ifarch s390x
  if [ -c /dev/kvm ]; then
    %_bindir/chmod 0666 /dev/kvm
    %_bindir/chgrp kvm /dev/kvm
  fi
%endif
  %udev_rules_update
  %_bindir/udevadm trigger -y kvm || :
%ifarch s390x
  sysctl vm.allocate_pgste=1 || :
%endif
fi
%endif

%pre tools
%_bindir/getent group kvm >/dev/null || %_sbindir/groupadd -r kvm

%post tools
%set_permissions %_libexecdir/qemu-bridge-helper

%verifyscript tools
%verify_permissions %_libexecdir/qemu-bridge-helper

%pre guest-agent
%_bindir/getent group kvm >/dev/null || %_sbindir/groupadd -r kvm
%service_add_pre qemu-ga@.service

%post guest-agent
%service_add_post qemu-ga@.service
if [ -e /dev/virtio-ports/org.qemu.guest_agent.0 ]; then
  /usr/bin/systemctl start qemu-ga@virtio\\x2dports-org.qemu.guest_agent.0.service || :
fi

%preun guest-agent
if [ -e /dev/virtio-ports/org.qemu.guest_agent.0 ]; then
  /usr/bin/systemctl stop qemu-ga@virtio\\x2dports-org.qemu.guest_agent.0.service || :
fi

%postun guest-agent
%service_del_postun_without_restart qemu-ga@.service
if [ "$1" = "1" ] ; then
  if [ -e /dev/virtio-ports/org.qemu.guest_agent.0 ]; then
    /usr/bin/systemctl restart qemu-ga@virtio\\x2dports-org.qemu.guest_agent.0.service || :
  fi
fi

%if 0%{?is_opensuse}
%pre ksm
%service_add_pre ksm.service

%post ksm
%service_add_post ksm.service

%preun ksm
%service_del_preun ksm.service

%postun ksm
%service_del_postun ksm.service
%endif

# above section is for qemu
%endif

# ========================================================================

%files
%defattr(-, root, root)
%doc Changelog README.rst VERSION
%license COPYING COPYING.LIB LICENSE

%if "%{name}" == "qemu"
%dir %_docdir/%name/interop
%dir %_docdir/%name/interop/_static
%dir %_docdir/%name/specs
%dir %_docdir/%name/specs/_static
%_docdir/%name/interop/.buildinfo
%_docdir/%name/interop/_static/*
%_docdir/%name/interop/bitmaps.html
%_docdir/%name/interop/genindex.html
%_docdir/%name/interop/index.html
%_docdir/%name/interop/live-block-operations.html
%_docdir/%name/interop/objects.inv
%_docdir/%name/interop/pr-helper.html
%_docdir/%name/interop/search.html
%_docdir/%name/interop/searchindex.js
%_docdir/%name/interop/vhost-user.html
%_docdir/%name/specs/.buildinfo
%_docdir/%name/specs/_static/*
%_docdir/%name/specs/acpi_hw_reduced_hotplug.html
%_docdir/%name/specs/genindex.html
%_docdir/%name/specs/index.html
%_docdir/%name/specs/objects.inv
%_docdir/%name/specs/ppc-spapr-xive.html
%_docdir/%name/specs/ppc-xive.html
%_docdir/%name/specs/search.html
%_docdir/%name/specs/searchindex.js
%_docdir/%name/qemu-doc.txt
%_docdir/%name/qemu-doc.html
%_docdir/%name/qemu-qmp-ref.txt
%_docdir/%name/qemu-qmp-ref.html
%_docdir/%name/qemu-ga-ref.txt
%_docdir/%name/qemu-ga-ref.html
%_mandir/man1/%name.1.gz
%_mandir/man7/qemu-block-drivers.7.gz
%_mandir/man7/qemu-cpu-models.7.gz
%_mandir/man7/qemu-qmp-ref.7.gz
%_mandir/man7/qemu-ga-ref.7.gz
%dir %_datadir/%name
%dir %_datadir/%name/firmware
%dir %_datadir/%name/forsplits
%_datadir/%name/forsplits/pkg-split.txt
%_datadir/%name/forsplits/00
%_datadir/%name/forsplits/01
%_datadir/%name/forsplits/02
%_datadir/%name/forsplits/03
%_datadir/%name/forsplits/04
%_datadir/%name/forsplits/05
%_datadir/%name/forsplits/06
%_datadir/%name/forsplits/07
%_datadir/%name/forsplits/08
%_datadir/%name/forsplits/09
%_datadir/%name/forsplits/10
%_datadir/%name/forsplits/11
%_datadir/%name/forsplits/12
%_datadir/%name/forsplits/13
%_datadir/%name/keymaps
%_datadir/%name/qemu-nsis.bmp
%_datadir/%name/trace-events-all
%dir %_sysconfdir/%name
%dir %_sysconfdir/%name/firmware
%_datadir/%name/qemu-ifup
%dir %_libexecdir/supportconfig
%dir %_libexecdir/supportconfig/plugins
%_libexecdir/supportconfig/plugins/%name
%if %{kvm_available}
/usr/lib/udev/rules.d/80-kvm.rules
%ifarch s390x
%_libexecdir/modules-load.d/kvm.conf
%endif
%endif
%dir %_datadir/icons/hicolor
%dir %_datadir/icons/hicolor/*/
%dir %_datadir/icons/hicolor/*/apps
%_datadir/icons/hicolor/16x16/apps/qemu.png
%_datadir/icons/hicolor/24x24/apps/qemu.png
%_datadir/icons/hicolor/32x32/apps/qemu.bmp
%_datadir/icons/hicolor/32x32/apps/qemu.png
%_datadir/icons/hicolor/48x48/apps/qemu.png
%_datadir/icons/hicolor/64x64/apps/qemu.png
%_datadir/icons/hicolor/128x128/apps/qemu.png
%_datadir/icons/hicolor/256x256/apps/qemu.png
%_datadir/icons/hicolor/512x512/apps/qemu.png
%_datadir/icons/hicolor/scalable/apps/qemu.svg
%_datadir/applications/qemu.desktop

%files x86
%defattr(-, root, root)
%_bindir/qemu-system-i386
%_bindir/qemu-system-x86_64
%_datadir/%name/kvmvapic.bin
%_datadir/%name/linuxboot.bin
%_datadir/%name/linuxboot_dma.bin
%_datadir/%name/multiboot.bin
%_datadir/%name/pvh.bin
%if 0%{?is_opensuse} == 0
%dir %_docdir/qemu-x86
%_docdir/qemu-x86/supported.txt
%endif

%files ppc
%defattr(-, root, root)
%_bindir/qemu-system-ppc
%_bindir/qemu-system-ppc64
%_datadir/%name/bamboo.dtb
%_datadir/%name/canyonlands.dtb
%_datadir/%name/openbios-ppc
%_datadir/%name/ppc_rom.bin
%_datadir/%name/qemu_vga.ndrv
%_datadir/%name/skiboot.lid
%_datadir/%name/slof.bin
%_datadir/%name/u-boot.e500
%_datadir/%name/u-boot-sam460-20100605.bin
%if 0%{?is_opensuse} == 0
%dir %_docdir/qemu-ppc
%_docdir/qemu-ppc/supported.txt
%endif

%files s390
%defattr(-, root, root)
%_bindir/qemu-system-s390x
%_datadir/%name/s390-ccw.img
%_datadir/%name/s390-netboot.img
%if 0%{?is_opensuse} == 0
%dir %_docdir/qemu-s390
%_docdir/qemu-s390/supported.txt
%endif

%files arm
%defattr(-, root, root)
%_bindir/qemu-system-arm
%_bindir/qemu-system-aarch64
%if 0%{?is_opensuse} == 0
%dir %_docdir/qemu-arm
%_docdir/qemu-arm/supported.txt
%endif

%files extra
%defattr(-, root, root)
%_bindir/qemu-system-alpha
%_bindir/qemu-system-cris
%_bindir/qemu-system-hppa
%_bindir/qemu-system-lm32
%_bindir/qemu-system-m68k
%_bindir/qemu-system-microblaze
%_bindir/qemu-system-microblazeel
%_bindir/qemu-system-mips
%_bindir/qemu-system-mipsel
%_bindir/qemu-system-mips64
%_bindir/qemu-system-mips64el
%_bindir/qemu-system-moxie
%_bindir/qemu-system-nios2
%_bindir/qemu-system-or1k
%_bindir/qemu-system-riscv32
%_bindir/qemu-system-riscv64
%_bindir/qemu-system-sh4
%_bindir/qemu-system-sh4eb
%_bindir/qemu-system-sparc
%_bindir/qemu-system-sparc64
%_bindir/qemu-system-tricore
%_bindir/qemu-system-unicore32
%_bindir/qemu-system-xtensa
%_bindir/qemu-system-xtensaeb
%_datadir/%name/hppa-firmware.img
%_datadir/%name/opensbi-riscv32-virt-fw_jump.bin
%_datadir/%name/opensbi-riscv64-sifive_u-fw_jump.bin
%_datadir/%name/opensbi-riscv64-virt-fw_jump.bin
%_datadir/%name/openbios-sparc32
%_datadir/%name/openbios-sparc64
%_datadir/%name/palcode-clipper
%_datadir/%name/petalogix-ml605.dtb
%_datadir/%name/petalogix-s3adsp1800.dtb
%_datadir/%name/QEMU,cgthree.bin
%_datadir/%name/QEMU,tcx.bin

%if %{legacy_qemu_kvm}
%files kvm
%defattr(-,root,root)
%_bindir/qemu-kvm
%_mandir/man1/qemu-kvm.1.gz
%if 0%{?is_opensuse} == 0
%dir %_docdir/qemu-kvm
%_docdir/qemu-kvm/kvm-supported.txt
%endif
%endif

%files block-curl
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-curl.so

%files block-dmg
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-dmg-bz2.so
%if 0%{?is_opensuse}
%_libdir/%name/block-dmg-lzfse.so
%endif

%if 0%{?with_glusterfs}
%files block-gluster
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-gluster.so
%endif

%files block-iscsi
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-iscsi.so

%if 0%{?is_opensuse}
%files block-nfs
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-nfs.so
%endif

%if 0%{?with_rbd}
%files block-rbd
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-rbd.so
%endif

%files block-ssh
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/block-ssh.so

%files ui-curses
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/ui-curses.so

%files ui-gtk
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/ui-gtk.so

%if 0%{?is_opensuse}
%files ui-sdl
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/ui-sdl.so
%endif

%files ui-spice-app
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/ui-spice-app.so

%files audio-alsa
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/audio-alsa.so

%files audio-pa
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/audio-pa.so

%if 0%{?is_opensuse}
%files audio-sdl
%defattr(-, root, root)
%dir %_libdir/%name
%_libdir/%name/audio-sdl.so
%endif

%files lang -f %mybuilddir/%name.lang
%defattr(-, root, root)

%ifarch %{build_rom_arch}
%files seabios
%defattr(-, root, root)
%dir %_datadir/%name
%_datadir/%name/bios.bin
%_datadir/%name/bios-256k.bin
%_datadir/%name/firmware/50-seabios-256k.json
%_datadir/%name/firmware/60-seabios-128k.json

%files microvm
%defattr(-, root, root)
%dir %_datadir/%name
%_datadir/%name/bios-microvm.bin

%files vgabios
%defattr(-, root, root)
%dir %_datadir/%name
%_datadir/%name/vgabios.bin
%_datadir/%name/vgabios-ati.bin
%_datadir/%name/vgabios-bochs-display.bin
%_datadir/%name/vgabios-cirrus.bin
%_datadir/%name/vgabios-qxl.bin
%_datadir/%name/vgabios-ramfb.bin
%_datadir/%name/vgabios-stdvga.bin
%_datadir/%name/vgabios-virtio.bin
%_datadir/%name/vgabios-vmware.bin

%files sgabios
%defattr(-, root, root)
%dir %_datadir/%name
%_datadir/%name/sgabios.bin

%files ipxe
%defattr(-, root, root)
%dir %_datadir/%name
%_datadir/%name/efi-e1000.rom
%_datadir/%name/efi-e1000e.rom
%_datadir/%name/efi-eepro100.rom
%_datadir/%name/efi-ne2k_pci.rom
%_datadir/%name/efi-pcnet.rom
%_datadir/%name/efi-rtl8139.rom
%_datadir/%name/efi-virtio.rom
%_datadir/%name/efi-vmxnet3.rom
%_datadir/%name/pxe-e1000.rom
%_datadir/%name/pxe-eepro100.rom
%_datadir/%name/pxe-ne2k_pci.rom
%_datadir/%name/pxe-pcnet.rom
%_datadir/%name/pxe-rtl8139.rom
%_datadir/%name/pxe-virtio.rom

%if %{provide_edk2_firmware}

%files edk2
%dir %_datadir/%name
%dir %_datadir/%name/firmware
%_datadir/%name/edk2-aarch64-code.fd
%_datadir/%name/edk2-arm-code.fd
%_datadir/%name/edk2-arm-vars.fd
%_datadir/%name/edk2-i386-code.fd
%_datadir/%name/edk2-i386-secure-code.fd
%_datadir/%name/edk2-i386-vars.fd
%_datadir/%name/edk2-licenses.txt
%_datadir/%name/edk2-x86_64-code.fd
%_datadir/%name/edk2-x86_64-secure-code.fd
%_datadir/%name/firmware/50-edk2-i386-secure.json
%_datadir/%name/firmware/50-edk2-x86_64-secure.json
%_datadir/%name/firmware/60-edk2-aarch64.json
%_datadir/%name/firmware/60-edk2-arm.json
%_datadir/%name/firmware/60-edk2-i386.json
%_datadir/%name/firmware/60-edk2-x86_64.json
%endif
%endif

%files vhost-user-gpu
%defattr(-, root, root)
%_libexecdir/vhost-user-gpu
%_docdir/%name/interop/vhost-user-gpu.html
%dir %_datadir/%name/vhost-user
%_datadir/%name/vhost-user/50-qemu-gpu.json

%files tools
%defattr(-, root, root)
%_mandir/man1/qemu-img.1.gz
%_mandir/man1/virtfs-proxy-helper.1.gz
%_mandir/man8/qemu-nbd.8.gz
%_bindir/elf2dmp
%_bindir/ivshmem-client
%_bindir/ivshmem-server
%_bindir/qemu-edid
%_bindir/qemu-img
%_bindir/qemu-io
%_bindir/qemu-keymap
%_bindir/qemu-nbd
%_bindir/qemu-pr-helper
%_bindir/virtfs-proxy-helper
%verify(not mode) %attr(4750,root,kvm) %_libexecdir/qemu-bridge-helper
%dir %_sysconfdir/%name
%config %_sysconfdir/%name/bridge.conf
%_bindir/analyze-migration.py
%_bindir/vmstate-static-checker.py

%files guest-agent
%defattr(-, root, root)
%dir %_docdir/%name/interop
%_docdir/%name/interop/qemu-ga.html
%_mandir/man8/qemu-ga.8.gz
%attr(0755,root,kvm) %_bindir/qemu-ga
%{_unitdir}/qemu-ga@.service
/usr/lib/udev/rules.d/80-qemu-ga.rules

%if 0%{?is_opensuse}
%files ksm
%defattr(-, root, root)
%{_unitdir}/ksm.service
%endif

# above section is for qemu
%endif
# ------------------------------------------------------------------------
%if "%{name}" == "qemu-linux-user"

%_bindir/qemu-aarch64
%_bindir/qemu-aarch64_be
%_bindir/qemu-alpha
%_bindir/qemu-arm
%_bindir/qemu-armeb
%_bindir/qemu-cris
%_bindir/qemu-hppa
%_bindir/qemu-i386
%_bindir/qemu-m68k
%_bindir/qemu-microblaze
%_bindir/qemu-microblazeel
%_bindir/qemu-mips
%_bindir/qemu-mipsel
%_bindir/qemu-mipsn32
%_bindir/qemu-mipsn32el
%_bindir/qemu-mips64
%_bindir/qemu-mips64el
%_bindir/qemu-nios2
%_bindir/qemu-or1k
%_bindir/qemu-ppc64
%_bindir/qemu-ppc64abi32
%_bindir/qemu-ppc64le
%_bindir/qemu-ppc
%_bindir/qemu-riscv32
%_bindir/qemu-riscv64
%_bindir/qemu-s390x
%_bindir/qemu-sh4
%_bindir/qemu-sh4eb
%_bindir/qemu-sparc32plus
%_bindir/qemu-sparc64
%_bindir/qemu-sparc
%_bindir/qemu-tilegx
%_bindir/qemu-x86_64
%_bindir/qemu-xtensa
%_bindir/qemu-xtensaeb
%_bindir/qemu-*-binfmt
%_sbindir/qemu-binfmt-conf.sh

%endif
# ------------------------------------------------------------------------
%if "%{name}" == "qemu-testsuite"

%_datadir/qemu/check-report.tap

%endif

%changelog
* Fri Aug  6 2021 José Ricardo Ziviani <jose.ziviani@suse.com>
- usbredir: free call on invalid pointer in bufp_alloc
  (bsc#1189145, CVE-2021-3682)
  usbredir-fix-free-call.patch
* Fri Jul 30 2021 José Ricardo Ziviani <jose.ziviani@suse.com>
- NULL pointer dereference in ESP
  (bsc#1180433, CVE-2020-35504)
  (bsc#1180434, CVE-2020-35505)
  (bsc#1180435, CVE-2020-35506)
  esp-always-check-current_req-is-not-NULL.patch
  esp-don-t-reset-async_len-directly-in-es.patch
  esp-ensure-cmdfifo-is-not-empty-and-curr.patch
  esp-ensure-that-do_cmd-is-set-to-zero-be.patch
- NULL pointer dereference issue in megasas-gen2 host bus adapter
  (bsc#1180432, CVE-2020-35503)
  hw-scsi-megasas-check-for-NULL-frame-in-.patch
- eepro100: stack overflow via infinite recursion
  (bsc#1182651, CVE-2021-20255)
  net-eepro100-validate-various-address-va.patch
- usb: unbounded stack allocation in usbredir
  (bsc#1186012, CVE-2021-3527)
  hw-usb-host-stub-Remove-unused-header.patch
  usb-hid-avoid-dynamic-stack-allocation.patch
  usb-limit-combined-packets-to-1-MiB-CVE-.patch
  usb-mtp-avoid-dynamic-stack-allocation.patch
  usb-redir-avoid-dynamic-stack-allocation.patch
* Wed Jul  7 2021 José Ricardo Ziviani <jose.ziviani@suse.com>
- Fix for bsc#1187364, CVE-2021-3592 and
  Fix for bsc#1187367, CVE-2021-3594 and
  Fix for bsc#1187365, CVE-2021-3593 and
  Fix for bsc#1187366, CVE-2021-3595
  Add-mtod_check.patch
  bootp-check-bootp_input-buffer-size.patch
  bootp-limit-vendor-specific-area-to-inpu.patch
  dhcp-Always-send-DHCP_OPT_LEN-bytes-in-o.patch
  tftp-check-tftp_input-buffer-size.patch
  tftp-introduce-a-header-structure.patch
  udp-check-upd_input-buffer-size.patch
  upd6-check-udp6_input-buffer-size.patch
* Mon Jul  5 2021 José Ricardo Ziviani <jose.ziviani@suse.com>
- Fix possible mremap overflow in the pvrdma
  (CVE-2021-3582, bsc#1187499)
  hw-rdma-Fix-possible-mremap-overflow-in-.patch
- Ensure correct input on ring init
  (CVE-2021-3607, bsc#1187539)
  pvrdma-Ensure-correct-input-on-ring-init.patch
- Fix the ring init error flow
  (CVE-2021-3608, bsc#1187538)
  pvrdma-Fix-the-ring-init-error-flow-CVE-.patch
* Mon Jul  5 2021 Al Cho <acho@suse.com>
  * Fix intel-hda segmentation fault due to stack overflow
  (CVE-2021-3611, bsc#1187529)
  qom-code-hardening-have-bound-checking-w.patch
* Mon Jun 21 2021 Lin Ma <lma@suse.com>
- Fix testsuite error (bsc#1184574)
  * Patches added:
  device-plug-test-use-qtest_qmp-to-send-t.patch
  qemu-iotests-qtest-rewrite-test-067-as-a.patch
  qtest-check-that-drives-are-really-appea.patch
  qtest-Reintroduce-qtest_qmp_receive-with.patch
  qtest-remove-qtest_qmp_receive_success.patch
  qtest-rename-qtest_qmp_receive-to-qtest_.patch
  qtest-switch-users-back-to-qtest_qmp_rec.patch
  tests-add-migration-helpers-unit.patch
* Thu Jun 10 2021 Lin Ma <lma@suse.com>
- Fix qemu crash with iothread when block commit after snapshot (bsc#1187013)
  * Patches added:
  blockjob-Fix-crash-with-IOthread-when-bl.patch
* Mon Jun  7 2021 José Ricardo Ziviani <jose.ziviani@suse.com>
- Fix out-of-bounds write in virgl_cmd_get_capset
  CVE-2021-3546 bsc#1185981
  vhost-user-gpu-abstract-vg_cleanup_mappi.patch
- Fix memory leaks found in the virtio vhost-user GPU device
  CVE-2021-3544 bsc#1186010
  vhost-user-gpu-fix-leak-in-virgl_cmd_res.patch
  vhost-user-gpu-fix-leak-in-virgl_resourc.patch
  vhost-user-gpu-fix-memory-disclosure-in-.patch
  vhost-user-gpu-fix-memory-leak-in-vg_res.patch
  vhost-user-gpu-fix-memory-leak-while-cal.patch
  vhost-user-gpu-fix-OOB-write-in-virgl_cm.patch
- Fix information disclosure due to uninitialized memory read
  CVE-2021-3545 bsc#1185990
  vhost-user-gpu-fix-resource-leak-in-vg_r.patch
* Thu Jun  3 2021 Lin Ma <lma@suse.com>
- Fix qemu hang while cancelling migrating hugepage vm (bsc#1185591)
  * Patches added:
  migration-migration.c-Fix-hang-in-ram_sa.patch
* Thu Jun  3 2021 Lin Ma <lma@suse.com>
- Use RCU to avoid race during scsi hotplug/hotunplug (bsc#1184574)
  * Patches added:
  device-core-use-atomic_set-on-.realized-.patch
  device_core-use-drain_call_rcu-in-in-qmp.patch
  device-core-use-RCU-for-list-of-children.patch
  qdev-add-check-if-address-free-callback-.patch
  qom-make-object_ref-unref-use-a-void-ins.patch
  rcu-Implement-drain_call_rcu.patch
  scsi-scsi_bus-Add-scsi_device_get.patch
  scsi-scsi_bus-fix-races-in-REPORT-LUNS.patch
  scsi-scsi-bus-scsi_device_find-don-t-ret.patch
  scsi-scsi_bus-switch-search-direction-in.patch
  scsi-switch-to-bus-check_address.patch
  virtio-scsi-use-scsi_device_get.patch
  xen-block-Fix-removal-of-backend-instanc.patch
* Tue May 25 2021 José Ricardo Ziviani <jose.ziviani@suse.com>
- Fix out-of-bounds access issue while doing multi block SDMA
  (CVE-2020-25085, bsc#1176681)
  hw-sd-sdhci-Fix-DMA-Transfer-Block-Size-.patch
* Mon May 24 2021 Al Cho <acho@suse.com>
- QEMU BIOS fails to read stage2 loader (on s390x)(bsc#1186290)
  * Patches added:
  pc-bios-s390-ccw-don-t-try-to-read-the-n.patch
* Fri May  7 2021 José Ricardo Ziviani <jose.ziviani@suse.com>
- Fix out-of-bounds read information disclosure in icmp6_send_echoreply
  (CVE-2020-10756, bsc#1172380)
  Drop-bogus-IPv6-messages.patch
* Thu May  6 2021 Bruce Rogers <brogers@suse.com>
- For the record, these issues are fixed in this package already.
  Most are alternate references to previously mentioned issues:
  (CVE-2019-15890, bsc#1149813, CVE-2020-8608, bsc#1163019,
  CVE-2020-14364, bsc#1175534, CVE-2020-25707, bsc#1178683,
  CVE-2020-25723, bsc#1178935, CVE-2020-29130, bsc#1179477,
  CVE-2020-29129, bsc#1179484, CVE-2021-20257, bsc#1182846,
  CVE-2021-3419, bsc#1182975)
* Thu Apr 29 2021 Dario Faggioli <dfaggioli@suse.com>
- Implement jsc#SLE-17785
  Host CPU microcode revision will be visible inside VMs (if
  the proper CPU-model is used):
  target-i386-add-a-ucode-rev-property.patch
  target-i386-check-for-availability-of-MS.patch
  target-i386-enable-monitor-and-ucode-rev.patch
  target-i386-fix-TCG-UCODE_REV-access.patch
  target-i386-kvm-initialize-microcode-rev.patch
* Tue Apr 20 2021 Bruce Rogers <brogers@suse.com>
- Fix issue where s390 guest fails to find zipl boot menu index
  (bsc#1183979)
  pc-bios-s390-ccw-break-loop-if-a-null-bl.patch
  pc-bios-s390-ccw-fix-off-by-one-error.patch
* Fri Apr 16 2021 Bruce Rogers <brogers@suse.com>
- Fix a case of PIIX southbridge state data not being migrated.
  This change requires the equivalent change present in the target
  qemu of a live migration (patch is also queued for the SLE-15-SP3
  qemu)
  hw-isa-piix4-Migrate-Reset-Control-Regis.patch
* Thu Apr 15 2021 Bruce Rogers <brogers@suse.com>
- v6.0.0 qemu is about to be released. Add comments to the in-
  package support documents (supported.<arch>.txt) about the new
  deprecations as of that release as an early head's up for qemu
  users. These deprecations include these command-line options:
  - M option: kernel-irqchip=off
  - chardev tty
  - chardev paraport
  - enable-fips
  - writeconfig
  - spice password=string
* Wed Mar 31 2021 Bruce Rogers <brogers@suse.com>
- Fix OOB access in sm501 device emulation (CVE-2020-12829, bsc#1172385)
  sm501-Clean-up-local-variables-in-sm501_.patch
  sm501-Convert-printf-abort-to-qemu_log_m.patch
  sm501-Replace-hand-written-implementatio.patch
  sm501-Shorten-long-variable-names-in-sm5.patch
  sm501-Use-BIT-x-macro-to-shorten-constan.patch
- Fix use-after-free in usb xhci packet handling (CVE-2020-25723,
  bsc#1178934)
  hw-xhci-check-return-value-of-usb_packet.patch
- Fix use-after-free in usb ehci packet handling (CVE-2020-25084,
  bsc#1176673)
  hw-ehci-check-return-value-of-usb_packet.patch
- Fix infinite loop (DoS) in usb hcd-ohci emulation
  (CVE-2020-25625, bsc#1176684)
  hw-usb-hcd-ohci-check-for-processed-TD-b.patch
- Fix OOB access in usb hcd-ohci emulation (CVE-2020-25624,
  bsc#1176682)
  hw-usb-hcd-ohci-check-len-and-frame_numb.patch
- Fix guest triggerable assert in shared network
  handling code (CVE-2020-27617, bsc#1178174)
  net-remove-an-assert-call-in-eth_get_gso.patch
- Fix infinite loop (DoS) in e1000e device emulation
  (CVE-2020-28916, bsc#1179468)
  hw-net-e1000e-advance-desc_offset-in-cas.patch
- Fix OOB access in atapi emulation (CVE-2020-29443, bsc#1181108)
  ide-atapi-assert-that-the-buffer-pointer.patch
- Fix heap overflow in MSIx emulation (CVE-2020-27821, bsc#1179686)
  memory-clamp-cached-translation-in-case-.patch
- Fix null pointer deref. (DoS) in mmio ops (CVE-2020-15469,
  bsc#1173612)
  hw-pci-host-add-pci-intack-write-method.patch
  imx7-ccm-add-digprog-mmio-write-method.patch
  nvram-add-nrf51_soc-flash-read-method.patch
  pci-host-designware-add-pcie-msi-read-me.patch
  prep-add-ppc-parity-write-method.patch
  spapr_pci-add-spapr-msi-read-method.patch
  tz-ppc-add-dummy-read-write-methods.patch
  vfio-add-quirk-device-write-method.patch
- Fix infinite loop (DoS) in e1000 device emulation
  (CVE-2021-20257, bsc#1182577)
  e1000-fail-early-for-evil-descriptor.patch
- Fix OOB access (stack overflow) in rtl8139 NIC emulation
  (CVE-2021-3416, bsc#1182968)
  net-introduce-qemu_receive_packet.patch
  rtl8139-switch-to-use-qemu_receive_packe.patch
- Fix OOB access (stack overflow) in other NIC emulations
  (CVE-2021-3416)
  cadence_gem-switch-to-use-qemu_receive_p.patch
  dp8393x-switch-to-use-qemu_receive_packe.patch
  e1000-switch-to-use-qemu_receive_packet-.patch
  lan9118-switch-to-use-qemu_receive_packe.patch
  pcnet-switch-to-use-qemu_receive_packet-.patch
  sungem-switch-to-use-qemu_receive_packet.patch
  tx_pkt-switch-to-use-qemu_receive_packet.patch
- Fix OOB access in ati-vga emulation (CVE-2020-27616, bsc#1178400)
  ati-check-x-y-display-parameter-values.patch
- Fix OOB access in SLIRP ARP/NCSI packet processing
  (CVE-2020-29129, bsc#1179466, CVE-2020-29130, bsc#1179467)
  slirp-check-pkt_len-before-reading-proto.patch
- Fix package scripts to not use hard coded paths for temporary
  working directories and log files (bsc#1182425)
- Add split-provides through forsplits/13 to cover updates of
  SLE15-SP2 to SLE15-SP3, and openSUSE equivalents (boo#1184064)
* Tue Mar  9 2021 Bruce Rogers <brogers@suse.com>
- Added a few more usability improvements for our git packaging
  workflow
* Fri Feb 12 2021 Bruce Rogers <brogers@suse.com>
- Fix potential privilege escalation in virtfs (CVE-2021-20181
  bsc#1182137)
  9pfs-Fully-restart-unreclaim-loop-CVE-20.patch
- Fix OOB access in iscsi (CVE-2020-11947 bsc#1180523)
  block-iscsi-fix-heap-buffer-overflow-in-.patch
- Fix OOB access in vmxnet3 emulation (CVE-2021-20203 bsc#1181639)
  net-vmxnet3-validate-configuration-value.patch
* Tue Feb  9 2021 Bruce Rogers <brogers@suse.com>
- Fix OOB access in ARM interrupt handling (CVE-2021-20221
  bsc#1181933)
  hw-intc-arm_gic-Fix-interrupt-ID-in-GICD.patch
* Tue Feb  9 2021 Bruce Rogers <brogers@suse.com>
- Apply fixes to qemu scsi passthrough with respect to timeout and
  error conditions, including using more correct status codes. Add
  more qemu tracing which helped track down these issues
  (bsc#1178049)
  scsi-add-tracing-for-SG_IO-commands.patch
  scsi-disk-fold-SG_IO-errors-back-into-re.patch
  scsi-disk-set-default-I-O-timeout-to-30-.patch
  scsi-disk-trace-rw-errors.patch
  scsi-generic-check-for-additional-SG_IO-.patch
  scsi-make-io_timeout-settable.patch
  virtio-scsi-change-DID-TIMEOUT-handling.patch
  virtio-scsi-trace-events.patch
  virtio-scsi-translate-SG_IO-host-status.patch
* Thu Jan 28 2021 Lin Ma <lma@suse.com>
- Use '%%service_del_postun_without_restart' instead of '%%service_del_postun'
  to avoid "Failed to try-restart qemu-ga@.service" error while updating the
  qemu-guest-agent. (bsc#1178565)
* Tue Jan 19 2021 Bruce Rogers <brogers@suse.com>
- Re-sort patches back into upstream commit order, followed by our
  private patches
- Minor spec file fixes and changes
* Tue Jan 19 2021 Liang Yan <lyan@suse.com>
- Revert meson build file back to Make.obj (bsc#1179719)
  Revert-meson-build-file-back-to-Make.obj.patch
* Mon Jan 18 2021 Liang Yan <lyan@suse.com>
- Fix vfio-pci device on s390 enters error state
  (bsc#1179717 bsc#1179719)
  linux-headers-sync-to-5.9-rc4.patch
  linux-headers-sync-to-5.9-rc7.patch
  linux-headers-update-against-5.10-rc1.patch
  linux-headers-Update-against-Linux-5.5-1.patch
  linux-headers-Update-against-Linux-5.5-r.patch
  linux-headers-update-against-Linux-5.6-r.patch
  linux-headers-update-against-Linux-5.7-r.patch
  Linux-headers-update-against-Linux-5.8-r.patch
  s390x-fix-build-for-without-default-devi.patch
  s390x-pci-Add-routine-to-get-the-vfio-dm.patch
  s390x-pci-Honor-DMA-limits-set-by-vfio.patch
  s390x-s390-virtio-ccw-Reset-PCI-devices-.patch
  vfio-Create-shared-routine-for-scanning-.patch
  vfio-Find-DMA-available-capability.patch
  virtio-net-fix-rsc_ext-compat-handling.patch
* Thu Sep 17 2020 Bruce Rogers <brogers@suse.com>
- Change qemu-x86 packaging relationship with qemu-microvm from
  Requires to Recommends
* Thu Sep 17 2020 Bruce Rogers <brogers@suse.com>
- Fix OOB access while processing USB packets (CVE-2020-14364
  bsc#1175441  bsc#1176494)
  usb-fix-setup_len-init-CVE-2020-14364.patch
- Fix DoS in packet processing of various emulated NICs
  (CVE-2020-16092 bsc#1174641)
  hw-net-net_tx_pkt-fix-assertion-failure-.patch
- Fix buffer overflow in the XGMAC device (CVE-2020-15863
  bsc#1174386)
  hw-net-xgmac-Fix-buffer-overflow-in-xgma.patch
- Note: v4.2.1 update included fix for CVE-2020-24352 bsc#1175370
* Wed Sep 16 2020 Bruce Rogers <brogers@suse.com>
- Add infrastructure to do package splits when split-off package
  isn't required and doesn't (otherwise) include any previously
  installed files. More recent versions of qemu have split out
  non-essential functionality into loadable modules, so we need
  our packaging infrastructure to be prepared to handle that.
* Tue Sep 15 2020 Liang Yan <lyan@suse.com>
- Allow to IPL secure guests with -no-reboot (bsc#1174863)
  s390x-protvirt-allow-to-IPL-secure-guest.patch
* Fri Jun 26 2020 Bruce Rogers <brogers@suse.com>
- Update to v4.2.1, a stable, bug-fix-only release
  * Patches dropped (subsumed by stable update):
  arm-arm-powerctl-set-NSACR.-CP11-CP10-bi.patch
  ati-vga-check-mm_index-before-recursive-.patch
  ati-vga-Fix-checks-in-ati_2d_blt-to-avoi.patch
  audio-oss-fix-buffer-pos-calculation.patch
  backup-top-Begin-drain-earlier.patch
  blkdebug-Allow-taking-unsharing-permissi.patch
  block-Activate-recursively-even-for-alre.patch
  block-Add-bdrv_qapi_perm_to_blk_perm.patch
  block-Avoid-memleak-on-qcow2-image-info-.patch
  block-backup-fix-memory-leak-in-bdrv_bac.patch
  block-backup-top-fix-failure-path.patch
  block-bdrv_set_backing_bs-fix-use-after-.patch
  block-block-copy-fix-progress-calculatio.patch
  block-Call-attention-to-truncation-of-lo.patch
  block-fix-crash-on-zero-length-unaligned.patch
  block-fix-memleaks-in-bdrv_refresh_filen.patch
  block-Fix-VM-size-field-width-in-snapsho.patch
  block-io-fix-bdrv_co_do_copy_on_readv.patch
  block-nbd-extract-the-common-cleanup-cod.patch
  block-nbd-fix-memory-leak-in-nbd_open.patch
  block-qcow2-threads-fix-qcow2_decompress.patch
  compat-disable-edid-on-correct-virtio-gp.patch
  display-bochs-display-fix-memory-leak.patch
  es1370-check-total-frame-count-against-c.patch
  Fix-double-free-issue-in-qemu_set_log_fi.patch
  Fix-use-afte-free-in-ip_reass-CVE-2020-1.patch
  hmp-vnc-Fix-info-vnc-list-leak.patch
  hw-arm-cubieboard-use-ARM-Cortex-A8-as-t.patch
  hw-arm-smmuv3-Align-stream-table-base-ad.patch
  hw-arm-smmuv3-Apply-address-mask-to-line.patch
  hw-arm-smmuv3-Check-stream-IDs-against-a.patch
  hw-arm-smmuv3-Correct-SMMU_BASE_ADDR_MAS.patch
  hw-arm-smmuv3-Report-F_STE_FETCH-fault-a.patch
  hw-arm-smmuv3-Use-correct-bit-positions-.patch
  hw-i386-pc-fix-regression-in-parsing-vga.patch
  hw-intc-arm_gicv3_kvm-Stop-wrongly-progr.patch
  i386-Resolve-CPU-models-to-v1-by-default.patch
  intel_iommu-a-fix-to-vtd_find_as_from_bu.patch
  iotests-add-test-for-backup-top-failure-.patch
  iotests-Fix-IMGOPTSSYNTAX-for-nbd.patch
  iotests-Fix-nonportable-use-of-od-endian.patch
  iscsi-Cap-block-count-from-GET-LBA-STATU.patch
  job-refactor-progress-to-separate-object.patch
  m68k-Fix-regression-causing-Single-Step-.patch
  migration-colo-fix-use-after-free-of-loc.patch
  migration-ram-fix-use-after-free-of-loca.patch
  migration-Rate-limit-inside-host-pages.patch
  migration-test-ppc64-fix-FORTH-test-prog.patch
  nbd-server-Avoid-long-error-message-asse.patch
  net-tulip-check-frame-size-and-r-w-data-.patch
  numa-properly-check-if-numa-is-supported.patch
  pc-bios-s390x-Save-iplb-location-in-lowc.patch
  ppc-ppc405_boards-Remove-unnecessary-NUL.patch
  qcow2-bitmaps-fix-qcow2_can_store_new_di.patch
  qcow2-List-autoclear-bit-names-in-header.patch
  Revert-qemu-options.hx-Update-for-reboot.patch
  Revert-vnc-allow-fall-back-to-RAW-encodi.patch
  runstate-ignore-finishmigrate-prelaunch-.patch
  s390-sclp-improve-special-wait-psw-logic.patch
  s390x-adapter-routes-error-handling.patch
  scsi-qemu-pr-helper-Fix-out-of-bounds-ac.patch
  sheepdog-Consistently-set-bdrv_has_zero_.patch
  slirp-use-correct-size-while-emulating-c.patch
  slirp-use-correct-size-while-emulating-I.patch
  spapr-Fix-failure-path-for-attempting-to.patch
  target-arm-Correct-definition-of-PMCRDP.patch
  target-arm-Fix-PAuth-sbox-functions.patch
  target-arm-fix-TCG-leak-for-fcvt-half-do.patch
  target-arm-monitor-query-cpu-model-expan.patch
  target-arm-Return-correct-IL-bit-in-merg.patch
  target-arm-Set-ISSIs16Bit-in-make_issinf.patch
  target-i386-do-not-set-unsupported-VMX-s.patch
  target-i386-kvm-initialize-feature-MSRs-.patch
  target-ppc-Fix-rlwinm-on-ppc64.patch
  target-xtensa-fix-pasto-in-pfwait.r-opco.patch
  tcg-i386-Fix-INDEX_op_dup2_vec.patch
  tcg-mips-mips-sync-encode-error.patch
  tcp_emu-Fix-oob-access.patch
  tcp_emu-fix-unsafe-snprintf-usages.patch
  tpm-ppi-page-align-PPI-RAM.patch
  util-add-slirp_fmt-helpers.patch
  vhost-user-blk-delete-virtioqueues-in-un.patch
  vhost-user-gpu-Drop-trailing-json-comma.patch
  vhost-user-gpu-Release-memory-returned-b.patch
  virtio-add-ability-to-delete-vq-through-.patch
  virtio-blk-fix-out-of-bounds-access-to-b.patch
  virtio-crypto-do-delete-ctrl_vq-in-virti.patch
  virtio-mmio-update-queue-size-on-guest-w.patch
  virtio-net-delete-also-control-queue-whe.patch
  virtio-pmem-do-delete-rq_vq-in-virtio_pm.patch
  virtio-update-queue-size-on-guest-write.patch
  vpc-Don-t-round-up-already-aligned-BAT-s.patch
  xen-block-Fix-double-qlist-remove-and-re.patch
* Thu Jun 25 2020 Bruce Rogers <brogers@suse.com>
- Fix DoS possibility in Network Block Device (nbd) support
  infrastructure (CVE-2020-10761 bsc#1172710)
  block-Call-attention-to-truncation-of-lo.patch
  nbd-server-Avoid-long-error-message-asse.patch
- Fix DoS possibility in ati-vga emulation (CVE-2020-13800
  bsc#1172495)
  ati-vga-check-mm_index-before-recursive-.patch
- Fix null pointer dereference possibility (DoS) in MegaRAID SAS
  8708EM2 emulation (CVE-2020-13659 bsc#1172386)
  exec-set-map-length-to-zero-when-returni.patch
- Fix OOB access possibility in MegaRAID SAS 8708EM2 emulation
  (CVE-2020-13362 bsc#1172383)
  megasas-use-unsigned-type-for-reply_queu.patch
- Fix OOB access possibility in ES1370 audio device emulation
  (CVE-2020-13361 bsc#1172384)
  es1370-check-total-frame-count-against-c.patch
- Fix vgabios issue for cirrus graphivs emulation, which
  effectively downgraded it to standard VGA behavior
  vga-fix-cirrus-bios.patch
- Remove problematic SMBus ACPI entry - causes problems for
  Windows 10 since it wants a (non-existent) driver for it
  i386-acpi-Remove-_HID-from-the-SMBus-ACP.patch
* Tue May 26 2020 Bruce Rogers <brogers@suse.com>
- Fix segfault when doing HMP wavcapture (boo#1171712)
  audio-fix-wavcapture-segfault.patch
* Fri May 15 2020 Bruce Rogers <brogers@suse.com>
- Note: a stable patch we've already included addresses bsc#1167816
  migration-Rate-limit-inside-host-pages.patch
* Thu Apr 30 2020 Bruce Rogers <brogers@suse.com>
- Fix use after free in slirp networking code (CVE-2020-1983
  bsc#1170940)
  Fix-use-afte-free-in-ip_reass-CVE-2020-1.patch
- Increased disk space in _constraints file from 8GB to 9GB
* Mon Apr 27 2020 Bruce Rogers <brogers@suse.com>
-Fix potential DoS in ATI VGA emulation (CVE-2020-11869
  bsc#1170537)
  ati-vga-Fix-checks-in-ati_2d_blt-to-avoi.patch
* Wed Apr 22 2020 Bruce Rogers <brogers@suse.com>
- Minor tweaks to patches and support doc
* Tue Apr 21 2020 Martin Liška <mliska@suse.cz>
- Add gcc10-maybe-uninitialized.patch in order to fix
  boo#1169728.
* Fri Apr 17 2020 Bruce Rogers <brogers@suse.com>
- Include upstream patches targeted for the next stable release
  (bug fixes only)
  spapr-Fix-failure-path-for-attempting-to.patch
  target-i386-do-not-set-unsupported-VMX-s.patch
  target-xtensa-fix-pasto-in-pfwait.r-opco.patch
  tcg-i386-Fix-INDEX_op_dup2_vec.patch
  tcg-mips-mips-sync-encode-error.patch
  vhost-user-gpu-Release-memory-returned-b.patch
  vpc-Don-t-round-up-already-aligned-BAT-s.patch
  xen-block-Fix-double-qlist-remove-and-re.patch
- Fix bug causing weak encryption in PAuth for ARM
  (CVE-2020-10702 bsc#1168681)
  target-arm-Fix-PAuth-sbox-functions.patch
- Fix OOB in tulip NIC emulation (CVE-2020-11102 bsc#1168713
  net-tulip-check-frame-size-and-r-w-data-.patch
- Note that previously included patch addresses CVE-2020-1711
  and bsc#1166240
  iscsi-Cap-block-count-from-GET-LBA-STATU.patch
- Include performance improvement (and related?) patch
  aio-wait-delegate-polling-of-main-AioCon.patch
  async-use-explicit-memory-barriers.patch
- Rework previous patch at Olaf H.'s direction
  hw-i386-disable-smbus-migration-for-xenf.patch
- Eliminate is_opensuse usage in producing seabios version string
  what we are doing here is just replacing the upstream string
  with one indicating that the openSUSE build service built it,
  and so just leave it as "-rebuilt.opensuse.org"
- Alter algorithm used to produce "unique" symbol for coordinating
  qemu with the optional modules it may load. This is a reasonable
  relaxation for broader compatibility
  configure-remove-pkgversion-from-CONFIG_.patch
- Tweak supported.*.txt for latest deprecations, and other fixes
- Tweak update_git.sh, config.sh
* Mon Apr  6 2020 Bruce Rogers <brogers@suse.com>
- One more fix is needed for: s390x Protected Virtualization support
  - start and control guest in secure mode (bsc#1167075 jsc#SLE-7407)
  s390x-s390-virtio-ccw-Fix-build-on-syste.patch
* Thu Mar 26 2020 Bruce Rogers <brogers@suse.com>
- Include upstream patches targeted for the next stable release
  (bug fixes only)
  block-Avoid-memleak-on-qcow2-image-info-.patch
  block-bdrv_set_backing_bs-fix-use-after-.patch
  hmp-vnc-Fix-info-vnc-list-leak.patch
  migration-colo-fix-use-after-free-of-loc.patch
  migration-ram-fix-use-after-free-of-loca.patch
  ppc-ppc405_boards-Remove-unnecessary-NUL.patch
  qcow2-List-autoclear-bit-names-in-header.patch
  scsi-qemu-pr-helper-Fix-out-of-bounds-ac.patch
  sheepdog-Consistently-set-bdrv_has_zero_.patch
* Tue Mar 24 2020 Bruce Rogers <brogers@suse.com>
- Note The previous set of s390x patches also includes the fix for:
  bsc#1167445
* Fri Mar 20 2020 Bruce Rogers <brogers@suse.com>
- Include upstream patches targeted for the next stable release
  (bug fixes only)
  block-io-fix-bdrv_co_do_copy_on_readv.patch
  compat-disable-edid-on-correct-virtio-gp.patch
  target-ppc-Fix-rlwinm-on-ppc64.patch
  vhost-correctly-turn-on-VIRTIO_F_IOMMU_P.patch
- s390x Protected Virtualization support - start and control guest
  in secure mode. (note: binary patch from patch series dropped since
  for s390x we rebuild the patched binary anyways) (bsc#1167075
  jsc#SLE-7407)
  s390-sclp-improve-special-wait-psw-logic.patch
  s390x-Add-missing-vcpu-reset-functions.patch
  s390x-Add-SIDA-memory-ops.patch
  s390x-Add-unpack-facility-feature-to-GA1.patch
  s390x-Beautify-diag308-handling.patch
  s390x-Don-t-do-a-normal-reset-on-the-ini.patch
  s390x-ipl-Consolidate-iplb-validity-chec.patch
  s390x-kvm-Make-kvm_sclp_service_call-voi.patch
  s390x-Move-clear-reset.patch
  s390x-Move-diagnose-308-subcodes-and-rcs.patch
  s390x-Move-initial-reset.patch
  s390x-Move-reset-normal-to-shared-reset-.patch
  s390x-protvirt-Add-migration-blocker.patch
  s390x-protvirt-Disable-address-checks-fo.patch
  s390x-protvirt-Handle-SIGP-store-status-.patch
  s390x-protvirt-Inhibit-balloon-when-swit.patch
  s390x-protvirt-KVM-intercept-changes.patch
  s390x-protvirt-Move-diag-308-data-over-S.patch
  s390x-protvirt-Move-IO-control-structure.patch
  s390x-protvirt-Move-STSI-data-over-SIDAD.patch
  s390x-protvirt-SCLP-interpretation.patch
  s390x-protvirt-Set-guest-IPL-PSW.patch
  s390x-protvirt-Support-unpack-facility.patch
  Sync-pv.patch
* Fri Mar 20 2020 Liang Yan <lyan@suse.com>
- Fix the issue that s390x could not read IPL channel program when using
  dasd as boot device (bsc#1163140)
  pc-bios-s390x-Save-iplb-location-in-lowc.patch
* Mon Mar 16 2020 Bruce Rogers <brogers@suse.com>
- Fix potential OOB accesses in slirp (CVE-2020-8608 bsc#1163018
  bsc#1161066 CVE-2020-7039)
  slirp-use-correct-size-while-emulating-c.patch
  slirp-use-correct-size-while-emulating-I.patch
  tcp_emu-Fix-oob-access.patch
  tcp_emu-fix-unsafe-snprintf-usages.patch
  util-add-slirp_fmt-helpers.patch
- Replace this patch with upstream version
  target-arm-monitor-query-cpu-model-expan.patch
* Thu Mar 12 2020 Bruce Rogers <brogers@suse.com>
- Include upstream patches targeted for the next stable release
  (bug fixes only)
  audio-oss-fix-buffer-pos-calculation.patch
  blkdebug-Allow-taking-unsharing-permissi.patch
  block-Add-bdrv_qapi_perm_to_blk_perm.patch
  block-backup-top-fix-failure-path.patch
  block-block-copy-fix-progress-calculatio.patch
  block-fix-crash-on-zero-length-unaligned.patch
  block-fix-memleaks-in-bdrv_refresh_filen.patch
  block-Fix-VM-size-field-width-in-snapsho.patch
  block-nbd-extract-the-common-cleanup-cod.patch
  block-nbd-fix-memory-leak-in-nbd_open.patch
  block-qcow2-threads-fix-qcow2_decompress.patch
  hw-arm-cubieboard-use-ARM-Cortex-A8-as-t.patch
  hw-intc-arm_gicv3_kvm-Stop-wrongly-progr.patch
  iotests-add-test-for-backup-top-failure-.patch
  iotests-Fix-nonportable-use-of-od-endian.patch
  job-refactor-progress-to-separate-object.patch
  target-arm-Correct-definition-of-PMCRDP.patch
  target-arm-fix-TCG-leak-for-fcvt-half-do.patch
  tpm-ppi-page-align-PPI-RAM.patch
  vhost-user-blk-delete-virtioqueues-in-un.patch
  virtio-add-ability-to-delete-vq-through-.patch
  virtio-crypto-do-delete-ctrl_vq-in-virti.patch
  virtio-pmem-do-delete-rq_vq-in-virtio_pm.patch
* Thu Feb 20 2020 Bruce Rogers <brogers@suse.com>
- Add Obsoletes directive for qemu-audio-sdl and qemu-ui-sdl since
  for a qemu package upgrade from SLE12-SP5, support for SDL is
  dropped
* Wed Feb 19 2020 Bruce Rogers <brogers@suse.com>
- Fix xenfv migration from xen host with pre-v4.0 qemu. We had
  previously dropped a similar patch, but have decided that for now
  we need to go with this type of solution (bsc#1159755)
  hw-i386-disable-smbus-migration-for-xenf.patch
* Tue Feb  4 2020 Liang Yan <lyan@suse.com>
- Avoid query-cpu-model-expansion crashed qemu when using
  machine type none, patch is queued in upstream now, will
  update commit id later (bsc#1159443)
  target-arm-monitor-query-cpu-model-expan.patch
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libudev) instead of libudev-devel: Allow
  OBS to shortcut through -mini flavors.
* Tue Jan 28 2020 Bruce Rogers <brogers@suse.com>
- Stop using system membarriers (ie switch from --enable-membarrier
  to --disable-membarrier). This is a blocker for using qemu in the
  context of containers (boo#1130134 jsc#SLE-11089)
- Drop this recently added patch - in consultation with upstream it
  was decided it needed to be solved a different way (bsc#1159755)
  hw-i386-disable-smbus-migration-for-xenf.patch
- Include upstream patches targeted for the next stable release
  (bug fixes only)
  block-backup-fix-memory-leak-in-bdrv_bac.patch
  iscsi-Cap-block-count-from-GET-LBA-STATU.patch
  s390x-adapter-routes-error-handling.patch
  target-i386-kvm-initialize-feature-MSRs-.patch
* Fri Jan 24 2020 Bruce Rogers <brogers@suse.com>
- Include upstream patches targeted for the next stable release
  (bug fixes only)
  hw-i386-pc-fix-regression-in-parsing-vga.patch
  m68k-Fix-regression-causing-Single-Step-.patch
  migration-Rate-limit-inside-host-pages.patch
  migration-test-ppc64-fix-FORTH-test-prog.patch
  Revert-vnc-allow-fall-back-to-RAW-encodi.patch
  runstate-ignore-finishmigrate-prelaunch-.patch
  target-arm-Return-correct-IL-bit-in-merg.patch
  target-arm-Set-ISSIs16Bit-in-make_issinf.patch
  vnc-prioritize-ZRLE-compression-over-ZLI.patch
* Fri Jan 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
- Use systemd_ordering in place of systemd_requires: systemd is
  never a strict requirement for qemu; but when installing qemu on
  a systemd-managed system, we want system to be present first.
* Tue Jan 14 2020 Bruce Rogers <brogers@suse.com>
- Fix xenfv migration from xen host with pre-v4.0 qemu (bsc#1159755)
  hw-i386-disable-smbus-migration-for-xenf.patch
* Tue Jan 14 2020 ohering@suse.de
- Create files within bundles.tar.xz with fixed timestamp and uid
* Sat Jan 11 2020 Bruce Rogers <brogers@suse.com>
- Add a %%bcond_without system_membarrier along with related
  processing to the spec file, to better investigate running QEMU
  with the --disable-membarrier configure option
* Fri Jan 10 2020 Bruce Rogers <brogers@suse.com>
- Include upstream patches targeted for the next stable release
  (bug fixes only)
  arm-arm-powerctl-set-NSACR.-CP11-CP10-bi.patch
  backup-top-Begin-drain-earlier.patch
  block-Activate-recursively-even-for-alre.patch
  display-bochs-display-fix-memory-leak.patch
  Fix-double-free-issue-in-qemu_set_log_fi.patch
  hw-arm-smmuv3-Align-stream-table-base-ad.patch
  hw-arm-smmuv3-Apply-address-mask-to-line.patch
  hw-arm-smmuv3-Check-stream-IDs-against-a.patch
  hw-arm-smmuv3-Correct-SMMU_BASE_ADDR_MAS.patch
  hw-arm-smmuv3-Report-F_STE_FETCH-fault-a.patch
  hw-arm-smmuv3-Use-correct-bit-positions-.patch
  i386-Resolve-CPU-models-to-v1-by-default.patch
  intel_iommu-a-fix-to-vtd_find_as_from_bu.patch
  iotests-Fix-IMGOPTSSYNTAX-for-nbd.patch
  iotests-Provide-a-function-for-checking-.patch
  iotests-Skip-test-060-if-it-is-not-possi.patch
  iotests-Skip-test-079-if-it-is-not-possi.patch
  numa-properly-check-if-numa-is-supported.patch
  qcow2-bitmaps-fix-qcow2_can_store_new_di.patch
  Revert-qemu-options.hx-Update-for-reboot.patch
  vhost-user-gpu-Drop-trailing-json-comma.patch
  virtio-blk-fix-out-of-bounds-access-to-b.patch
  virtio-mmio-update-queue-size-on-guest-w.patch
  virtio-net-delete-also-control-queue-whe.patch
  virtio-update-queue-size-on-guest-write.patch
- Include performance improvement
  virtio-don-t-enable-notifications-during.patch
- Repair incorrect packaging references to Jira tracked features
* Thu Jan  9 2020 Bruce Rogers <brogers@suse.com>
- Add Cooperlake vcpu model (jsc#SLE-7923)
  i386-Add-MSR-feature-bit-for-MDS-NO.patch
  i386-Add-macro-for-stibp.patch
  i386-Add-new-CPU-model-Cooperlake.patch
  target-i386-Add-new-bit-definitions-of-M.patch
  target-i386-Add-missed-features-to-Coope.patch
- Add HMAT support (jsc#SLE-8897) (the test case for this series
  isn't included because we aren't set up to handle binary patches)
  numa-Extend-CLI-to-provide-initiator-inf.patch
  numa-Extend-CLI-to-provide-memory-latenc.patch
  numa-Extend-CLI-to-provide-memory-side-c.patch
  hmat-acpi-Build-Memory-Proximity-Domain-.patch
  hmat-acpi-Build-System-Locality-Latency-.patch
  hmat-acpi-Build-Memory-Side-Cache-Inform.patch
  tests-numa-Add-case-for-QMP-build-HMAT.patch
* Thu Dec 12 2019 Bruce Rogers <brogers@suse.com>
- Update to v4.2.0: See http://wiki.qemu.org/ChangeLog/4.2
  Take note that ongoing feature deprecation is tracked at both
  http://wiki.qemu-project.org/Features/LegacyRemoval and in
  Appendix B of the qemu-doc.* files installed with the qemu package
  Some noteworthy changes:
  * x86: Denverton, Snowridge, and Dhyana CPU models added
  * x86: Latest version of all CPU models how have TSX (HLE and RTM)
  disabled by default
  * x86: Support for AVX512 BFloat16 extensions
  * x86: VMX features exposed more accurately and controllably
  * s390: TCG now implements IEP (Instruction Execution Protection)
  * PowerPC: POWER8 and POWER9 non-virtualized machines separated out
  * PowerPC: RTAS now comes from SLOF instead of QEMU itself
  * PowerPC: Unplug of multifunction PCI devices now unplugs the
  whole slot, as in x86
  * ARM: Support for >256 CPUs with KVM is fixed
  * ARM: Memory hotplug now supported , when using UEFI, ACPI, for
  virt machine type
  * ARM: SVE support possuble now for KVM guests
  * ARM: ACPI generic event device can now deliver powerdown event
  * The backend device can be specified for a guest audio device
  * virtio v1.1 packed virtqueues supported
  * Socket based character device backends now support TCP keep-alive
  * Use encryption library cipher mode facilities, allowing improved
  performance for eg. AES-XTS encrption
  * Misc block device improvements, esp. with nbd
- See the following few release-candidate changelog entries for
  additional changes related to this release
- Switched package build to be out-of-tree
* Tue Dec 10 2019 Bruce Rogers <brogers@suse.com>
- Update to v4.2.0-rc5: See http://wiki.qemu.org/ChangeLog/4.2
* Wed Dec  4 2019 Bruce Rogers <brogers@suse.com>
- Update to v4.2.0-rc4: See http://wiki.qemu.org/ChangeLog/4.2
  * Update the support documents used for SUSE SLE releases to cover
  this qemu release
* Wed Nov 27 2019 Bruce Rogers <brogers@suse.com>
- Update to v4.2.0-rc3: See http://wiki.qemu.org/ChangeLog/4.2
  * Patches dropped (upstream unless otherwise noted):
  ati-add-edid-support.patch
  ati-vga-add-rage128-edid-support.patch
  ati-vga-fix-ati_read.patch
  ati-vga-make-i2c-register-and-bits-confi.patch
  ati-vga-make-less-verbose.patch
  ati-vga-try-vga-ddc-first.patch
  Disable-Waddress-of-packed-member-for-GC.patch
  hdata-vpd-fix-printing-char-0x00.patch
  target-i386-add-PSCHANGE_NO-bit-for-the-.patch
  target-i386-Export-TAA_NO-bit-to-guests.patch
  vbe-add-edid-support.patch
  vga-add-ati-bios-tables.patch
  vga-add-atiext-driver.patch
  vga-make-memcpy_high-public.patch
  vga-move-modelist-from-bochsvga.c-to-new.patch
  * Patches added:
  Enable-cross-compile-prefix-for-C-compil.patch
  ensure-headers-included-are-compatible-w.patch
  roms-Makefile-enable-cross-compile-for-b.patch
  * Add qemu-ui-spice-app package containing ui-spice-app.so
  * Add qemu-microvm package containing bios-microvm.bin
- Add descriptors for the 128k and 256k SeaBios firmware images
- For the record, the following issues reported for SUSE SLE15-SP1
  are either fixed in this current package, or are otherwise not an
  issue: bsc#1079730 bsc#1098403 bsc#1111025 bsc#1128106 bsc#1133031
  bsc#1134883 bsc#1135210 bsc#1135902 bsc#1136540 bsc#1136778
  bsc#1138534 bsc#1140402 bsc#1143794 bsc#1145379 bsc#1144087
  bsc#1145427 bsc#1145436 bsc#1145774 bsc#1146873 bsc#1149811
  bsc#1152506 bsc#1155812 bsc#1156642 CVE-2018-12207 CVE-2019-5008
  CVE-2019-11135 CVE-2019-12068 CVE-2019-12155 CVE-2019-13164
  CVE-2019-14378 CVE-2019-15890, and the following feature requests
  are satisfied by this package: fate#327410 fate#327764 fate#327796
  jsc#SLE-4883 jsc#SLE-6132 jsc#SLE-6237 jsc#SLE-6754
* Tue Nov 19 2019 Bruce Rogers <brogers@suse.com>
- Expose pschange-mc-no "feature", indicating CPU does not have
  the page size change machine check vulnerability (CVE-2018-12207
  bsc#1155812)
  target-i386-add-PSCHANGE_NO-bit-for-the-.patch
- Expose taa-no "feature", indicating CPU does not have the
  TSX Async Abort vulnerability. (CVE-2019-11135 bsc#1152506)
  target-i386-Export-TAA_NO-bit-to-guests.patch
  Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.1
* Fri Nov 15 2019 Bruce Rogers <brogers@suse.com>
- Update to v4.1.1, a stable, bug-fix-only release
  * Besides incorporating the following fixes we already carried, it
  includes about the same number of other, similar type fixes
  which we hadn't yet incorporated.
  * Patches dropped (subsumed by stable update):
  block-Add-bdrv_co_get_self_request.patch
  block-create-Do-not-abort-if-a-block-dri.patch
  block-file-posix-Let-post-EOF-fallocate-.patch
  block-file-posix-Reduce-xfsctl-use.patch
  block-io-refactor-padding.patch
  blockjob-update-nodes-head-while-removin.patch
  block-Make-wait-mark-serialising-request.patch
  block-nfs-tear-down-aio-before-nfs_close.patch
  coroutine-Add-qemu_co_mutex_assert_locke.patch
  curl-Check-completion-in-curl_multi_do.patch
  curl-Handle-success-in-multi_check_compl.patch
  curl-Keep-pointer-to-the-CURLState-in-CU.patch
  curl-Keep-socket-until-the-end-of-curl_s.patch
  curl-Pass-CURLSocket-to-curl_multi_do.patch
  curl-Report-only-ready-sockets.patch
  hw-arm-boot.c-Set-NSACR.-CP11-CP10-for-N.patch
  hw-core-loader-Fix-possible-crash-in-rom.patch
  make-release-pull-in-edk2-submodules-so-.patch
  memory-Provide-an-equality-function-for-.patch
  mirror-Keep-mirror_top_bs-drained-after-.patch
  pr-manager-Fix-invalid-g_free-crash-bug.patch
  qcow2-bitmap-Fix-uint64_t-left-shift-ove.patch
  qcow2-Fix-corruption-bug-in-qcow2_detect.patch
  qcow2-Fix-QCOW2_COMPRESSED_SECTOR_MASK.patch
  qcow2-Fix-the-calculation-of-the-maximum.patch
  roms-Makefile.edk2-don-t-pull-in-submodu.patch
  s390-PCI-fix-IOMMU-region-init.patch
  s390x-tcg-Fix-VERIM-with-32-64-bit-eleme.patch
  target-alpha-fix-tlb_fill-trap_arg2-valu.patch
  target-arm-Don-t-abort-on-M-profile-exce.patch
  target-arm-Free-TCG-temps-in-trans_VMOV_.patch
  util-iov-introduce-qemu_iovec_init_exten.patch
  vhost-Fix-memory-region-section-comparis.patch
  vpc-Return-0-from-vpc_co_create-on-succe.patch
  Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.1
* Fri Nov  8 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix %%arm builds
* Thu Nov  7 2019 Bruce Rogers <brogers@suse.com>
- Fix two issues with qcow2 image processing which could affect
  disk integrity
  qcow2-Fix-QCOW2_COMPRESSED_SECTOR_MASK.patch
  qcow2-bitmap-Fix-uint64_t-left-shift-ove.patch
* Wed Nov  6 2019 Bruce Rogers <brogers@suse.com>
- Work around a host kernel xfs bug which can result in qcow2 image
  corruption
  block-io-refactor-padding.patch
  util-iov-introduce-qemu_iovec_init_exten.patch
  block-Make-wait-mark-serialising-request.patch
  block-Add-bdrv_co_get_self_request.patch
  block-file-posix-Let-post-EOF-fallocate-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.1
* Mon Nov  4 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Correct package names in _constraints after switch to multibuild.
* Sat Oct 26 2019 Bruce Rogers <brogers@suse.com>
- Address potential corruption when using qcow2 images
  coroutine-Add-qemu_co_mutex_assert_locke.patch
  qcow2-Fix-corruption-bug-in-qcow2_detect.patch
- Include more tweaks to our packaging workflow scripts - this will
  continue as we refine the scripts
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.1
* Thu Oct 17 2019 Ludwig Nussel <lnussel@suse.de>
- use %%gcc_version for cross compilers (boo#1153703)
* Tue Oct 15 2019 Bruce Rogers <brogers@suse.com>
- Add upstream edk2 submodule fix for creating tarball
- Switch to upstream patch for avoiding git ref in edk2 makefile
- Fix failing block tests which aren't compatible with the configure
  option --enable-membarrier
  * Patches dropped:
  roms-Makefile.edk2-don-t-invoke-git-sinc.patch
  tests-block-io-test-130-needs-some-delay.patch
  * Patches added:
  make-release-pull-in-edk2-submodules-so-.patch
  roms-Makefile.edk2-don-t-pull-in-submodu.patch
  tests-Fix-block-tests-to-be-compatible-w.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.1
* Thu Oct 10 2019 Bruce Rogers <brogers@suse.com>
- Reduce the cross compiler versions we rely on
- Fix some qemu-testsuite issues, reducing known error cases
  test-add-mapping-from-arch-of-i686-to-qe.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.1
* Wed Oct  2 2019 Bruce Rogers <brogers@suse.com>
- Since our spec file has bashisms, include the following in the
  spec file: %%define _buildshell /bin/bash
* Wed Oct  2 2019 Bruce Rogers <brogers@suse.com>
- Disable some block tests which randomly fail. This is in context
  of the build service build of qemu-testsuite
  tests-Disable-some-block-tests-for-now.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.1
* Tue Oct  1 2019 Bruce Rogers <brogers@suse.com>
- Add some post v4.1.0 upstream stable patches
  * Patches added:
  mirror-Keep-mirror_top_bs-drained-after-.patch
  s390x-tcg-Fix-VERIM-with-32-64-bit-eleme.patch
  target-alpha-fix-tlb_fill-trap_arg2-valu.patch
  target-arm-Free-TCG-temps-in-trans_VMOV_.patch
  target-arm-Don-t-abort-on-M-profile-exce.patch
  qcow2-Fix-the-calculation-of-the-maximum.patch
  block-file-posix-Reduce-xfsctl-use.patch
  pr-manager-Fix-invalid-g_free-crash-bug.patch
  vpc-Return-0-from-vpc_co_create-on-succe.patch
  block-nfs-tear-down-aio-before-nfs_close.patch
  block-create-Do-not-abort-if-a-block-dri.patch
  curl-Keep-pointer-to-the-CURLState-in-CU.patch
  curl-Keep-socket-until-the-end-of-curl_s.patch
  curl-Check-completion-in-curl_multi_do.patch
  curl-Pass-CURLSocket-to-curl_multi_do.patch
  curl-Report-only-ready-sockets.patch
  curl-Handle-success-in-multi_check_compl.patch
  blockjob-update-nodes-head-while-removin.patch
  memory-Provide-an-equality-function-for-.patch
  vhost-Fix-memory-region-section-comparis.patch
  hw-arm-boot.c-Set-NSACR.-CP11-CP10-for-N.patch
  s390-PCI-fix-IOMMU-region-init.patch
  hw-core-loader-Fix-possible-crash-in-rom.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.1
* Wed Sep 11 2019 Bruce Rogers <brogers@suse.com>
- Include more tweaks to our packaging workflow scripts
- Produce qemu-linux-user and qemu-testsuite via the build service
  multibuild capability, instead of duplicating the spec file and
  using package link in build service
  * combine qemu-linux-user spec file into main qemu spec file. Since
  this model uses a single changelog, here are some historicial
  mentions from the now unused qemu-linux-user.changes (delta from
  qemu's was quite minimal):
  - Adjust to a v5.2 linux kernel change regarding SIOCGSTAMP
  - Fix pwrite64/pread64 to return 0 over -1 for a
    zero length NULL buffer in qemu (bsc#1121600)
  * bsc#1112499
  * Since qemu-testsuite.spec and qemu-testsuite.changes were just
  copies of the main qemu version nothing needs to be done there
* Fri Sep  6 2019 Bruce Rogers <brogers@suse.com>
- Build opensbi from source on riscv64
* Fri Sep  6 2019 Bruce Rogers <brogers@suse.com>
- Update to v4.1.0: See http://wiki.qemu.org/ChangeLog/4.1
  Take note that ongoing feature deprecation is tracked at both
  http://wiki.qemu-project.org/Features/LegacyRemoval and in
  Appendix B of the qemu-doc.* files installed with the qemu package
  Some noteworthy changes:
  * x86: CPU models are now versioned
  * x86: CPU die topology can now be configured
  * x86: New Hygon Dhyana and Intel Snowridge CPU models
  * s390: The bios now supports IPL (boot) from ECKD DASD assigned
  to the guest via vfio-ccw
  * s390: The bios now tolerates the presence of bootmap signature
  entries written by zipl
  * PowerPC: pseries machine now supports KVM acceleration
  (kernel_irqchip=on) of the XIVE interrupt controller
  * PowerPC: pseries now supports hot-plug of PCI bridges and hot-plug
  and unplug of devices under PCI bridges
  * ARM: QEMU now supports emulating an FPU for Cortex-M CPUs, and the
  Cortex-M4 and Cortex-M33 now provide the FP
  * Python 2 support is deprecated
  * UEFI platform firmware binaries, and matching variable store
  templates are now installed
  * Now it's possible to specify memory-less NUMA node when using
  "-numa node,memdev" options
  * Possible to trigger self announcement on specific network interfaces
  * Default memory distribution between NUMA nodes is now deprecated
  * Fallback to normal RAM allocation if QEMU is not able to allocate
  from the "-mem-path" provided file/filesystem is now deprecated
  * virtio-gpu 2d/3d rendering may now be offloaded to an external
  vhost-user process, such as QEMU vhost-user-gpu
  * QEMU will automatically try to use the MAP_SYNC mmap flag for memory
  backends configured with pmem=on,share=on
  * Additional SeaVGABIOS patches added for vga-ati compatibility
- Drop attempt at build compatibility with SLE12
- New sub-packages: qemu-edk2, qemu-vhost-user-gpu
- Conditionalize building of qemu-edk2 (and leave unbuilt for now)
- Implement new packaging workflow, includes no longer numbering
  patches, and having the "current git repo" stored with the package
  in the form of git bundles
  * Patches dropped (upstream unless otherwise noted):
  0027-tests-test-thread-pool-is-racy-add-.patch
  0032-tests-Fix-Makefile-handling-of-chec.patch
  0034-Revert-target-i386-kvm-add-VMX-migr.patch
  0036-sockets-avoid-string-truncation-war.patch
  0039-linux-user-avoid-string-truncation-.patch
  0040-linux-user-elfload-Fix-GCC-9-build-.patch
  0041-qxl-avoid-unaligned-pointer-reads-w.patch
  0042-libvhost-user-fix-Waddress-of-packe.patch
  0043-target-i386-define-md-clear-bit.patch
  0045-kbd-state-fix-autorepeat-handling.patch
  0046-target-ppc-ensure-we-get-null-termi.patch
  0049-qxl-check-release-info-object.patch
  0050-qemu-bridge-helper-restrict-interfa.patch
  0051-linux-user-fix-to-handle-variably-s.patch
  ipxe-use-gcc6-for-more-compact-code.patch (no longer needed)
  (the next three are replaced by the upstream equivalent)
  ipxe-efi-Simplify-diagnostic-for-NULL-handle.patch
  ipxe-build-Disable-gcc-address-of-packed-member-warning.patch
  ipxe-efi-Avoid-string-op-warning-with-cross-gcc-7-compile.patch
  slirp-fix-heap-overflow-in-ip_reass-on-big-packet-input.patch
  * Patches renamed:
  0001-XXX-dont-dump-core-on-sigabort.patch
  - > XXX-dont-dump-core-on-sigabort.patch
  0002-qemu-binfmt-conf-Modify-default-pat.patch
  - > qemu-binfmt-conf-Modify-default-path.patch
  0003-qemu-cvs-gettimeofday.patch
  - > qemu-cvs-gettimeofday.patch
  0004-qemu-cvs-ioctl_debug.patch
  - > qemu-cvs-ioctl_debug.patch
  0005-qemu-cvs-ioctl_nodirection.patch
  - > qemu-cvs-ioctl_nodirection.patch
  0006-linux-user-add-binfmt-wrapper-for-a.patch
  - > linux-user-add-binfmt-wrapper-for-argv-0.patch
  0007-PPC-KVM-Disable-mmu-notifier-check.patch
  - > PPC-KVM-Disable-mmu-notifier-check.patch
  0008-linux-user-binfmt-support-host-bina.patch
  - > linux-user-binfmt-support-host-binaries.patch
  0009-linux-user-Fake-proc-cpuinfo.patch
  - > linux-user-Fake-proc-cpuinfo.patch
  0010-linux-user-use-target_ulong.patch
  - > linux-user-use-target_ulong.patch
  0011-Make-char-muxer-more-robust-wrt-sma.patch
  - > Make-char-muxer-more-robust-wrt-small-FI.patch
  0012-linux-user-lseek-explicitly-cast-no.patch
  - > linux-user-lseek-explicitly-cast-non-set.patch
  0013-AIO-Reduce-number-of-threads-for-32.patch
  - > AIO-Reduce-number-of-threads-for-32bit-h.patch
  0014-xen_disk-Add-suse-specific-flush-di.patch
  - > xen_disk-Add-suse-specific-flush-disable.patch
  0015-qemu-bridge-helper-reduce-security-.patch
  - > qemu-bridge-helper-reduce-security-profi.patch
  0016-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  - > qemu-binfmt-conf-use-qemu-ARCH-binfmt.patch
  0017-linux-user-properly-test-for-infini.patch
  - > linux-user-properly-test-for-infinite-ti.patch
  0018-roms-Makefile-pass-a-packaging-time.patch
  - > roms-Makefile-pass-a-packaging-timestamp.patch
  0019-Raise-soft-address-space-limit-to-h.patch
  - > Raise-soft-address-space-limit-to-hard-l.patch
  0020-increase-x86_64-physical-bits-to-42.patch
  - > increase-x86_64-physical-bits-to-42.patch
  0021-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  - > vga-Raise-VRAM-to-16-MiB-for-pc-0.15-and.patch
  0022-i8254-Fix-migration-from-SLE11-SP2.patch
  - > i8254-Fix-migration-from-SLE11-SP2.patch
  0023-acpi_piix4-Fix-migration-from-SLE11.patch
  - > acpi_piix4-Fix-migration-from-SLE11-SP2.patch
  0024-Switch-order-of-libraries-for-mpath.patch
  - > Switch-order-of-libraries-for-mpath-supp.patch
  0025-Make-installed-scripts-explicitly-p.patch
  - > Make-installed-scripts-explicitly-python.patch
  0026-hw-smbios-handle-both-file-formats-.patch
  - > hw-smbios-handle-both-file-formats-regar.patch
  0028-xen-add-block-resize-support-for-xe.patch
  - > xen-add-block-resize-support-for-xen-dis.patch
  0029-tests-qemu-iotests-Triple-timeout-o.patch
  - > tests-qemu-iotests-Triple-timeout-of-i-o.patch
  0030-tests-block-io-test-130-needs-some-.patch
  - > tests-block-io-test-130-needs-some-delay.patch
  0031-xen-ignore-live-parameter-from-xen-.patch
  - > xen-ignore-live-parameter-from-xen-save-.patch
  0033-Conditionalize-ui-bitmap-installati.patch
  - > Conditionalize-ui-bitmap-installation-be.patch
  0035-tests-change-error-message-in-test-.patch
  - > tests-change-error-message-in-test-162.patch
  0037-hw-usb-hcd-xhci-Fix-GCC-9-build-war.patch
  - > hw-usb-hcd-xhci-Fix-GCC-9-build-warning.patch
  0038-hw-usb-dev-mtp-Fix-GCC-9-build-warn.patch
  - > hw-usb-dev-mtp-Fix-GCC-9-build-warning.patch
  0044-hw-intc-exynos4210_gic-provide-more.patch
  - > hw-intc-exynos4210_gic-provide-more-room.patch
  0047-configure-only-populate-roms-if-sof.patch
  - > configure-only-populate-roms-if-softmmu.patch
  0048-pc-bios-s390-ccw-net-avoid-warning-.patch
  - > pc-bios-s390-ccw-net-avoid-warning-about.patch
  keycodemapdb-make-keycode-gen-output-reproducible.patch
  - > Make-keycode-gen-output-reproducible-use.patch
  ipxe-stub-out-the-SAN-req-s-in-int13.patch
  - > stub-out-the-SAN-req-s-in-int13.patch
  sgabios-fix-cross-build.patch deleted
  - > roms-sgabios-Fix-csum8-to-be-built-by-ho.patch
  sgabios-stable-buildid.patch
  - > sgabios-Makefile-fix-issues-of-build-rep.patch
  skiboot-gcc9-compat.patch
  - > Disable-Waddress-of-packed-member-for-GC.patch
  ipxe-stable-buildid.patch
  - > ipxe-Makefile-fix-issues-of-build-reprod.patch
  seabios-fix_cross_compilation.patch
  - > enable-cross-compilation-on-ARM.patch
  * Patches added:
  roms-change-cross-compiler-naming-to-be-.patch
  roms-Makefile.edk2-don-t-invoke-git-sinc.patch
  vga-move-modelist-from-bochsvga.c-to-new.patch
  vga-make-memcpy_high-public.patch
  vga-add-atiext-driver.patch
  vga-add-ati-bios-tables.patch
  vbe-add-edid-support.patch
  ati-add-edid-support.patch
  ati-vga-make-less-verbose.patch
  ati-vga-fix-ati_read.patch
  ati-vga-make-i2c-register-and-bits-confi.patch
  ati-vga-try-vga-ddc-first.patch
  ati-vga-add-rage128-edid-support.patch
  Fix-s-directive-argument-is-null-error.patch
  Workaround-compilation-error-with-gcc-9..patch
  Do-not-apply-WORKAROUND_CFLAGS-for-host-.patch
  hdata-vpd-fix-printing-char-0x00.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.1
* Fri Aug  9 2019 Bruce Rogers <brogers@suse.com>
- Since we build seabios, take advantage of ability to add our own
  identifying version info by changing SEABIOS_EXTRAVERSION from
  "-prebuilt.qemu.org" to "-rebuilt.suse.com" (or
  "-rebuilt.opensuse.org for openSUSE releases)
* Wed Aug  7 2019 Liang Yan <lyan@suse.com>
- Security fix for heap overflow in ip_reass on big packet input
  (CVE-2019-14378, bsc#1143794)
  slirp-fix-heap-overflow-in-ip_reass-on-big-packet-input.patch
* Tue Aug  6 2019 Bruce Rogers <brogers@suse.com>
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.0
  * Patches added:
  0051-linux-user-fix-to-handle-variably-s.patch
* Mon Aug  5 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Make keycode-gen output reproducible (use SOURCE_DATE_EPOCH timestamp)
  keycodemapdb-make-keycode-gen-output-reproducible.patch
* Thu Jul 25 2019 Liang Yan <lyan@suse.com>
- Security fix for null pointer dereference while releasing spice resources
  (CVE-2019-12155, bsc#1135902)
  0049-qxl-check-release-info-object.patch
- Security fix for qemu-bridge-helper ACL can be bypassed when names are too long
  (CVE-2019-13164, bsc#1140402)
  0050-qemu-bridge-helper-restrict-interfa.patch
- Replace patch 0043 with an upstream version
  0043-target-i386-define-md-clear-bit.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.0
* Tue Jun 11 2019 Christian Goll <cgoll@suse.com>
- fixed regression for ksm.service was (bsc#1112646)
* Mon Jun 10 2019 Bruce Rogers <brogers@suse.com>
- Content of packaged %%_docdir/%%name/interop/_static/ dir depends
  on python-Sphinx version, so lets just wildcard specifying
  those files, rather than trying to manage a specific file list
* Fri Jun  7 2019 Bruce Rogers <brogers@suse.com>
- Last change exposed that we still do rely on python2. Make
  spec file adjustment
* Fri Jun  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch from python-Sphinx to Sphinx from python variant we are
  building with (new Sphinx is for python3 only)
* Wed May 29 2019 Bruce Rogers <brogers@suse.com>
- Fix a number of compatibility issues with the stricter gcc9 checks
  * Disable warning for taking address of packed structure members
  0048-pc-bios-s390-ccw-net-avoid-warning-.patch
  * Fix case of strncpy where null terminated string not guaranteed
  0046-target-ppc-ensure-we-get-null-termi.patch
  * Disable warning for taking address of packed structure members
  and fix case of passing null pointer as "%%s" format parameter
  skiboot-gcc9-compat.patch
- Fix configure script which caused firmware to be built in
  linux-user only build.
  0047-configure-only-populate-roms-if-sof.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.0
* Fri May 17 2019 Bruce Rogers <brogers@suse.com>
- Fix regression in autorepeat key handling
  0045-kbd-state-fix-autorepeat-handling.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.0
* Fri May 17 2019 Andreas Schwab <schwab@suse.de>
- Fix file list
* Wed May 15 2019 Bruce Rogers <brogers@suse.com>
- Yet another gcc9 related code fix (bsc#1121464)
  0044-hw-intc-exynos4210_gic-provide-more.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.0
* Tue May 14 2019 Bruce Rogers <brogers@suse.com>
- Switch to now upstreamed version of patch and add one more
  gcc9 related patch
  * Patches renamed:
  0041-qxl-fix-Waddress-of-packed-member.patch
  - > 0041-qxl-avoid-unaligned-pointer-reads-w.patch
  0042-libvhost-user-fix-Waddress-of-packe.patch
- Add x86 cpu feature "md-clear" (CVE-2018-12126 CVE-2018-12127
  CVE-2018-12130 CVE-2019-11091 bsc#1111331)
  0043-target-i386-define-md-clear-bit.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.0
* Sat May 11 2019 Bruce Rogers <brogers@suse.com>
- Correct logic of which ipxe patches get included based on
  suse_version. We were wrongly excluding a gcc9 related patch for
  example
* Fri May 10 2019 Bruce Rogers <brogers@suse.com>
- Switch to now upstreamed version of some patches
  * Patches renamed:
  0036-util-qemu-sockets-Fix-GCC-9-build-w.patch
  - > 0036-sockets-avoid-string-truncation-war.patch
  0039-linux-user-uname-Fix-GCC-9-build-wa.patch
  - > 0039-linux-user-avoid-string-truncation-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.0
* Thu May  9 2019 Bruce Rogers <brogers@suse.com>
- Create /usr/share/qemu/firmware and /etc/qemu/firmware directories
  in support of the firmware descriptor feature now in use as of
  libvirt v5.2
* Mon May  6 2019 Bruce Rogers <brogers@suse.com>
- Disable LTO as suggested by Martin Liska (boo#1133281)
- Remove and obsolete qemu-oss-audio subpackage. OSS audio is very
  old, and we didn't really even configure the package properly for
  it for a very long time, so presumably there can't be any users
  of it as far as qemu is concerned
- Avoid warnings which gcc9 complains about
  0036-util-qemu-sockets-Fix-GCC-9-build-w.patch
  0037-hw-usb-hcd-xhci-Fix-GCC-9-build-war.patch
  0038-hw-usb-dev-mtp-Fix-GCC-9-build-warn.patch
  0039-linux-user-uname-Fix-GCC-9-build-wa.patch
  0040-linux-user-elfload-Fix-GCC-9-build-.patch
  0041-qxl-fix-Waddress-of-packed-member.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.0
* Wed May  1 2019 Bruce Rogers <brogers@suse.com>
- Update to v4.0.0: See http://wiki.qemu.org/ChangeLog/4.0
  Take note that ongoing feature deprecation is tracked at both
  http://wiki.qemu-project.org/Features/LegacyRemoval and in
  Appendix B of the qemu-doc.* files installed with the qemu package
  Some noteworthy changes:
  * ARM: ARMv8+ extensions for SB, PredInv, HPD, LOR, FHM, AA32HPD,
  PAuth, JSConv, CondM, FRINT, and BTI
  * ARM: new emulation support for "Musca" and "MPS2" development boards
  * ARM: virt: support for >255GB of RAM and u-boot "noload" image types
  * ARM: improved emulation of ARM PMU
  * HPPA: support for TLB protection IDs and TLB trace events
  * MIPS: support for multi-threaded TCG emulation
  * MIPS: emulation support for I7200 I6500 CPUs, QMP-base querying of
  CPU types, and improved support for SAARI and SAAR configuration registers
  * MIPS: improvements to Interthread Communication Unit, Fulong 2E
  machine types, and end-user documentation.
  * PowerPC: pseries/powernv: support for POWER9 large decrementer
  * PowerPC: pseries: emulation support for XIVE interrupt controller
  * PowerPC: pseries: support for hotplugging PCI host bridges (PHBs)
  * PowerPC: pseries: Spectre/Meltdown mitigations enabled by default,
  additional support for count-cache-flush mitigation
  * RISC-V: virt: support for PCI and USB
  * RISC-V: support for TSR, TW, and TVM fields of mstatus, FS field now
  supports three stats (dirty, clean, and off)
  * RISC-V: built-in gdbserver supports register lists via XML files
  * s390: support for z14 GA 2 CPU model, Multiple-epoch and PTFF
  features now enabled in z14 CPU model by default
  * s390: vfio-ap: now supports hot plug/unplug, and no longer inhibits memory
  ballooning
  * s390: emulation support for floating-point extension facility and
  vector support instructions
  * x86: HAX accelerator now supported POSIX hosts other than Darwin,
  including Linux and NetBSD
  * x86: Q35: advertised PCIe root port speeds will now optimally default
  to maximum link speed (16GT/s) and width (x32) provided by PCIe 4.0 for
  QEMU 4.0+ machine types; older machine types will retain 2.5GT/x1
  defaults for compatibility.
  * x86: Xen PVH images can now be booted with "-kernel" option
  * Xtensa: xtfpga: improved SMP support for linux (interrupt
  distributor, IPI, and runstall) and new SMP-capable test_mmuhifi_c3
  core configuration
  * Xtensa: support for Flexible length instructions extension (FLIX)
  * GUI: new '-display spice-app' to configure/launch a Spice client GUI with
  a similar UI to QEMU GTK. VNC server now supports access controls via
  tls-authz/sasl-authz options
  * QMP: support for "out-of-band" command execution, can be useful for
  postcopy migration recovery. Additional QMP commands for working with
  block devices and dirty bitmaps
  * VFIO: EDID interface for supported mdev (Intel vGPU for kernel 5.0+),
  allows resolution setting via xres/yres options.
  * Xen: new 'xen-disk' device which can create a Xen PV disk backend,
  and performance improvements for Xen PV disk backend.
  * Network Block Device: improved tracing and error diagnostics, improved
  client compatibility with buggy NBD server implementations, new
  - -bitmap, --list, --tls-authz options for qemu-nbd
  * virtio-blk now supports DISCARD and WRITE_ZEROES
  * qemu-test-suite output is now in TAP format
  * Sphinx now used for part of qemu documentation
  * A few more configure features are enabled: iconv, lzfse (for openSUSE)
  * Provide better logo icons
- Made these package building changes:
  * Removed this token from spec file: #!BuildIgnore:  gcc-PIE
  * Created ability to build qemu source out-of-tree
  * Added BSD-2-Clause license clause due to EDK II code inclusion
  * Patches dropped (upstream unless otherwise noted):
  0010-Remove-problematic-evdev-86-key-fro.patch
  0025-Fix-tigervnc-long-press-issue.patch
  0026-string-input-visitor-Fix-uint64-par.patch
  0027-test-string-input-visitor-Add-int-t.patch
  0028-test-string-input-visitor-Add-uint6.patch
  0029-tests-Add-QOM-property-unit-tests.patch
  0030-tests-Add-scsi-disk-test.patch
  0033-smbios-Add-1-terminator-if-any-stri.patch (different approach used)
  0034-qemu-io-tests-comment-out-problemat.patch (not as needed)
  0039-xen_disk-Avoid-repeated-memory-allo.patch
  0041-vfio-ap-flag-as-compatible-with-bal.patch
  0042-hw-s390x-Fix-bad-mask-in-time2tod.patch
  0043-pcie-set-link-state-inactive-active.patch
  0044-pc-piix4-Update-smbus-I-O-space-aft.patch
  0045-hw-usb-fix-mistaken-de-initializati.patch
  0046-usb-mtp-use-O_NOFOLLOW-and-O_CLOEXE.patch
  0047-pvrdma-release-device-resources-in-.patch
  0048-rdma-check-num_sge-does-not-exceed-.patch
  0049-pvrdma-add-uar_read-routine.patch
  0050-pvrdma-check-number-of-pages-when-c.patch
  0051-pvrdma-check-return-value-from-pvrd.patch
  0052-pvrdma-release-ring-object-in-case-.patch
  0053-block-Fix-hangs-in-synchronous-APIs.patch
  0054-linux-user-make-pwrite64-pread64-fd.patch
  0055-xen-Add-xen-v4.12-based-xc_domain_c.patch
  0056-slirp-check-data-length-while-emula.patch
  0057-s390x-Return-specification-exceptio.patch
  0059-memory-Fix-the-memory-region-type-a.patch
  0060-target-i386-sev-Do-not-pin-the-ram-.patch
  0061-slirp-check-sscanf-result-when-emul.patch
  0062-ppc-add-host-serial-and-host-model-.patch
  0063-i2c-ddc-fix-oob-read.patch
  0064-device_tree.c-Don-t-use-load_image.patch
  0065-spapr-Simplify-handling-of-host-ser.patch
  ipxe-efi-guard-strncpy-with-gcc-warning-ignore-pragma.patch
  ipxe-fix-build.patch
  skiboot-hdata-i2c.c-fix-building-with-gcc8.patch
  * Patches renamed:
  0011-linux-user-use-target_ulong.patch
  - > 0010-linux-user-use-target_ulong.patch
  0012-Make-char-muxer-more-robust-wrt-sma.patch
  - > 0011-Make-char-muxer-more-robust-wrt-sma.patch
  0013-linux-user-lseek-explicitly-cast-no.patch
  - > 0012-linux-user-lseek-explicitly-cast-no.patch
  0014-AIO-Reduce-number-of-threads-for-32.patch
  - > 0013-AIO-Reduce-number-of-threads-for-32.patch
  0015-xen_disk-Add-suse-specific-flush-di.patch
  - > 0014-xen_disk-Add-suse-specific-flush-di.patch
  0016-qemu-bridge-helper-reduce-security-.patch
  - > 0015-qemu-bridge-helper-reduce-security-.patch
  0017-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  - > 0016-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  0018-linux-user-properly-test-for-infini.patch
  - > 0017-linux-user-properly-test-for-infini.patch
  0019-roms-Makefile-pass-a-packaging-time.patch
  - > 0018-roms-Makefile-pass-a-packaging-time.patch
  0020-Raise-soft-address-space-limit-to-h.patch
  - > 0019-Raise-soft-address-space-limit-to-h.patch
  0021-increase-x86_64-physical-bits-to-42.patch
  - > 0020-increase-x86_64-physical-bits-to-42.patch
  0022-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  - > 0021-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0023-i8254-Fix-migration-from-SLE11-SP2.patch
  - > 0022-i8254-Fix-migration-from-SLE11-SP2.patch
  0024-acpi_piix4-Fix-migration-from-SLE11.patch
  - > 0023-acpi_piix4-Fix-migration-from-SLE11.patch
  0031-Switch-order-of-libraries-for-mpath.patch
  - > 0024-Switch-order-of-libraries-for-mpath.patch
  0032-Make-installed-scripts-explicitly-p.patch
  - > 0025-Make-installed-scripts-explicitly-p.patch
  0035-tests-test-thread-pool-is-racy-add-.patch
  - > 0027-tests-test-thread-pool-is-racy-add-.patch
  0036-xen-add-block-resize-support-for-xe.patch
  - > 0028-xen-add-block-resize-support-for-xe.patch
  0037-tests-qemu-iotests-Triple-timeout-o.patch
  - > 0029-tests-qemu-iotests-Triple-timeout-o.patch
  0038-tests-block-io-test-130-needs-some-.patch
  - > 0030-tests-block-io-test-130-needs-some-.patch
  0040-xen-ignore-live-parameter-from-xen-.patch
  - > 0031-xen-ignore-live-parameter-from-xen-.patch
  0058-Revert-target-i386-kvm-add-VMX-migr.patch
  - > 0034-Revert-target-i386-kvm-add-VMX-migr.patch
  * Patches added:
  0026-hw-smbios-handle-both-file-formats-.patch
  0032-tests-Fix-Makefile-handling-of-chec.patch
  0033-Conditionalize-ui-bitmap-installati.patch
  0035-tests-change-error-message-in-test-.patch
  ipxe-efi-Avoid-string-op-warning-with-cross-gcc-7-compile.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-4.0
* Fri Mar 29 2019 Bruce Rogers <brogers@suse.com>
- Adjust fix for CVE-2019-8934 (bsc#1126455) to match the latest
  upstream adjustments for the same. Basically now the security fix
  is to provide a dummy host-model and host-serial value, which
  overrides getting that value from the host
  0065-spapr-Simplify-handling-of-host-ser.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
* Wed Mar 27 2019 Bruce Rogers <brogers@suse.com>
- Tweak last spec file change to guard new Requires with conditional
- Fix DOS possibility in device tree processing (CVE-2018-20815
  bsc#1130675)
  0064-device_tree.c-Don-t-use-load_image.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
* Mon Mar 25 2019 Bruce Rogers <brogers@suse.com>
- Remove an unneeded BuildRequires which impacts bsc#1119414 fix
  Also add a corresponding Recommends for qemu-tools as part of
  this packaging adjustment (bsc#1130484)
- Fix information leak in slirp (CVE-2019-9824 bsc#1129622)
  0061-slirp-check-sscanf-result-when-emul.patch
- Add method to specify whether or not to expose certain ppc64 host
  information, which can be considered a security issue
  (CVE-2019-8934 bsc#1126455)
  0062-ppc-add-host-serial-and-host-model-.patch
- Fix OOB memory access and information leak in virtual monitor
  interface (CVE-2019-03812 bsc#1125721)
  0063-i2c-ddc-fix-oob-read.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
* Fri Mar  8 2019 Bruce Rogers <brogers@suse.com>
- Again address ipxe GCC 9 incompatibilities. Previously included
  patch to disable unneeded warning got muffed somehow (bsc#1121464)
* Fri Feb 22 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Package and cross-build rom files for aarch64 from
  SLE15/Leap15.0 to fix boo#1125964
- Add patch to fix seabios cross-compilation:
  * seabios-fix_cross_compilation.patch
- Add patch to fix sgabios cross-compilation:
  * sgabios-fix-cross-build.patch
* Thu Feb 21 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix _constraints to include all architectures for disk size
  (fix aarch64)
* Fri Feb 15 2019 Bruce Rogers <brogers@suse.com>
- Revert upstream patch which declares x86 vmx feature a migration
  blocker. Given the proliferation of using vm's with host features
  passed through and the general knowledge that nested
  virtualization has many usage caveats, but still gets put in use
  in restricted scenarios, this patch did more harm than good, I
  feel. So despite this relaxation, please consider yourself warned
  that nested virtualization is not yet a supportable feature.
  (bsc#1121604)
  0058-Revert-target-i386-kvm-add-VMX-migr.patch
- Fix SEV VM device assignment (bsc#1123205)
  0059-memory-Fix-the-memory-region-type-a.patch
  0060-target-i386-sev-Do-not-pin-the-ram-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
* Mon Feb 11 2019 Bruce Rogers <brogers@suse.com>
- Remove 71-sev.rules, which modifies the default permissions of
  /dev/sev by adding the kvm group as reader/writer. Upstream
  decided to take a different approach for libvirt to manage SEV
  due to security concerns which I agree overrides the convenience
  of providing /dev/sev access to all the kvm group (bsc#1124842
  bsc#1102604)
* Fri Feb  1 2019 Bruce Rogers <brogers@suse.com>
- Increase memory needed to build qemu-testsuite for ppc* arch's
  in _constraints file
* Wed Jan 30 2019 Liang Yan <lyan@suse.com>
- Return specification exception for unimplemented diag 308 subcodes
  rather than a hardware error (bsc#1123179)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
  * Patches added:
  0057-s390x-Return-specification-exceptio.patch
* Fri Jan 25 2019 Bruce Rogers <brogers@suse.com>
- Fix OOB issue in slirp (CVE-2019-6778 bsc#1123156)
  0056-slirp-check-data-length-while-emula.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
- Fix ipxe GCC 9 incompatibilities (bsc#1121464)
  ipxe-efi-Simplify-diagnostic-for-NULL-handle.patch
  ipxe-build-Disable-gcc-address-of-packed-member-warning.patch
* Thu Jan 17 2019 Bruce Rogers <brogers@suse.com>
- Tweak Xen interface to be compatible with upcoming v4.12 Xen
  0055-xen-Add-xen-v4.12-based-xc_domain_c.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
* Tue Jan 15 2019 Liang Yan <lyan@suse.com>
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
  * Patches added:
  0054-linux-user-make-pwrite64-pread64-fd.patch
  (bsc#1121600)
* Mon Jan 14 2019 Bruce Rogers <brogers@suse.com>
- Clarify that move to include v3.1.0 in qemu package corresponds
  with fate#327089, which of course builds on v3.0.0 mentioned
  previously, and that among other patches which this change
  obsoletes (because functionality is included in base version) I
  will mention one pointed out by reviewers:
  0094-s390x-cpumodels-add-z14-Model-ZR1.patch
* Thu Jan 10 2019 Bruce Rogers <brogers@suse.com>
- include post v3.1.0 patches marked for next stable release:
  0041-vfio-ap-flag-as-compatible-with-bal.patch
  0042-hw-s390x-Fix-bad-mask-in-time2tod.patch
  0043-pcie-set-link-state-inactive-active.patch
  0044-pc-piix4-Update-smbus-I-O-space-aft.patch
  0045-hw-usb-fix-mistaken-de-initializati.patch
- Address various security/stability issues
  * Fix host access vulnerability in usb-mtp infrastructure
  (CVE-2018-16872 bsc#1119493)
  0046-usb-mtp-use-O_NOFOLLOW-and-O_CLOEXE.patch
  * Fix DoS in pvrdma interface (CVE-2018-20123 bsc#1119437)
  0047-pvrdma-release-device-resources-in-.patch
  * Fix OOB access issue in rdma backend (CVE-2018-20124 bsc#1119840)
  0048-rdma-check-num_sge-does-not-exceed-.patch
  * Fix NULL pointer reference in pvrdma emulation (CVE-2018-20191
  bsc#1119979)
  0049-pvrdma-add-uar_read-routine.patch
  * Fix DoS in pvrdma interface (CVE-2018-20125 bsc#1119989)
  0050-pvrdma-check-number-of-pages-when-c.patch
  * Fix DoS in pvrdma interface (CVE-2018-20216 bsc#1119984)
  0051-pvrdma-check-return-value-from-pvrd.patch
  * Fix DoS in pvrdma interface (CVE-2018-20126 bsc#1119991)
  0052-pvrdma-release-ring-object-in-case-.patch
- one more post v3.1.0 patches marked for next stable release:
  0053-block-Fix-hangs-in-synchronous-APIs.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
* Tue Jan  8 2019 olaf@aepfle.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
  * Patches added:
  0040-xen-ignore-live-parameter-from-xen-.patch
  (bsc#1079730, bsc#1101982, bsc#1063993)
* Fri Jan  4 2019 Bruce Rogers <brogers@suse.com>
- Follow up on ideas prompted by last change: clean up the patches
  generated by git workflow. There is no value to the first line
  (mbox From line), or [PATCH] on subject line. Get rid of those
- Other minor fixes and improvements to update_git.sh
* Thu Jan  3 2019 olaf@aepfle.de
- Modify update_git.sh script:
  pass --zero-commit to format-patch
  This removes needless noise in the buildservice when the same set
  of patches is imported/exported at different times by different users.
  pass --no-signature to format-patch
  Remove sed call which used to remove the signature, use mv instead
* Fri Dec 14 2018 lma@suse.com
- Use /bin/bash to echo value into sys fs for ksm control (bsc#1112646)
* Wed Dec 12 2018 Bruce Rogers <brogers@suse.com>
- fix memory leak in xen_disk (bsc#1100408)
  0039-xen_disk-Avoid-repeated-memory-allo.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
* Wed Dec 12 2018 olaf@aepfle.de
- building against xen-devel requires the XC_* compat macros to be
  set because this version of QEMU will be built against many
  versions of Xen. configure will decide on the appropriate function
  names it knows about today. To actually call these functions,
  future versions of Xen may require XC_* to be set.
  Furthermore, fix a bug in QEMU: xen_common.h undefines the XC_*
  macros unconditionally.
* Tue Dec 11 2018 Bruce Rogers <brogers@suse.com>
- Update to v3.1.0: See http://wiki.qemu.org/ChangeLog/3.1
  Take note that ongoing feature deprecation is tracked at both
  http://wiki.qemu-project.org/Features/LegacyRemoval and in
  Appendix B of the qemu-doc.* files installed with the qemu package
  Some noteworthy changes:
  * x86 IceLake-Server and IceLake-Client cpu models added
  * Document recommendations for choosing cpu modesl for x86 guests
  * Support for Hyper-V enlightened VMCS
  * stdvga and bochs-display devices can expose EDID information to the
  guest. stdvga xres and yres properties are exposed in the EDID information
  * s390 improvements: vfio-ap crypto device support, max-cpu model added,
  etoken support, huge page backing support
  * ARM: ARMv6M architecture and Cortex-M0 cpu host support added,
  Cortex-A72 cpu model added, GICv2 virtualization extensions, emulation
  of AArch32 virtualization, Scalable Vector Extension implemented
  * Support for AMD IOMMU interrupt remapping and guest virtual APIC mode
  * Multithreaded TCG on x86 is considered supportable
  * Add a patch to triple timeout of block io tests, since the obs
  environment is fickle
  * x86 save/restore and live migration is prohibited if Intel KVM nested
  virtualization is enabled
  * Patches dropped (upstream unless otherwise noted):
  0033-migration-warn-about-inconsistent-s.patch (shouldn't be needed anymore)
  0035-configure-Modify-python-used-for-io.patch (upstream now python3 friendly)
  0039-tests-boot-serial-test-Bump-timeout.patch
  0040-linux-headers-update.patch
  0041-s390x-kvm-add-etoken-facility.patch
  0042-seccomp-prefer-SCMP_ACT_KILL_PROCES.patch
  0043-configure-require-libseccomp-2.2.0.patch
  0044-seccomp-set-the-seccomp-filter-to-a.patch
  0045-sandbox-disable-sandbox-if-CONFIG_S.patch
  0046-seccomp-check-TSYNC-host-capability.patch
  0047-linux-user-init_guest_space-Try-to-.patch
  0048-ne2000-fix-possible-out-of-bound-ac.patch
  0049-rtl8139-fix-possible-out-of-bound-a.patch
  0050-pcnet-fix-possible-buffer-overflow.patch
  0051-net-ignore-packet-size-greater-than.patch
  0052-lsi53c895a-check-message-length-val.patch
  0053-nvme-fix-oob-access-issue-CVE-2018-.patch (fixed differently upstream)
  * Patches renamed:
  0034-smbios-Add-1-terminator-if-any-stri.patch
  - > 0033-smbios-Add-1-terminator-if-any-stri.patch
  0036-qemu-io-tests-comment-out-problemat.patch
  - > 0034-qemu-io-tests-comment-out-problemat.patch
  0037-tests-test-thread-pool-is-racy-add-.patch
  - > 0035-tests-test-thread-pool-is-racy-add-.patch
  0038-xen-add-block-resize-support-for-xe.patch
  - > 0036-xen-add-block-resize-support-for-xe.patch
  * Patches added:
  0037-tests-qemu-iotests-Triple-timeout-o.patch
  0038-tests-block-io-test-130-needs-some-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.1
- Update includes the following bug fixes: bsc#1108474, bsc#1117615
- Update includes the following SLE requested functionality: FATE#324810,
  FATE#325875, FATE#326369, FATE#326378, FATE#326379, FATE#326401,
  FATE#326672, FATE#326829
- Make the following packaging changes related to the new release
  * Enable libpmem, pvrdma, vhost-crypto features and qemu-block-nfs
  subpackage
  * New roms available: vgabios-bochs-display.bin, vgabios-ramfb.bin
  * New binary tool included (qemu-edid) for testing the new qemu edid
  generator
- Tweaked patches we carry to pass qemu's checkpatch checker
- Modify update_git.sh script to enable packaging qemu from development
  time sources, not just at release time
- Removed erroneous (and now useless) tests for tar and gzip formats
- Don't exclude s390x anymore from building the qemu-testsuite
- Based on current OBS building observations make changes to storage
  and memory requires specified in the _constraints file
* Thu Nov  8 2018 Bruce Rogers <brogers@suse.com>
- Re-sync openSUSE and SUSE SLE qemu packages. This changes file
  is the openSUSE one with this entry providing the intervening
  SLE CVE, FATE, and bugzilla references, which are still addressed
  in this package, and not yet called out in this changes file.
  * CVE-2018-10839 CVE-2018-16847 CVE-2018-17958 CVE-2018-17962
  CVE-2018-17963 CVE-2018-18849
  * bsc#1110910 bsc#1111006 bsc#1111010 bsc#1111013 bsc#1114422
  bsc#1114529
  * Patches added:
  0047-linux-user-init_guest_space-Try-to-.patch
  0048-ne2000-fix-possible-out-of-bound-ac.patch
  0049-rtl8139-fix-possible-out-of-bound-a.patch
  0050-pcnet-fix-possible-buffer-overflow.patch
  0051-net-ignore-packet-size-greater-than.patch
  0052-lsi53c895a-check-message-length-val.patch
  0053-nvme-fix-oob-access-issue-CVE-2018-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.0
* Fri Oct  5 2018 Larry Dewey <ldewey@suse.com>
  * Adding changes to mitigate seccomp vulnerability
  (CVE-2018-15746 bsc#1106222)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.0
  * Patches added:
  0042-seccomp-prefer-SCMP_ACT_KILL_PROCES.patch
  0043-configure-require-libseccomp-2.2.0.patch
  0044-seccomp-set-the-seccomp-filter-to-a.patch
  0045-sandbox-disable-sandbox-if-CONFIG_S.patch
  0046-seccomp-check-TSYNC-host-capability.patch
* Mon Sep 24 2018 Bruce Rogers <brogers@suse.com>
- Do more misc spec file fixes:
  * Be explicit in spec file about Version used for all subpackages
  (again, to avoid subpackage ordering issues). Default Release
  tag is also brought in by obs format_spec_file service
  * Delete binary blob s390-netboot.img, which we rebuild
  * Don't provide separate Url for qemu-kvm package - the main qemu
  website provides easily findable link for kvm specifics
  * Associate petalogix-ml605.dtb with qemu-extra instead of qemu-ppc
  * More entry sorting
* Fri Sep 21 2018 Bruce Rogers <brogers@suse.com>
- Correct some versioning as follows:
  * Accurately reflect the qemu-ipxe package version value by adding
  "+" at the end
  * Don't overwrite seabios .version file, since now (for quite some
  time actually) upstream tarball creation creates this file and
  the value we are writing to it is actually wrong
- Make spec file improvements, including the following:
  * Add qemu.keyring to enable package source verification
  * Create srcname macro to identify source file name separately from
  package name
  * Create alternate to %%version to avoid subpackage ordering
  causing inadvertantly wrong %%version value at point of use
  * Sort some entries
  * Be more consistent with macro syntax usage
  * Minor file tweaks as done by osc format_spec_file service
* Fri Sep 14 2018 Bruce Rogers <brogers@suse.com>
- Re-sync openSUSE and SUSE SLE qemu packages. This changes file
  is the openSUSE one with this entry providing the intervening
  SLE CVE, FATE, and bugzilla references, which are still addressed
  in this package, and not yet called out in this changes file.
  * CVE-2018-11806 CVE-2018-12617 CVE-2018-7550 CVE-2018-15746
  * fate#325467
  * bsc#1091695 bsc#1094725 bsc#1094913 bsc#1096223 bsc#1098735
  bsc#1103628 bsc#1105279 bsc#1106222 bsc#1106222 bsc#1107489
  * Patches added:
  * only enable glusterfs for openSUSE
  0040-linux-headers-update.patch
  0041-s390x-kvm-add-etoken-facility.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.0
* Mon Aug 20 2018 brogers@suse.com
- Increase timeout for boot-serial-test, since we've hit the timeout
  for armv7l arch in qemu-testsuite.
  0039-tests-boot-serial-test-Bump-timeout.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.0
* Wed Aug 15 2018 brogers@suse.com
- Drop legacy kvm_stat script and man page. We'll rely on the kvm_stat
  package only going forward
  kvm_stat
  kvm_stat.1.gz
- Update SLE support documentation to match v3.0.0 release
* Tue Aug 14 2018 brogers@suse.com
- Update to v3.0.0: See http://wiki.qemu.org/ChangeLog/3.0
  Don't read anything into the major version number update. It's
  been decided to increase the major version number each year.
  Take note that ongoing feature deprecation is tracked at both
  http://wiki.qemu-project.org/Features/LegacyRemoval and in
  Appendix B of the qemu-doc.* files installed with the qemu package.
  Some noteworthy changes:
  * Support for additional x86/AMD mitigations against Speculative
  Store Bypass (Spectre Variant 4, CVE-2018-3639)
  * Improved support for nested KVM guests running on Hyper-V
  * Block device support for active disk-mirroring, which avoids
  convergence issues which may arise when doing passive/background
  mirroring of busy devices
  * Improved support for AHCI emulation, SCSI emulation, and persistent
  reservations / cluster management
  * OpenGL ES support for SDL front-end, additional framebuffer
  device options for early boot display without using legacy VGA
  emulation
  * Live migration support for TPM TIS devices, capping bandwidth
  usage during post-copy migration, and recovering from a failed
  post-copy migration
  * Improved latency when using user-mode networking / SLIRP
  * ARM: support for SMMUv3 IOMMU when using 'virt' machine type
  * ARM: v8M extensions for VLLDM and VLSTM floating-point instructions,
  and improved support for AArch64 v8.2 FP16 extensions
  * ARM: support for Scalable Vector Extensions in linux-user mode
  * Microblaze: support for 64-bit address sizes and translation bug
  fixes
  * PowerPC: PMU support for mac99 machine type and improvements for
  Uninorth PCI host bridge emulation for Mac machine types
  * PowerPC: preliminary support for emulating POWER9 hash MMU mode when
  using powernv machine type
  * RISC-V: improvement for privileged ISA emulation
  * s390: support for z14 ZR1 CPU model
  * s390: bpb/ppa15 Spectre mitigations enabled by default for z196 and
  later CPU models
  * s390: support for configuring consoles via -serial options
  * Patches dropped (upstream unless otherwise noted):
  0008-linux-user-fix-segfault-deadlock.patch (no longer needed)
  0039-blockjob-Fix-assertion-in-block_job.patch
  0041-seccomp-allow-sched_setscheduler-wi.patch
  Make-installed-scripts-explicitly-python3.patch (we now make
  python3 explicit in other patch)
  * Patches renamed:
  0009-linux-user-binfmt-support-host-bina.patch
  - > 0008-linux-user-binfmt-support-host-bina.patch
  0010-linux-user-Fake-proc-cpuinfo.patch
  - > 0009-linux-user-Fake-proc-cpuinfo.patch
  0011-Remove-problematic-evdev-86-key-fro.patch
  - > 0010-Remove-problematic-evdev-86-key-fro.patch
  0012-linux-user-use-target_ulong.patch
  - > 0011-linux-user-use-target_ulong.patch
  0013-Make-char-muxer-more-robust-wrt-sma.patch
  - > 0012-Make-char-muxer-more-robust-wrt-sma.patch
  0014-linux-user-lseek-explicitly-cast-no.patch
  - > 0013-linux-user-lseek-explicitly-cast-no.patch
  0015-AIO-Reduce-number-of-threads-for-32.patch
  - > 0014-AIO-Reduce-number-of-threads-for-32.patch
  0016-xen_disk-Add-suse-specific-flush-di.patch
  - > 0015-xen_disk-Add-suse-specific-flush-di.patch
  0017-qemu-bridge-helper-reduce-security-.patch
  - > 0016-qemu-bridge-helper-reduce-security-.patch
  0018-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  - > 0017-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  0019-linux-user-properly-test-for-infini.patch
  - > 0018-linux-user-properly-test-for-infini.patch
  0020-roms-Makefile-pass-a-packaging-time.patch
  - > 0019-roms-Makefile-pass-a-packaging-time.patch
  0021-Raise-soft-address-space-limit-to-h.patch
  - > 0020-Raise-soft-address-space-limit-to-h.patch
  0022-increase-x86_64-physical-bits-to-42.patch
  - > 0021-increase-x86_64-physical-bits-to-42.patch
  0023-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  - > 0022-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0024-i8254-Fix-migration-from-SLE11-SP2.patch
  - > 0023-i8254-Fix-migration-from-SLE11-SP2.patch
  0025-acpi_piix4-Fix-migration-from-SLE11.patch
  - > 0024-acpi_piix4-Fix-migration-from-SLE11.patch
  0026-Fix-tigervnc-long-press-issue.patch
  - > 0025-Fix-tigervnc-long-press-issue.patch
  0027-string-input-visitor-Fix-uint64-par.patch
  - > 0026-string-input-visitor-Fix-uint64-par.patch
  0028-test-string-input-visitor-Add-int-t.patch
  - > 0027-test-string-input-visitor-Add-int-t.patch
  0029-test-string-input-visitor-Add-uint6.patch
  - > 0028-test-string-input-visitor-Add-uint6.patch
  0030-tests-Add-QOM-property-unit-tests.patch
  - > 0029-tests-Add-QOM-property-unit-tests.patch
  0031-tests-Add-scsi-disk-test.patch
  - > 0030-tests-Add-scsi-disk-test.patch
  0032-Switch-order-of-libraries-for-mpath.patch
  - > 0031-Switch-order-of-libraries-for-mpath.patch
  0033-Make-installed-scripts-explicitly-p.patch
  - > 0032-Make-installed-scripts-explicitly-p.patch (python2->python3)
  0034-migration-warn-about-inconsistent-s.patch
  - > 0033-migration-warn-about-inconsistent-s.patch
  0035-smbios-Add-1-terminator-if-any-stri.patch
  - > 0034-smbios-Add-1-terminator-if-any-stri.patch
  0036-configure-Modify-python-used-for-io.patch
  - > 0035-configure-Modify-python-used-for-io.patch
  0037-qemu-io-tests-comment-out-problemat.patch
  - > 0036-qemu-io-tests-comment-out-problemat.patch
  0038-tests-test-thread-pool-is-racy-add-.patch
  - > 0037-tests-test-thread-pool-is-racy-add-.patch
  0040-xen-add-block-resize-support-for-xe.patch
  - > 0038-xen-add-block-resize-support-for-xe.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-3.0
* Thu Aug  9 2018 ldewey@suse.com
- Update QEMU to allow kvm group access to /dev/sev (bsc#1102604).
  71-sev.rules
* Fri Aug  3 2018 brogers@suse.com
- Update to v2.12.1, a stable, (mostly) bug-fix-only release
  * This update contains new mitigation functionality for
  CVE-2018-3639 (Speculative Store Bypass) in x86. There are also
  bug fixes for migration, Intel IOMMU emulation, block layer/image
  handling, ARM emulation, and various other areas.
  (Note that a number of 2.12.1 patches were already included by us
  previously) (CVE-2018-3639 bsc#1092885)
  * Patches dropped (subsumed by stable update):
  0039-device_tree-Increase-FDT_MAX_SIZE-t.patch
  0040-vnc-fix-use-after-free.patch
  0041-ccid-Fix-dwProtocols-advertisement-.patch
  0042-tcg-arm-Fix-memory-barrier-encoding.patch
  0043-s390-ccw-force-diag-308-subcode-to-.patch
  0044-nbd-client-fix-nbd_negotiate_simple.patch
  0045-migration-block-dirty-bitmap-fix-me.patch
  0046-nbd-client-Fix-error-messages-durin.patch
  0047-nbd-client-Relax-handling-of-large-.patch
  0048-qxl-fix-local-renderer-crash.patch
  0049-tcg-Limit-the-number-of-ops-in-a-TB.patch
  0050-target-arm-Clear-SVE-high-bits-for-.patch
  0051-cpus-tcg-fix-never-exiting-loop-on-.patch
  0052-s390x-css-disabled-subchannels-cann.patch
  0053-pc-bios-s390-ccw-struct-tpi_info-mu.patch
  0054-virtio-ccw-common-reset-handler.patch
  0055-s390x-ccw-make-sure-all-ccw-devices.patch
  0056-blockjob-expose-error-string-via-qu.patch
  0058-qemu-io-Use-purely-string-blockdev-.patch
  0059-qemu-img-Use-only-string-options-in.patch
  0060-nfs-Remove-processed-options-from-Q.patch
  0061-i386-define-the-ssbd-CPUID-feature-.patch
  0062-i386-Define-the-Virt-SSBD-MSR-and-h.patch
  0063-i386-define-the-AMD-virt-ssbd-CPUID.patch
  0064-ahci-fix-PxCI-register-race.patch
  0065-ccid-card-passthru-fix-regression-i.patch
  * Patches renamed:
  0057-blockjob-Fix-assertion-in-block_job.patch
  - > 0039-blockjob-Fix-assertion-in-block_job.patch
  0066-xen-add-block-resize-support-for-xe.patch
  - > 0040-xen-add-block-resize-support-for-xe.patch
  0067-seccomp-allow-sched_setscheduler-wi.patch
  - > 0041-seccomp-allow-sched_setscheduler-wi.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.12
* Wed Jul 25 2018 ldewey@suse.com
- Fixing seccomp resourcecontrol defunct issue (bsc#1102627)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.12
  * Patches added:
  0067-seccomp-allow-sched_setscheduler-wi.patch
* Wed Jul 25 2018 matz@suse.com
- Add ipxe-fix-build.patch to not error out with
  binutils >= 2.31 .
* Thu Jul  5 2018 brogers@suse.com
- Remove linux-user patch which is no longer needed (bsc#1098056)
  * Patches dropped:
  0011-linux-user-XXX-disable-fiemap.patch
  * Patches renamed:
  0036-Remove-problematic-evdev-86-key-fro.patch
  - > 0011-Remove-problematic-evdev-86-key-fro.patch
  0037-configure-Modify-python-used-for-io.patch
  - > 0036-configure-Modify-python-used-for-io.patch
  0038-qemu-io-tests-comment-out-problemat.patch
  - > 0037-qemu-io-tests-comment-out-problemat.patch
  0039-tests-test-thread-pool-is-racy-add-.patch
  - > 0038-tests-test-thread-pool-is-racy-add-.patch
  0040-device_tree-Increase-FDT_MAX_SIZE-t.patch
  - > 0039-device_tree-Increase-FDT_MAX_SIZE-t.patch
  0041-vnc-fix-use-after-free.patch
  - > 0040-vnc-fix-use-after-free.patch
  0042-ccid-Fix-dwProtocols-advertisement-.patch
  - > 0041-ccid-Fix-dwProtocols-advertisement-.patch
  0043-tcg-arm-Fix-memory-barrier-encoding.patch
  - > 0042-tcg-arm-Fix-memory-barrier-encoding.patch
  0044-s390-ccw-force-diag-308-subcode-to-.patch
  - > 0043-s390-ccw-force-diag-308-subcode-to-.patch
  0045-nbd-client-fix-nbd_negotiate_simple.patch
  - > 0044-nbd-client-fix-nbd_negotiate_simple.patch
  0046-migration-block-dirty-bitmap-fix-me.patch
  - > 0045-migration-block-dirty-bitmap-fix-me.patch
  0047-nbd-client-Fix-error-messages-durin.patch
  - > 0046-nbd-client-Fix-error-messages-durin.patch
  0048-nbd-client-Relax-handling-of-large-.patch
  - > 0047-nbd-client-Relax-handling-of-large-.patch
  0049-qxl-fix-local-renderer-crash.patch
  - > 0048-qxl-fix-local-renderer-crash.patch
  0050-tcg-Limit-the-number-of-ops-in-a-TB.patch
  - > 0049-tcg-Limit-the-number-of-ops-in-a-TB.patch
  0051-target-arm-Clear-SVE-high-bits-for-.patch
  - > 0050-target-arm-Clear-SVE-high-bits-for-.patch
  0052-cpus-tcg-fix-never-exiting-loop-on-.patch
  - > 0051-cpus-tcg-fix-never-exiting-loop-on-.patch
  0053-s390x-css-disabled-subchannels-cann.patch
  - > 0052-s390x-css-disabled-subchannels-cann.patch
  0054-pc-bios-s390-ccw-struct-tpi_info-mu.patch
  - > 0053-pc-bios-s390-ccw-struct-tpi_info-mu.patch
  0055-virtio-ccw-common-reset-handler.patch
  - > 0054-virtio-ccw-common-reset-handler.patch
  0056-s390x-ccw-make-sure-all-ccw-devices.patch
  - > 0055-s390x-ccw-make-sure-all-ccw-devices.patch
  0057-blockjob-expose-error-string-via-qu.patch
  - > 0056-blockjob-expose-error-string-via-qu.patch
  0058-blockjob-Fix-assertion-in-block_job.patch
  - > 0057-blockjob-Fix-assertion-in-block_job.patch
  0059-qemu-io-Use-purely-string-blockdev-.patch
  - > 0058-qemu-io-Use-purely-string-blockdev-.patch
  0060-qemu-img-Use-only-string-options-in.patch
  - > 0059-qemu-img-Use-only-string-options-in.patch
  0061-nfs-Remove-processed-options-from-Q.patch
  - > 0060-nfs-Remove-processed-options-from-Q.patch
  0062-i386-define-the-ssbd-CPUID-feature-.patch
  - > 0061-i386-define-the-ssbd-CPUID-feature-.patch
  0063-i386-Define-the-Virt-SSBD-MSR-and-h.patch
  - > 0062-i386-Define-the-Virt-SSBD-MSR-and-h.patch
  0064-i386-define-the-AMD-virt-ssbd-CPUID.patch
  - > 0063-i386-define-the-AMD-virt-ssbd-CPUID.patch
  0065-ahci-fix-PxCI-register-race.patch
  - > 0064-ahci-fix-PxCI-register-race.patch
  0066-ccid-card-passthru-fix-regression-i.patch
  - > 0065-ccid-card-passthru-fix-regression-i.patch
  0067-xen-add-block-resize-support-for-xe.patch
  - > 0066-xen-add-block-resize-support-for-xe.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.12
* Thu Jul  5 2018 brogers@suse.com
- Fix build failure of skiboot with gcc8 compiler
  skiboot-hdata-i2c.c-fix-building-with-gcc8.patch
* Thu Jul  5 2018 brogers@suse.com
- Tweak build service constraints information to avoid failures
* Fri Jun  8 2018 brogers@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.12
  * Patches added:
  0067-xen-add-block-resize-support-for-xe.patch
* Thu Jun  7 2018 brogers@suse.com
- Tweak patch file generation to be more git version agnostic.
  Also change update_git.sh to not reformat spec file by default.
* Thu May 31 2018 brogers@suse.com
- Looks like the right fix for the AHCI issue has been identified
  upstream. Turns out to also affect Linux guests as well.
  (bsc#1094406)
  * Patches dropped:
  0065-Revert-replay-don-t-process-async-e.patch
  0066-Revert-replay-avoid-recursive-call-.patch
  0067-Revert-replay-check-return-values-o.patch
  0068-Revert-replay-push-replay_mutex_loc.patch
  * Patches added:
  0065-ahci-fix-PxCI-register-race.patch
- Fix a regresssion introduced in v2.12.0 for ccid-card-passthrough
  (bsc#1095419)
  0066-ccid-card-passthru-fix-regression-i.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.12
* Tue May 29 2018 lma@suse.com
- Fix qemu-guest-agent service issue (bsc#1094898)
* Fri May 25 2018 brogers@suse.com
- Spectre v4 vulnerability mitigation support for KVM guests.
  High level description of vulnerability: Systems with microprocessors
  utilizing speculative execution and speculative execution of memory
  reads before the addresses of all prior memory writes are known may
  allow unauthorized disclosure of information to an attacker with
  local user access via a side-channel analysis.
  This change permits the new x86 cpu feature flag named "ssbd" to be
  presented to the guest, given that the host has this feature, and
  KVM exposes it to the guest as well.
  For this feature to be enabled, via adding it to the qemu commandline
  (eg: -cpu <model>,+spec-ctrl,+ssbd), so the guest OS can take advantage
  of the feature, spec-ctrl and ssbd support is also required in the host.
  Another new x86 cpu feature flag named "virt-ssbd" is also added to
  handle this vulnerability for AMD processors.
  (CVE-2018-3639 bsc#1092885)
  0062-i386-define-the-ssbd-CPUID-feature-.patch
  0063-i386-Define-the-Virt-SSBD-MSR-and-h.patch
  0064-i386-define-the-AMD-virt-ssbd-CPUID.patch
- Replay code introduced an issue for AHCI emulation, where on Windows 10
  I/O would stop randomly, and Windows would then reset the AHCI device.
  The issue is not yet fully identified, but reverting some of those
  changes is at least for now a workaround. (bsc#1094406)
  0065-Revert-replay-don-t-process-async-e.patch
  0066-Revert-replay-avoid-recursive-call-.patch
  0067-Revert-replay-check-return-values-o.patch
  0068-Revert-replay-push-replay_mutex_loc.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.12
* Thu May 17 2018 brogers@suse.com
- Add some upstream fixes targeted for the next stable release
  0040-device_tree-Increase-FDT_MAX_SIZE-t.patch
  0041-vnc-fix-use-after-free.patch
  0042-ccid-Fix-dwProtocols-advertisement-.patch
  0043-tcg-arm-Fix-memory-barrier-encoding.patch
  0044-s390-ccw-force-diag-308-subcode-to-.patch
  0045-nbd-client-fix-nbd_negotiate_simple.patch
  0046-migration-block-dirty-bitmap-fix-me.patch
  0047-nbd-client-Fix-error-messages-durin.patch
  0048-nbd-client-Relax-handling-of-large-.patch
  0049-qxl-fix-local-renderer-crash.patch
  0050-tcg-Limit-the-number-of-ops-in-a-TB.patch
  0051-target-arm-Clear-SVE-high-bits-for-.patch
  0052-cpus-tcg-fix-never-exiting-loop-on-.patch
  0053-s390x-css-disabled-subchannels-cann.patch
  0054-pc-bios-s390-ccw-struct-tpi_info-mu.patch
  0055-virtio-ccw-common-reset-handler.patch
  0056-s390x-ccw-make-sure-all-ccw-devices.patch
  0057-blockjob-expose-error-string-via-qu.patch
  0058-blockjob-Fix-assertion-in-block_job.patch
  0059-qemu-io-Use-purely-string-blockdev-.patch
  0060-qemu-img-Use-only-string-options-in.patch
  0061-nfs-Remove-processed-options-from-Q.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.12
* Wed May 16 2018 brogers@suse.com
- Fix qemu-guest-agent uninstall (bsc#1093169)
- Minor tweak to qemu spec file
* Fri Apr 27 2018 brogers@suse.com
- Update to v2.12.0: See http://wiki.qemu.org/ChangeLog/2.12
  Some noteworthy changes:
  CLI options removed: -tdf, -no-kvm-pit, -drive boot, -net channel,
  - net dump, -hdachs, -drive,if=scsi
  HMP commands removed: usb_add, usb_del, host_net_add, host_net_remove
  Q35 default nic now e1000e
  AMD SEV support
  - smbios supports setting data for type 11 tables
  audio and display support split out as modules
  - nic for simple creation of guest NIC and host back-end
  QMP monitor "out-of-band" capability
  lots of ARM and s390 improvements
- Include more of upstream's in-tree tests in the qemu-testsuite
  package
  * Patches dropped:
  0033-memfd-fix-configure-test.patch
  0034-qapi-use-items-values-intead-of-ite.patch
  0035-qapi-Use-OrderedDict-from-standard-.patch
  0036-qapi-adapt-to-moved-location-of-Str.patch
  0037-qapi-Adapt-to-moved-location-of-mak.patch
  0038-qapi-remove-q-arg-to-diff-when-comp.patch
  0039-qapi-ensure-stable-sort-ordering-wh.patch
  0040-qapi-force-a-UTF-8-locale-for-runni.patch
  0041-scripts-ensure-signrom-treats-data-.patch
  0042-configure-allow-use-of-python-3.patch
  0043-input-add-missing-JIS-keys-to-virti.patch
  0045-pc-fail-memory-hot-plug-unplug-with.patch
  0046-memattrs-add-debug-attribute.patch
  0047-exec-add-ram_debug_ops-support.patch
  0048-exec-add-debug-version-of-physical-.patch
  0049-monitor-i386-use-debug-APIs-when-ac.patch
  0050-machine-add-memory-encryption-prope.patch
  0051-kvm-update-kvm.h-to-include-memory-.patch
  0052-docs-add-AMD-Secure-Encrypted-Virtu.patch
  0053-target-i386-add-Secure-Encrypted-Vi.patch
  0054-qmp-add-query-sev-command.patch
  0055-sev-i386-add-command-to-initialize-.patch
  0056-qmp-populate-SevInfo-fields-with-SE.patch
  0057-sev-i386-register-the-guest-memory-.patch
  0058-kvm-introduce-memory-encryption-API.patch
  0059-hmp-add-info-sev-command.patch
  0060-sev-i386-add-command-to-create-laun.patch
  0061-sev-i386-add-command-to-encrypt-gue.patch
  0062-target-i386-encrypt-bios-rom.patch
  0063-sev-i386-add-support-to-LAUNCH_MEAS.patch
  0064-sev-i386-finalize-the-SEV-guest-lau.patch
  0065-hw-i386-set-ram_debug_ops-when-memo.patch
  0066-sev-i386-add-debug-encrypt-and-decr.patch
  0067-target-i386-clear-C-bit-when-walkin.patch
  0068-include-add-psp-sev.h-header-file.patch
  0069-sev-i386-add-support-to-query-PLATF.patch
  0070-sev-i386-add-support-to-KVM_SEV_GUE.patch
  0071-qmp-add-query-sev-launch-measure-co.patch
  0072-tests-qmp-test-blacklist-query-sev-.patch
  0073-sev-i386-add-migration-blocker.patch
  0074-cpu-i386-populate-CPUID-0x8000_001F.patch
  0075-migration-warn-about-inconsistent-s.patch
  0076-smbios-support-setting-OEM-strings-.patch
  0077-smbios-Add-1-terminator-if-any-stri.patch
  0078-Remove-problematic-evdev-86-key-fro.patch
  0079-tpm-lookup-cancel-path-under-tpm-de.patch
  0080-vga-fix-region-calculation.patch
  skiboot-GCC7-fixes-for-Wimplicit-fallthr.patch
  skiboot-libc-stdio-vsnprintf.c-add-expli.patch
  skiboot-build-LDFLAGS-pass-pie-flag-explicitly-to-ld.patch
  ui-keycodemapdb-Add-missing-QKeyCode-val.patch
  ui-keycodemapdb-Fix-compat-with-py3-dict.patch
  * Patches renamed:
  0044-Make-installed-scripts-explicitly-p.patch
  - > 0033-Make-installed-scripts-explicitly-p.patch
  0075-migration-warn-about-inconsistent-s.patch
  - > 0034-migration-warn-about-inconsistent-s.patch
  0077-smbios-Add-1-terminator-if-any-stri.patch
  - > 0035-smbios-Add-1-terminator-if-any-stri.patch
  0078-Remove-problematic-evdev-86-key-fro.patch
  - > 0036-Remove-problematic-evdev-86-key-fro.patch
  * Patches added:
  0037-configure-Modify-python-used-for-io.patch
  0038-qemu-io-tests-comment-out-problemat.patch
  0039-tests-test-thread-pool-is-racy-add-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.12
* Fri Apr 27 2018 brogers@suse.com
- Fix autoinstall of qemu-guest-agent by getting the modalias string
  right (bsc#1091143)
* Thu Apr 26 2018 brogers@suse.com
- Guard strncpy call with GCC pragma to disable warning about possible
  incorrect usage, when in fact it is correct. This is for gcc 8
  compatibility (bsc#1090355)
  ipxe-efi-guard-strncpy-with-gcc-warning-ignore-pragma.patch
* Mon Apr 23 2018 lma@suse.com
- Add WantedBy for enable qemu-ga@.service auto start (bsc#1090369)
* Tue Apr 10 2018 kwalter@suse.com
- fix qemu-ga service file name (bsc#1089067)
* Thu Apr  5 2018 brogers@suse.com
- Fix OOB access in VGA emulation (CVE-2018-7858 bsc#1084604)
  0080-vga-fix-region-calculation.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
* Thu Apr  5 2018 lyan@suse.com
- Add new look up path "sys/class/tpm" for tpm cancel path based
  on Linux 4.0 change (commit 313d21eeab9282e)(bsc#1070615)
  0079-tpm-lookup-cancel-path-under-tpm-de.patch
* Wed Mar 14 2018 brogers@suse.com
- Fix issue with key codes in qemu v2.11
  0078-Remove-problematic-evdev-86-key-fro.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
* Wed Mar 14 2018 lma@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
  * Patches added:
  0077-smbios-Add-1-terminator-if-any-stri.patch
  bsc#994082 and bsc#1084316
* Fri Mar  9 2018 brogers@suse.com
- Add support for setting OEM strings table (fate#323624)
  0076-smbios-support-setting-OEM-strings-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
* Sat Mar  3 2018 brogers@suse.com
- SLE15 KVM (as targeted for RC1) now has the feature exposed.
  Drop the patch. (bsc#1082276)
  0076-i386-Compensate-for-KVM-SPEC_CTRL-f.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
* Fri Mar  2 2018 brogers@suse.com
- Change example qemu-ifup script to not depend on bridge-utils.
  Also update the paths used for ip binary.
* Wed Feb 28 2018 brogers@suse.com
- Eliminate bogus use of CPUID_7_0_EDX_PRED_CMD which we've
  carried since the initial Spectre v2 patch was added. EDX bit
  27 of CPUID Leaf 07H, Sub-leaf 0 provides status on STIBP, and
  not the PRED_CMD MSR. Exposing the STIBP CPUID feature bit to the
  guest is wrong in general, since the VM doesn't directly control
  the scheduling of physical hyperthreads. This is left strictly to
  the L0 hypervisor.
* Thu Feb 22 2018 brogers@suse.com
- Update to v2.11.1, a stable, (mostly) bug-fix-only release
  In addition to bug fixes, of necessity fixes are needed to
  address the Spectre v2 vulnerability by passing along to the
  guest new hardware features introduced by host microcode updates.
  A January 2018 release of qemu initially addressed this issue
  by exposing the feature for all x86 vcpu types, which was the
  quick and dirty approach, but not the proper solution. We remove
  that initial patch and now rely on the upstream solution. This
  update instead defines spec_ctrl and ibpb cpu feature flags as
  well as new cpu models which are clones of existing models with
  either -IBRS or -IBPB added to the end of the model name. These
  new vcpu models explicitly include the new feature(s), whereas
  the feature flags can be added to the cpu parameter as with other
  features.  In short, for continued Spectre v2 protection, ensure
  that either the appropriate cpu feature flag is added to the QEMU
  command-line, or one of the new cpu models is used. Although
  migration from older versions is supported, the new cpu features
  won't be properly exposed to the guest until it is restarted with
  the cpu features explicitly added. A reboot is insufficient.
  A warning patch is added which attempts to detect a migration
  from a qemu version which had the quick and dirty fix (it only
  detects certain cases, but hopefully is helpful.)
  s390x guest vulnerability to Spectre v2 is also addressed in this
  update by including support for bpb and ppa/stfle.81 features.
  (CVE-2017-5715 bsc#1068032)
  For additional information on Spectre v2 as it relates to QEMU,
  see: https://www.qemu.org/2018/02/14/qemu-2-11-1-and-spectre-update/
- Unfortunately, it was found that our current KVM isn't correctly
  indicating support for the spec-ctrl feature, so I've added a patch
  to still detect that support within QEMU. This is of course a
  temporary kludge until KVM gets fixed. (bsc#1082276)
- The SEV support patches are updated to the v9 series.
- Fix incompatibility with recent glibc (boo#1081154)
- Add Supplements tags for the guest agent package in an attempt to
  auto-install for QEMU and Xen SUSE Linux guests (fate#323570)
  * Patches dropped (subsumed by stable update, or reworked in v9):
  0033-i386-kvm-MSR_IA32_SPEC_CTRL-and-MSR.patch
  0050-target-i386-add-memory-encryption-f.patch
  0054-accel-add-Secure-Encrypted-Virtuliz.patch
  0072-sev-Fix-build-for-non-x86-hosts.patch
  * Patches added:
  0033-memfd-fix-configure-test.patch
  0053-target-i386-add-Secure-Encrypted-Vi.patch
  0056-qmp-populate-SevInfo-fields-with-SE.patch
  0072-tests-qmp-test-blacklist-query-sev-.patch
  0073-sev-i386-add-migration-blocker.patch
  0074-cpu-i386-populate-CPUID-0x8000_001F.patch
  0075-migration-warn-about-inconsistent-s.patch
  0076-i386-Compensate-for-KVM-SPEC_CTRL-f.patch
  * Patches renamed (plus some minor code changes):
  0051-machine-add-memory-encryption-prope.patch
  - > 0050-machine-add-memory-encryption-prope.patch
  0052-kvm-update-kvm.h-to-include-memory-.patch
  - > 0051-kvm-update-kvm.h-to-include-memory-.patch
  0053-docs-add-AMD-Secure-Encrypted-Virtu.patch
  - > 0052-docs-add-AMD-Secure-Encrypted-Virtu.patch
  0055-sev-add-command-to-initialize-the-m.patch
  - > 0055-sev-i386-add-command-to-initialize-.patch
  0056-sev-register-the-guest-memory-range.patch
  - > 0057-sev-i386-register-the-guest-memory-.patch
  0057-kvm-introduce-memory-encryption-API.patch
  - > 0058-kvm-introduce-memory-encryption-API.patch
  0058-qmp-add-query-sev-command.patch
  - > 0054-qmp-add-query-sev-command.patch
  0060-sev-add-command-to-create-launch-me.patch
  - > 0060-sev-i386-add-command-to-create-laun.patch
  0061-sev-add-command-to-encrypt-guest-me.patch
  - > 0061-sev-i386-add-command-to-encrypt-gue.patch
  0063-sev-add-support-to-LAUNCH_MEASURE-c.patch
  - > 0063-sev-i386-add-support-to-LAUNCH_MEAS.patch
  0064-sev-Finalize-the-SEV-guest-launch-f.patch
  - > 0064-sev-i386-finalize-the-SEV-guest-lau.patch
  0066-sev-add-debug-encrypt-and-decrypt-c.patch
  - > 0066-sev-i386-add-debug-encrypt-and-decr.patch
  0069-sev-add-support-to-query-PLATFORM_S.patch
  - > 0069-sev-i386-add-support-to-query-PLATF.patch
  0070-sev-add-support-to-KVM_SEV_GUEST_ST.patch
  - > 0070-sev-i386-add-support-to-KVM_SEV_GUE.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
* Thu Feb  8 2018 brogers@suse.com
- Add AMD SEV (Secure Encrypted Virtualization) support by taking
  the v7 series of the patches posted to qemu ml. (fate#322124)
  0046-memattrs-add-debug-attribute.patch
  0047-exec-add-ram_debug_ops-support.patch
  0048-exec-add-debug-version-of-physical-.patch
  0049-monitor-i386-use-debug-APIs-when-ac.patch
  0050-target-i386-add-memory-encryption-f.patch
  0051-machine-add-memory-encryption-prope.patch
  0052-kvm-update-kvm.h-to-include-memory-.patch
  0053-docs-add-AMD-Secure-Encrypted-Virtu.patch
  0054-accel-add-Secure-Encrypted-Virtuliz.patch
  0055-sev-add-command-to-initialize-the-m.patch
  0056-sev-register-the-guest-memory-range.patch
  0057-kvm-introduce-memory-encryption-API.patch
  0058-qmp-add-query-sev-command.patch
  0059-hmp-add-info-sev-command.patch
  0060-sev-add-command-to-create-launch-me.patch
  0061-sev-add-command-to-encrypt-guest-me.patch
  0062-target-i386-encrypt-bios-rom.patch
  0063-sev-add-support-to-LAUNCH_MEASURE-c.patch
  0064-sev-Finalize-the-SEV-guest-launch-f.patch
  0065-hw-i386-set-ram_debug_ops-when-memo.patch
  0066-sev-add-debug-encrypt-and-decrypt-c.patch
  0067-target-i386-clear-C-bit-when-walkin.patch
  0068-include-add-psp-sev.h-header-file.patch
  0069-sev-add-support-to-query-PLATFORM_S.patch
  0070-sev-add-support-to-KVM_SEV_GUEST_ST.patch
  0071-qmp-add-query-sev-launch-measure-co.patch
  0072-sev-Fix-build-for-non-x86-hosts.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
* Thu Feb  8 2018 brogers@suse.com
- Update python3 related patches now that they are upstream
* Thu Feb  8 2018 jfehlig@suse.com
- guest agent: change service file to a template so it can be
  used by Xen as well. Adjust udev rule accordingly.
  FATE#324963
* Mon Jan 29 2018 brogers@suse.com
- Fix machine inconsistency with -no-acpi and nvdimm (bsc#1077823)
  0045-pc-fail-memory-hot-plug-unplug-with.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
* Fri Jan 26 2018 brogers@suse.com
- Modify BuildRequires python references
- seabios also needed tweaks for python2 vs python3
  * Patches added:
  seabios-use-python2-explicitly-as-needed.patch
  seabios-switch-to-python3-as-needed.patch
* Thu Jan 25 2018 brogers@suse.com
- Try to get our story right wrt python2 vs python3 (bsc#1077564)
  * Get rid of use of #!/usr/bin/env python in scripts we install
  * include proposed upstream build system changes needed for building
  with python2 or python3
  * Patches dropped:
  0032-scripts-avoid-usr-bin-python-refere.patch
  * Patches renamed:
  0033-Switch-order-of-libraries-for-mpath.patch
  - > 0032-Switch-order-of-libraries-for-mpath.patch
  0034-i386-kvm-MSR_IA32_SPEC_CTRL-and-MSR.patch
  - > 0033-i386-kvm-MSR_IA32_SPEC_CTRL-and-MSR.patch
  * Patches added:
  0034-qapi-use-items-values-intead-of-ite.patch
  0035-qapi-Use-OrderedDict-from-standard-.patch
  0036-qapi-adapt-to-moved-location-of-Str.patch
  0037-qapi-Adapt-to-moved-location-of-mak.patch
  0038-qapi-remove-q-arg-to-diff-when-comp.patch
  0039-qapi-ensure-stable-sort-ordering-wh.patch
  0040-qapi-force-a-UTF-8-locale-for-runni.patch
  0041-scripts-ensure-signrom-treats-data-.patch
  0042-configure-allow-use-of-python-3.patch
  0043-input-add-missing-JIS-keys-to-virti.patch
  0044-Make-installed-scripts-explicitly-p.patch
  Make-installed-scripts-explicitly-python3.patch
  ui-keycodemapdb-Add-missing-QKeyCode-val.patch
  ui-keycodemapdb-Fix-compat-with-py3-dict.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
* Fri Jan 12 2018 brogers@suse.com
- Fix packaging dependencies (coreutils) for qemu-ksm package
  (bsc#1040202)
* Thu Jan  4 2018 brogers@suse.com
- Pass through to guest info related to x86 security vulnerability
  (CVE-2017-5715 bsc#1068032)
  0034-i386-kvm-MSR_IA32_SPEC_CTRL-and-MSR.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
* Wed Dec 13 2017 brogers@suse.com
- Update to v2.11.0: See http://wiki.qemu.org/ChangeLog/2.11
  Some noteworthy changes:
  - nodefconfig is now deprecated
  legacy pci-assignment code removed
  qemu-pr-helper added for handling guest persistant reservations (bsc#891066,
  bsc#910704, bsc#943807)
  qemu-keymap tool added for generating keymap files
  throttle block filter driver added
  support for a TPM emulator
  qcow2 image shrink support
  better support for >=64 vcpus for Windows guests
  nested KVM related improvements
  s390 pgste handling now done better
  EPYC cpu model added (bsc#1052825)
  improvements in qcow2 buffer handling
  vhost-user resume issue fixed
  migration hardening
  ARMv8-M security extension support
  more seccomp/sandboxing options available
  s390 cpu hot-plug improvements
  misc. virtfs improvements
  nbd improvements
  MTTCG improvements
  misc. TCG improvements
  scsi correctness improvements
  SEABIOS now has serial output option
  * Includes fixes for CVE-2017-15118 bsc#1070147, CVE-2017-15119 bsc#1070144
  * Adds KASLR support (fate#323473, bsc#1070281)
  * Update SLE support docs to match this release
  * simplify spec file to expect at least sle_version >= 1315
  * Patches dropped (upstream):
  0013-console-add-question-mark-escape-op.patch
  0020-configure-Fix-detection-of-seccomp-.patch
  0034-target-i386-cpu-Add-new-EPYC-CPU-mo.patch
  0035-chardev-baum-fix-baum-that-releases.patch
  0036-io-fix-temp-directory-used-by-test-.patch
  0037-io-fix-check-for-handshake-completi.patch
  0038-crypto-fix-test-cert-generation-to-.patch
  0039-vhost-user-disable-the-broken-subpr.patch
  0040-io-monitor-encoutput-buffer-size-fr.patch
  0041-cirrus-fix-oob-access-in-mode4and5-.patch
  0042-9pfs-use-g_malloc0-to-allocate-spac.patch
  * Patches renamed:
  0014-Make-char-muxer-more-robust-wrt-sma.patch
  - > 0013-Make-char-muxer-more-robust-wrt-sma.patch
  0015-linux-user-lseek-explicitly-cast-no.patch
  - > 0014-linux-user-lseek-explicitly-cast-no.patch
  0016-AIO-Reduce-number-of-threads-for-32.patch
  - > 0015-AIO-Reduce-number-of-threads-for-32.patch
  0017-xen_disk-Add-suse-specific-flush-di.patch
  - > 0016-xen_disk-Add-suse-specific-flush-di.patch
  0018-qemu-bridge-helper-reduce-security-.patch
  - > 0017-qemu-bridge-helper-reduce-security-.patch
  0019-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  - > 0018-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  0021-linux-user-properly-test-for-infini.patch
  - > 0019-linux-user-properly-test-for-infini.patch
  0022-roms-Makefile-pass-a-packaging-time.patch
  - > 0020-roms-Makefile-pass-a-packaging-time.patch
  0023-Raise-soft-address-space-limit-to-h.patch
  - > 0021-Raise-soft-address-space-limit-to-h.patch
  0024-increase-x86_64-physical-bits-to-42.patch
  - > 0022-increase-x86_64-physical-bits-to-42.patch
  0025-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  - > 0023-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0026-i8254-Fix-migration-from-SLE11-SP2.patch
  - > 0024-i8254-Fix-migration-from-SLE11-SP2.patch
  0027-acpi_piix4-Fix-migration-from-SLE11.patch
  - > 0025-acpi_piix4-Fix-migration-from-SLE11.patch
  0028-Fix-tigervnc-long-press-issue.patch
  - > 0026-Fix-tigervnc-long-press-issue.patch
  0029-string-input-visitor-Fix-uint64-par.patch
  - > 0027-string-input-visitor-Fix-uint64-par.patch
  0030-test-string-input-visitor-Add-int-t.patch
  - > 0028-test-string-input-visitor-Add-int-t.patch
  0031-test-string-input-visitor-Add-uint6.patch
  - > 0029-test-string-input-visitor-Add-uint6.patch
  0032-tests-Add-QOM-property-unit-tests.patch
  - > 0030-tests-Add-QOM-property-unit-tests.patch
  0033-tests-Add-scsi-disk-test.patch
  - > 0031-tests-Add-scsi-disk-test.patch
  0043-scripts-avoid-usr-bin-python-refere.patch
  - > 0032-scripts-avoid-usr-bin-python-refere.patch
  * We need the multipath libraries link order switched
  0033-Switch-order-of-libraries-for-mpath.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.11
* Wed Nov 29 2017 brogers@suse.com
- Avoid ref to /usr/bin/python in vmstate-static-checker.py script
  0043-scripts-avoid-usr-bin-python-refere.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.10
* Tue Nov 28 2017 brogers@suse.com
- For SLE15, it's been decided to stop providing SDL based graphics
  due to packaging constraints. Long ago GTK became the default,
  and there is little benefit to providing both. For now, keep it
  enabled for openSUSE (Tumblweed and Leap), but consider it marked
  deprecated there and if no one complains it will be removed for
  openSUSE as well in the near future. (fate#324465)
- Fix problem building skiboot.lid
  skiboot-build-LDFLAGS-pass-pie-flag-explicitly-to-ld.patch
* Thu Oct 26 2017 lyan@suse.com
- Wrap analyze-migration and vmstate-static-checker into tools from
  qemu scripts folder, also changed introduction of qemu-tools in
  spec file
- Move supportplugin position in spec file
* Thu Oct 19 2017 brogers@suse.com
- Add announcement in support docs about qed storage format no
  longer being supported in next major SLE release (SLE15)
  (fate#324200)
- Address various security/stability issues
  * Fix DoS in I/O channel websockets (CVE-2017-15268 bsc#1062942)
  0040-io-monitor-encoutput-buffer-size-fr.patch
  * Fix OOB access in cirrus vga device emulation (CVE-2017-15289
  bsc#1063122)
  0041-cirrus-fix-oob-access-in-mode4and5-.patch
  * Fix information leak in 9pfs interface (CVE-2017-15038 bsc#1062069)
  0042-9pfs-use-g_malloc0-to-allocate-spac.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.10
* Mon Oct 16 2017 brogers@suse.com
- Don't tie glusterfs support to specific arch
- Build skiboot firmware (OPAL), particularly since it's fairly
  easy to do so
  skiboot-GCC7-fixes-for-Wimplicit-fallthr.patch
  skiboot-libc-stdio-vsnprintf.c-add-expli.patch
* Fri Oct 13 2017 henrik.kuhn@origenis.de
- Added the global macro 'with_glusterfs' in order to re-enable
  glusterfs support. The macro enable easier future adjustments
  for various ARCH/targets/requiremnets.
  At first glusterfs support is enabled for openSUSE Leap 42.x and
  Factory for ARCH x86_64.
* Wed Oct  4 2017 brogers@suse.com
- Add dependencies on ovmf (uefi) for the qemu-x86 and qemu-arm
  packages
- Fix s390-netboot.img to be included with qemu-s390 package, not
  qemu-ppc
* Tue Oct  3 2017 brogers@suse.com
- Update to v2.10.1, a stable, bug-fix-only release
  * fixes bsc#1056386 CVE-2017-13673, bsc#1056334 CVE-2017-13672,
  bsc#1057585 CVE-2017-14167
  * Patches dropped (upstream):
  0034-slirp-fix-clearing-ifq_so-from-pend.patch
  0035-s390-ccw-Fix-alignment-for-CCW1.patch
  0038-s390x-ais-for-2.10-stable-disable-a.patch
  0039-s390x-cpumodel-remove-ais-from-z14-.patch
  * Patches renamed:
  0036-target-i386-cpu-Add-new-EPYC-CPU-mo.patch
  - > 0034-target-i386-cpu-Add-new-EPYC-CPU-mo.patch
  0037-chardev-baum-fix-baum-that-releases.patch
  - > 0035-chardev-baum-fix-baum-that-releases.patch
  0040-io-fix-temp-directory-used-by-test-.patch
  - > 0036-io-fix-temp-directory-used-by-test-.patch
  0041-io-fix-check-for-handshake-completi.patch
  - > 0037-io-fix-check-for-handshake-completi.patch
  0042-crypto-fix-test-cert-generation-to-.patch
  - > 0038-crypto-fix-test-cert-generation-to-.patch
  0043-vhost-user-disable-the-broken-subpr.patch
  - > 0039-vhost-user-disable-the-broken-subpr.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.10
* Mon Oct  2 2017 brogers@suse.com
- Fix failures and potential failures in qemu-testsuite
  0040-io-fix-temp-directory-used-by-test-.patch
  0041-io-fix-check-for-handshake-completi.patch
  0042-crypto-fix-test-cert-generation-to-.patch
  0043-vhost-user-disable-the-broken-subpr.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.10
* Thu Sep 28 2017 brogers@suse.com
- Fix migration issue on s390
  0038-s390x-ais-for-2.10-stable-disable-a.patch
  0039-s390x-cpumodel-remove-ais-from-z14-.patch
- Fix case of not being able to build from rpm sources due to
  undefined macro (boo#1057966)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.10
* Thu Sep 28 2017 lyan@suse.com
- Fix baum that release brlapi twice (bsc#1060045)
  0037-chardev-baum-fix-baum-that-releases.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.10
* Thu Sep 21 2017 brogers@suse.com
- For SLE15 pre-release testing, add support for the EPYC processor.
  This will be officially supported once it is included in the v2.11
  release. (bsc#1052825)
  0036-target-i386-cpu-Add-new-EPYC-CPU-mo.patch
- Fix some support statements in our SLE support documents.
* Thu Aug 31 2017 brogers@suse.com
- Update BuildRequires packages libibverbs-devel and librdmacm-devel
  to the more correct rdma-core-devel
- Enable seccomp for s390x, aarch64, and ppc64le
- Fix OOB issue (use after free) in slirp network stack (CVE-2017-13711
  bsc#1056291)
  0034-slirp-fix-clearing-ifq_so-from-pend.patch
- Fix a misalignment in the s390 ccw firmware (bsc#1056680)
  0035-s390-ccw-Fix-alignment-for-CCW1.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.10
* Thu Aug 31 2017 jfehlig@suse.com
- Add a supportconfig plugin
  qemu-supportconfig
  FATE#323661
* Wed Aug 30 2017 brogers@suse.com
- Update to v2.10.0: See http://wiki.qemu.org/ChangeLog/2.10
- Dropped internal only patches used to support SUSE Studio
  Testdrive as well as other miscellaneous patches deemed unused
  and not worth carrying (bsc#1046783, bsc#1055125, bsc#1055127)
- Update SLE support statements in anticipation of SLE15
- disable SAN boot capability from virtio pxe rom used in v1.4 and
  older pc machine types due to rom size requirements. Hopefully
  a better solution can be found which doesn't impact functionality
  * Patches added:
  ipxe-stub-out-the-SAN-req-s-in-int13.patch
  * Patches renamed:
  0006-qemu-cvs-gettimeofday.patch -> 0003-qemu-cvs-gettimeofday.patch
  0007-qemu-cvs-ioctl_debug.patch -> 0004-qemu-cvs-ioctl_debug.patch
  0008-qemu-cvs-ioctl_nodirection.patch -> 0005-qemu-cvs-ioctl_nodirection.patch
  0009-linux-user-add-binfmt-wrapper-for-a.patch -> 0006-linux-user-add-binfmt-wrapper-for-a.patch
  0010-PPC-KVM-Disable-mmu-notifier-check.patch -> 0007-PPC-KVM-Disable-mmu-notifier-check.patch
  0011-linux-user-fix-segfault-deadlock.patch -> 0008-linux-user-fix-segfault-deadlock.patch
  0012-linux-user-binfmt-support-host-bina.patch -> 0009-linux-user-binfmt-support-host-bina.patch
  0013-linux-user-Fake-proc-cpuinfo.patch -> 0010-linux-user-Fake-proc-cpuinfo.patch
  0014-linux-user-XXX-disable-fiemap.patch -> 0011-linux-user-XXX-disable-fiemap.patch
  0017-linux-user-use-target_ulong.patch -> 0012-linux-user-use-target_ulong.patch
  0021-console-add-question-mark-escape-op.patch -> 0013-console-add-question-mark-escape-op.patch
  0022-Make-char-muxer-more-robust-wrt-sma.patch -> 0014-Make-char-muxer-more-robust-wrt-sma.patch
  0023-linux-user-lseek-explicitly-cast-no.patch -> 0015-linux-user-lseek-explicitly-cast-no.patch
  0025-AIO-Reduce-number-of-threads-for-32.patch -> 0016-AIO-Reduce-number-of-threads-for-32.patch
  0027-xen_disk-Add-suse-specific-flush-di.patch -> 0017-xen_disk-Add-suse-specific-flush-di.patch
  0028-qemu-bridge-helper-reduce-security-.patch -> 0018-qemu-bridge-helper-reduce-security-.patch
  0029-qemu-binfmt-conf-use-qemu-ARCH-binf.patch -> 0019-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  0030-configure-Fix-detection-of-seccomp-.patch -> 0020-configure-Fix-detection-of-seccomp-.patch
  0031-linux-user-properly-test-for-infini.patch -> 0020-linux-user-properly-test-for-infini.patch
  0033-roms-Makefile-pass-a-packaging-time.patch -> 0022-roms-Makefile-pass-a-packaging-time.patch
  0034-Raise-soft-address-space-limit-to-h.patch -> 0023-Raise-soft-address-space-limit-to-h.patch
  0035-increase-x86_64-physical-bits-to-42.patch -> 0024-increase-x86_64-physical-bits-to-42.patch
  0036-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch -> 0025-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0037-i8254-Fix-migration-from-SLE11-SP2.patch -> 0026-i8254-Fix-migration-from-SLE11-SP2.patch
  0038-acpi_piix4-Fix-migration-from-SLE11.patch -> 0027-acpi_piix4-Fix-migration-from-SLE11.patch
  0039-Fix-tigervnc-long-press-issue.patch -> 0028-Fix-tigervnc-long-press-issue.patch
  0041-string-input-visitor-Fix-uint64-par.patch -> 0029-string-input-visitor-Fix-uint64-par.patch
  0042-test-string-input-visitor-Add-int-t.patch -> 0030-test-string-input-visitor-Add-int-t.patch
  0043-test-string-input-visitor-Add-uint6.patch -> 0031-test-string-input-visitor-Add-uint6.patch
  0044-tests-Add-QOM-property-unit-tests.patch -> 0032-tests-Add-QOM-property-unit-tests.patch
  0045-tests-Add-scsi-disk-test.patch -> 0033-tests-Add-scsi-disk-test.patch
  * Patches dropped (upstream unless otherwise noted):
  0003-qemu-cvs-alsa_bitfield.patch (deemed not needed)
  0004-qemu-cvs-alsa_ioctl.patch (deemed not needed)
  0005-qemu-cvs-alsa_mmap.patch (deemed not needed)
  0015-slirp-nooutgoing.patch (bsc#1055125)
  0016-vnc-password-file-and-incoming-conn.patch (bsc#1055127)
  0018-block-Add-support-for-DictZip-enabl.patch (bsc#1046783)
  0019-block-Add-tar-container-format.patch (bsc#1046783)
  0020-Legacy-Patch-kvm-qemu-preXX-dictzip.patch (bsc#1046783)
  0024-configure-Enable-PIE-for-ppc-and-pp.patch (obsolete)
  0026-dictzip-Fix-on-big-endian-systems.patch (bsc#1046783)
  0032-linux-user-remove-all-traces-of-qem.patch
  0040-fix-xen-hvm-direct-kernel-boot.patch (bsc#970791)
  0046-RFC-update-Linux-headers-from-irqs-.patch
  0047-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0048-input-Add-trace-event-for-empty-key.patch
  0049-ACPI-don-t-call-acpi_pcihp_device_p.patch
  0050-i386-Allow-cpuid-bit-override.patch (was for testing only)
  0051-input-limit-kbd-queue-depth.patch
  0052-audio-release-capture-buffers.patch
  0053-scsi-avoid-an-off-by-one-error-in-m.patch
  0054-vmw_pvscsi-check-message-ring-page-.patch
  0055-9pfs-local-forbid-client-access-to-.patch
  0056-jazz_led-fix-bad-snprintf.patch
  0057-slirp-smb-Replace-constant-strings-.patch
  0058-altera_timer-fix-incorrect-memset.patch
  0059-Hacks-for-building-on-gcc-7-Fedora-.patch
  0060-9pfs-local-fix-unlink-of-alien-file.patch
  0061-megasas-do-not-read-DCMD-opcode-mor.patch
  0062-megasas-always-store-SCSIRequest-in.patch
  0063-nbd-Fully-initialize-client-in-case.patch
  0064-9pfs-local-remove-use-correct-path-.patch
  0065-hid-Reset-kbd-modifiers-on-reset.patch
  0066-input-Decrement-queue-count-on-kbd-.patch
  0067-xhci-only-update-dequeue-ptr-on-com.patch
  0068-vnc-Set-default-kbd-delay-to-10ms.patch
  0069-qemu-nbd-Ignore-SIGPIPE.patch
  0070-usb-redir-fix-stack-overflow-in-usb.patch
  0072-slirp-check-len-against-dhcp-option.patch
  0071-exec-use-qemu_ram_ptr_length-to-acc.patch
  0073-xen-mapcache-store-dma-information-.patch
  0074-exec-Add-lock-parameter-to-qemu_ram.patch
  0075-Replace-struct-ucontext-with-uconte.patch
  ipxe-build-Avoid-implicit-fallthrough-warnings-on-GCC-7.patch
  ipxe-iscsi-Always-send-FirstBurstLength-parameter.patch
  ipxe-ath-Add-missing-break-statements.patch
  ipxe-mucurses-Fix-erroneous-__nonnull-attribute.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.10
* Thu Aug 24 2017 brogers@suse.com
- Fix package build failure as of glibc v2.26 update in Factory
  (boo#1055587)
  0075-Replace-struct-ucontext-with-uconte.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Mon Aug 21 2017 schwab@suse.de
- Remove redundant prerequire for pwdutils
* Fri Aug 18 2017 brogers@suse.com
- Postrequire acl for setfacl
* Wed Aug 16 2017 schwab@suse.de
- Prerequire shadow for groupadd
* Tue Aug 15 2017 brogers@suse.com
- The recent security fix for CVE-2017-11334 adversely affects Xen.
  Include two additional patches to make sure Xen is going to be OK.
  0073-xen-mapcache-store-dma-information-.patch
  0074-exec-Add-lock-parameter-to-qemu_ram.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Wed Aug  9 2017 lyan@suse.com
- Pre-add group kvm for qemu-tools (bsc#1011144)
* Mon Aug  7 2017 brogers@suse.com
- Fixed a few more inaccuracies in the support docs.
* Tue Jul 25 2017 brogers@suse.com
- Address various security/stability issues
  * Fix DOS vulnerability in qemu-nbd (bsc#1046636 CVE-2017-10664)
  0069-qemu-nbd-Ignore-SIGPIPE.patch
  * Fix DOS from stack overflow in debug messages of usb redirection
  support (bsc#1047674 CVE-2017-10806)
  0070-usb-redir-fix-stack-overflow-in-usb.patch
  * Fix OOB access during DMA operation (CVE-2017-11334 bsc#1048902)
  0071-exec-use-qemu_ram_ptr_length-to-acc.patch
  * Fix OOB access parsing dhcp slirp options (CVE-2017-11434 bsc#1049381)
  0072-slirp-check-len-against-dhcp-option.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Jul 25 2017 brogers@suse.com
- Fix support docs to indicate ARM64 is now fully L3 supported in
  SLES 12 SP3. Apply a few additional clarifications in the support
  docs. (bsc#1050268)
- Adjust to libvdeplug-devel package naming changes.
* Tue Jul 18 2017 brogers@suse.com
- Fix migration with xhci (bsc#1048296)
  0067-xhci-only-update-dequeue-ptr-on-com.patch
- Increase VNC delay to fix missing keyboard input events (bsc#1031692)
  0068-vnc-Set-default-kbd-delay-to-10ms.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Thu Jun 29 2017 lyan@suse.com
- Remove build dependency package iasl used for seabios
* Mon Jun 26 2017 brogers@suse.com
- Fixed stuck state during usb keyboard reset (bsc#1044936)
  0065-hid-Reset-kbd-modifiers-on-reset.patch
- Fixed keyboard events getting lost (bsc#1044936)
  0066-input-Decrement-queue-count-on-kbd-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Jun 20 2017 brogers@suse.com
- Use most recent compiler to build size-critical firmware, instead
  of hard-coding gcc6 for all target versions (bsc#1043390)
  * A few upstream ipxe patches were needed for gcc7 compatibility:
  ipxe-ath-Add-missing-break-statements.patch
  ipxe-mucurses-Fix-erroneous-__nonnull-attribute.patch
- Add --no-renames to the git format-patch command in the git
  workflow script for better patch compatibility
- Address various security/stability issues
  * Fix potential privilege escalation in virtfs (CVE-2016-9602
  bsc#1020427)
  0060-9pfs-local-fix-unlink-of-alien-file.patch
  * Fix DOS in megasas device emulation (CVE-2017-9503 bsc#1043296)
  0061-megasas-do-not-read-DCMD-opcode-mor.patch
  0062-megasas-always-store-SCSIRequest-in.patch
  * Fix DOS in qemu-nbd server (CVE-2017-9524 bsc#1043808)
  0063-nbd-Fully-initialize-client-in-case.patch
  * Fix regression introduced by recent virtfs security fixes (bsc#1045035)
  0064-9pfs-local-remove-use-correct-path-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Jun  6 2017 lyan@suse.com
- Backport ipxe to support FirstBurstLength (bsc#1040476)
  ipxe-iscsi-Always-send-FirstBurstLength-parameter.patch
* Mon May 22 2017 brogers@suse.com
- Fixes for gcc7 compatability (bsc#1040228) (in behalf of Liang Yan)
  0056-jazz_led-fix-bad-snprintf.patch
  0057-slirp-smb-Replace-constant-strings-.patch
  0058-altera_timer-fix-incorrect-memset.patch
  0059-Hacks-for-building-on-gcc-7-Fedora-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Mon May 22 2017 brogers@suse.com
- Protect access to metadata in virtio-9pfs (CVE-2017-7493 bsc#1039495)
  0055-9pfs-local-forbid-client-access-to-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Thu May 11 2017 brogers@suse.com
- Address various security/stability issues
  * Fix DOS potential in vnc interface (CVE-2017-8379 bsc#1037334)
  0051-input-limit-kbd-queue-depth.patch
  * Fix DOS potential in vnc interface (CVE-2017-8309 bsc#1037242)
  0052-audio-release-capture-buffers.patch
  * Fix OOB access in megasas device emulation (CVE-2017-8380
  bsc#1037336)
  0053-scsi-avoid-an-off-by-one-error-in-m.patch
  * Fix DOS in Vmware pv scsi emulation (CVE-2017-8112 bsc#1036211)
  0054-vmw_pvscsi-check-message-ring-page-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Thu May  4 2017 brogers@suse.com
- Fix building packages for some older distros.
- Further refine our handling of building firmware (or not) for
  the various arch's and distro versions we build for. Note that
  if we don't build x86 firmware, (eg: x86 Leap 42.1) the upstream
  binary blobs are used, which may have migration incompatibilities
  with previous versions of qemu provided.
* Thu Apr 27 2017 brogers@suse.com
- Fix issue in shipping qemu v2.9.0, where pci-passthrough for Xen
  HVM guests got broken (bsc#1034131)
  0049-ACPI-don-t-call-acpi_pcihp_device_p.patch
- Include experimental, unsupported feature to assist in some
  performance analysis work.
  0050-i386-Allow-cpuid-bit-override.patch
* Thu Apr 20 2017 brogers@suse.com
- Updated to v2.9.0: See http://wiki.qemu-project.org/ChangeLog/2.9
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Apr 18 2017 brogers@suse.com
- Updated to v2.9.0-rc5: See http://wiki.qemu-project.org/ChangeLog/2.9
  * Includes fix for CVE-2017-7471, a virtfs security issue.
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Wed Apr 12 2017 brogers@suse.com
- Add empty keyboard queue tracepoint to help openQA testing work
  better (bsc#1031692)
  0048-input-Add-trace-event-for-empty-key.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Apr 11 2017 brogers@suse.com
- Updated to v2.9.0-rc4: See http://wiki.qemu-project.org/ChangeLog/2.9
- Enable ceph/rbd support for s390x (bsc#1030068)
- Enable ceph/rbd support for ppc* as available
- Update ARM in-kernel-timers patch (bsc#1033416)
  * Patches renamed:
  0041-ARM-KVM-Enable-in-kernel-timers-wit.patch -> 0047-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0042-string-input-visitor-Fix-uint64-par.patch -> 0041-string-input-visitor-Fix-uint64-par.patch
  0043-test-string-input-visitor-Add-int-t.patch -> 0042-test-string-input-visitor-Add-int-t.patch
  0044-test-string-input-visitor-Add-uint6.patch -> 0043-test-string-input-visitor-Add-uint6.patch
  0045-tests-Add-QOM-property-unit-tests.patch -> 0044-tests-Add-QOM-property-unit-tests.patch
  0046-tests-Add-scsi-disk-test.patch -> 0045-tests-Add-scsi-disk-test.patch
  * Patches added (support patch):
  0046-RFC-update-Linux-headers-from-irqs-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Wed Apr  5 2017 brogers@suse.com
- Updated to v2.9.0-rc3: See http://wiki.qemu-project.org/ChangeLog/2.9
  * Patches dropped (included in upstream source archive):
  0047-hw-intc-arm_gicv3_kvm-Check-KVM_DEV.patch
  0048-i386-Replace-uint32_t-with-FeatureW.patch
  0049-i386-Don-t-override-cpu-options-on-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
- Added additional documentation provided with v2.9.0
- Fix build failure with gcc7 (bsc#1031340)
  ipxe-build-Avoid-implicit-fallthrough-warnings-on-GCC-7.patch
- Made miscellaneous spec file refinements
* Thu Mar 30 2017 brogers@suse.com
- The support documents included are now fairly accurate for the
  arm and s390 world, and the x86 version also received a few
  tweaks. Also included in those docs is a url reference to upstream
  qemu deprecation plans and discussions.
  (fate#321146)
- Add post v2.9.0-rc2 upstream patches which fix -cpu host and -cpu
  max feature overrides for libvirt compatability.
  0048-i386-Replace-uint32_t-with-FeatureW.patch
  0049-i386-Don-t-override-cpu-options-on-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Mar 28 2017 brogers@suse.com
- Updated to v2.9.0-rc2: See http://wiki.qemu-project.org/ChangeLog/2.9
  * Includes fix for in guest privilege escalation when using TCG
  (bsc#1030624)
  * Patches dropped (equivalent included in upstream source archive):
  0047-linux-user-exclude-cpu-model-code-w.patch
- Fix failure booting SLE12-SP2 Aarch64 guest (bsc#1031384)
  0047-hw-intc-arm_gicv3_kvm-Check-KVM_DEV.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Tue Mar 21 2017 brogers@suse.com
- Updated to v2.9.0-rc1: See http://wiki.qemu-project.org/ChangeLog/2.9
  * Patches dropped (no longer needed based on what we now build for):
  0024-virtfs-proxy-helper-Provide-__u64-f.patch
  * Patches dropped (included in upstream source archive):
  0034-dma-rc4030-limit-interval-timer-rel.patch
  * Patches renamed:
  0025-configure-Enable-PIE-for-ppc-and-pp.patch -> 0024-configure-Enable-PIE-for-ppc-and-pp.patch
  0026-AIO-Reduce-number-of-threads-for-32.patch -> 0025-AIO-Reduce-number-of-threads-for-32.patch
  0027-dictzip-Fix-on-big-endian-systems.patch -> 0026-dictzip-Fix-on-big-endian-systems.patch
  0028-xen_disk-Add-suse-specific-flush-di.patch -> 0027-xen_disk-Add-suse-specific-flush-di.patch
  0029-qemu-bridge-helper-reduce-security-.patch -> 0028-qemu-bridge-helper-reduce-security-.patch
  0030-qemu-binfmt-conf-use-qemu-ARCH-binf.patch -> 0029-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  0031-configure-Fix-detection-of-seccomp-.patch -> 0030-configure-Fix-detection-of-seccomp-.patch
  0032-linux-user-properly-test-for-infini.patch -> 0031-linux-user-properly-test-for-infini.patch
  0033-linux-user-remove-all-traces-of-qem.patch -> 0032-linux-user-remove-all-traces-of-qem.patch
  0035-roms-Makefile-pass-a-packaging-time.patch -> 0033-roms-Makefile-pass-a-packaging-time.patch
  0036-Raise-soft-address-space-limit-to-h.patch -> 0034-Raise-soft-address-space-limit-to-h.patch
  0037-increase-x86_64-physical-bits-to-42.patch -> 0035-increase-x86_64-physical-bits-to-42.patch
  0038-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch -> 0036-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0039-i8254-Fix-migration-from-SLE11-SP2.patch -> 0037-i8254-Fix-migration-from-SLE11-SP2.patch
  0040-acpi_piix4-Fix-migration-from-SLE11.patch -> 0038-acpi_piix4-Fix-migration-from-SLE11.patch
  0041-Fix-tigervnc-long-press-issue.patch -> 0039-Fix-tigervnc-long-press-issue.patch
  0042-fix-xen-hvm-direct-kernel-boot.patch -> 0040-fix-xen-hvm-direct-kernel-boot.patch
  0043-ARM-KVM-Enable-in-kernel-timers-wit.patch -> 0041-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0044-string-input-visitor-Fix-uint64-par.patch -> 0042-string-input-visitor-Fix-uint64-par.patch
  0045-test-string-input-visitor-Add-int-t.patch -> 0043-test-string-input-visitor-Add-int-t.patch
  0046-test-string-input-visitor-Add-uint6.patch -> 0044-test-string-input-visitor-Add-uint6.patch
  0047-tests-Add-QOM-property-unit-tests.patch -> 0045-tests-Add-QOM-property-unit-tests.patch
  0048-tests-Add-scsi-disk-test.patch -> 0046-tests-Add-scsi-disk-test.patch
  0049-linux-user-exclude-cpu-model-code-w.patch -> 0047-linux-user-exclude-cpu-model-code-w.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Mon Mar 20 2017 brogers@suse.com
- Updated to v2.9.0-rc0: See http://wiki.qemu-project.org/ChangeLog/2.9
  * Updated version carries fixes for the following reported issues:
  CVE-2016-9602 bsc#1020427, CVE-2016-9923 bsc#1014703,
  CVE-2017-2630 bsc#1025396, CVE-2017-2633 bsc#1026612,
  CVE-2017-5579 bsc#1021741, CVE-2017-5931 bsc#1024114,
  CVE-2017-5973 bsc#1025109, CVE-2017-5987 bsc#1025311,
  CVE-2017-6058 bsc#1025837, CVE-2017-6505 bsc#1028184
  * Patches dropped:
  seabios_128kb.patch (no longer required)
  * Patches dropped (included in upstream source archive):
  0035-net-imx-limit-buffer-descriptor-cou.patch
  0045-virtio-gpu-call-cleanup-mapping-fun.patch
  0051-virtio-gpu-fix-information-leak-in-.patch
  0052-display-cirrus-ignore-source-pitch-.patch
  0053-s390x-kvm-fix-small-race-reboot-vs..patch
  0054-target-s390x-use-qemu-cpu-model-in-.patch
  0056-tests-check-path-to-avoid-a-failing.patch
  0057-display-virtio-gpu-3d-check-virgl-c.patch
  0058-watchdog-6300esb-add-exit-function.patch
  0059-virtio-gpu-3d-fix-memory-leak-in-re.patch
  0060-virtio-gpu-fix-memory-leak-in-resou.patch
  0061-virtio-fix-vq-inuse-recalc-after-mi.patch
  0062-audio-es1370-add-exit-function.patch
  0063-audio-ac97-add-exit-function.patch
  0064-megasas-fix-guest-triggered-memory-.patch
  0065-cirrus-handle-negative-pitch-in-cir.patch
  0066-cirrus-fix-blit-address-mask-handli.patch
  0067-cirrus-fix-oob-access-issue-CVE-201.patch
  0068-usb-ccid-check-ccid-apdu-length.patch
  0069-sd-sdhci-check-data-length-during-d.patch
  0070-virtio-gpu-fix-resource-leak-in-vir.patch
  0071-cirrus-fix-patterncopy-checks.patch
  0072-cirrus-add-blit_is_unsafe-call-to-c.patch
  * Patches renamed:
  0036-roms-Makefile-pass-a-packaging-time.patch -> 0035-roms-Makefile-pass-a-packaging-time.patch
  0037-Raise-soft-address-space-limit-to-h.patch -> 0036-Raise-soft-address-space-limit-to-h.patch
  0038-increase-x86_64-physical-bits-to-42.patch -> 0037-increase-x86_64-physical-bits-to-42.patch
  0039-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch -> 0038-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0040-i8254-Fix-migration-from-SLE11-SP2.patch -> 0039-i8254-Fix-migration-from-SLE11-SP2.patch
  0041-acpi_piix4-Fix-migration-from-SLE11.patch -> 0040-acpi_piix4-Fix-migration-from-SLE11.patch
  0042-Fix-tigervnc-long-press-issue.patch -> 0041-Fix-tigervnc-long-press-issue.patch
  0043-fix-xen-hvm-direct-kernel-boot.patch -> 0042-fix-xen-hvm-direct-kernel-boot.patch
  0044-ARM-KVM-Enable-in-kernel-timers-wit.patch -> 0043-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0046-string-input-visitor-Fix-uint64-par.patch -> 0044-string-input-visitor-Fix-uint64-par.patch
  0047-test-string-input-visitor-Add-int-t.patch -> 0045-test-string-input-visitor-Add-int-t.patch
  0048-test-string-input-visitor-Add-uint6.patch -> 0046-test-string-input-visitor-Add-uint6.patch
  0049-tests-Add-QOM-property-unit-tests.patch -> 0047-tests-Add-QOM-property-unit-tests.patch
  0050-tests-Add-scsi-disk-test.patch -> 0048-tests-Add-scsi-disk-test.patch
  0055-linux-user-exclude-cpu-model-code-w.patch -> 0049-linux-user-exclude-cpu-model-code-w.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.9
* Wed Mar  1 2017 brogers@suse.com
-  Buildignore for the global gcc-PIE, as this package enables PIE
  on its own and has troubles if all use it. (meissner@suse.com)
* Wed Mar  1 2017 brogers@suse.com
- Address various security/stability issues
  * Fix OOB access in virito-gpu-3d (CVE-2016-10028 bsc#1017084
  bsc#1016503)
  0057-display-virtio-gpu-3d-check-virgl-c.patch
  * Fix DOS in Intel 6300ESB device emulation (CVE-2016-10155 bsc#1021129)
  0058-watchdog-6300esb-add-exit-function.patch
  * Fix DOS in virtio-gpu-3d (CVE-2017-5552 bsc#1021195)
  0059-virtio-gpu-3d-fix-memory-leak-in-re.patch
  * Fix DOS in virtio-gpu (CVE-2017-5578 bsc#1021481)
  0060-virtio-gpu-fix-memory-leak-in-resou.patch
  * Fix cause of infrequent migration failures from bad virtio device
  state. (bsc#1020928)
  0061-virtio-fix-vq-inuse-recalc-after-mi.patch
  * Fix DOS in es1370 emulated audio device (CVE-2017-5526 bsc#1020589)
  0062-audio-es1370-add-exit-function.patch
  * Fix DOS in ac97 emulated audio device (CVE-2017-5525 bsc#1020491)
  0063-audio-ac97-add-exit-function.patch
  * Fix DOS in megasas device emulation (CVE-2017-5856 bsc#1023053)
  0064-megasas-fix-guest-triggered-memory-.patch
  * Fix various inaccuracies in cirrus vga device emulation
  0065-cirrus-handle-negative-pitch-in-cir.patch
  0066-cirrus-fix-blit-address-mask-handli.patch
  * Fix OOB access in cirrus vga emulation (CVE-2017-2615 bsc#1023004)
  0067-cirrus-fix-oob-access-issue-CVE-201.patch
  * Fix DOS in usb CCID card device emulator (CVE-2017-5898 bsc#1023907)
  0068-usb-ccid-check-ccid-apdu-length.patch
  * Fix OOB access in SDHCI device emulation (CVE-2017-5667 bsc#1022541)
  0069-sd-sdhci-check-data-length-during-d.patch
  * Fix DOS in virtio-gpu-3d (CVE-2017-5857 bsc#1023073)
  0070-virtio-gpu-fix-resource-leak-in-vir.patch
  * Fix cirrus patterncopy checks
  0071-cirrus-fix-patterncopy-checks.patch
  * Fix OOB access in cirrus vga emulation (CVE-2017-2620 bsc#1024972)
  0072-cirrus-add-blit_is_unsafe-call-to-c.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.8
* Thu Feb 23 2017 brogers@suse.com
- Fix name of s390x specific sysctl configuration file to end with
  .conf (bsc#1026583)
* Fri Feb 17 2017 brogers@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.8
  * Check that sysfs path exists before running test which requires
  it. This allows qemu-testsuite to succeed in local build service
  chroot based package build.
  0056-tests-check-path-to-avoid-a-failing.patch
* Wed Feb 15 2017 brogers@suse.com
- Factory and SLE12-SP3 got a name change in the dtc devel package:
  libfdt1-devel -> libfdt-devel. Adjust our spec file accordingly.
* Tue Feb 14 2017 brogers@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.8
  * Patches added:
  0055-linux-user-exclude-cpu-model-code-w.patch
* Thu Feb  2 2017 brogers@suse.com
- Make sure qemu guest agent is usable as soon as qemu-guest-agent
  package is installed. The previous post script was still not
  doing the job.
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.8
  * Fix potential hang/crash rebooting s390x guest
  0053-s390x-kvm-fix-small-race-reboot-vs..patch
  * Fix s390x linux-user failure since v2.8.0 update
  0054-target-s390x-use-qemu-cpu-model-in-.patch
* Wed Jan 25 2017 brogers@suse.com
- Merge qemu packages from openSUSE and SUSE SLE releases together
  for the v2.8 qemu update. The qemu.changes file is the openSUSE
  version with this entry providing CVE, FATE, and bugzilla
  references from the SUSE SLE qemu package to date (see below)
- Updated to v2.8.0: See http://wiki.qemu-project.org/ChangeLog/2.8
  * For SUSE SLE-12-SP3, update relates to fate#319684, fate#321331,
  fate#321335, fate#321339, fate#321349, fate#321857
  * For best compatibility, qemu-ifup and kvm_stat scripts now owned
  by qemu package
  * Build ipxe roms with gcc6 to maintain SLE legacy migration
  compatibility requirements
  * qmp-commands.txt file removed, to resurface in future doc reorganization
  * qemu-tech.html file merged into other existing doc
  * trace-events renamed to trace-events-all
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.8
  * Patches dropped (upstream):
  0013-linux-user-lock-tcg.patch
  0014-linux-user-Run-multi-threaded-code-.patch
  0015-linux-user-lock-tb-flushing-too.patch
  0017-linux-user-implement-FS_IOC_GETFLAG.patch
  0018-linux-user-implement-FS_IOC_SETFLAG.patch
  0034-xen-SUSE-xenlinux-unplug-for-emulat.patch
  0039-Fix-tlb_vaddr_to_host-with-CONFIG_U.patch
  0041-vmsvga-correct-bitmap-and-pixmap-si.patch
  0042-scsi-mptconfig-fix-an-assert-expres.patch
  0043-scsi-mptconfig-fix-misuse-of-MPTSAS.patch
  0044-scsi-pvscsi-limit-loop-to-fetch-SG-.patch
  0045-usb-xhci-fix-memory-leak-in-usb_xhc.patch
  0046-scsi-mptsas-use-g_new0-to-allocate-.patch
  0047-scsi-pvscsi-limit-process-IO-loop-t.patch
  0048-virtio-add-check-for-descriptor-s-m.patch
  0049-net-mcf-limit-buffer-descriptor-cou.patch
  0050-usb-ehci-fix-memory-leak-in-ehci_pr.patch
  0051-xhci-limit-the-number-of-link-trbs-.patch
  0052-9pfs-allocate-space-for-guest-origi.patch
  0053-9pfs-fix-memory-leak-in-v9fs_link.patch
  0054-9pfs-fix-potential-host-memory-leak.patch
  0055-9pfs-fix-information-leak-in-xattr-.patch
  0056-9pfs-fix-memory-leak-in-v9fs_xattrc.patch
  0057-9pfs-fix-memory-leak-in-v9fs_write.patch
  0058-char-serial-check-divider-value-aga.patch
  0059-net-pcnet-check-rx-tx-descriptor-ri.patch
  0060-net-eepro100-fix-memory-leak-in-dev.patch
  0061-net-rocker-set-limit-to-DMA-buffer-.patch
  0062-net-vmxnet-initialise-local-tx-desc.patch
  0063-net-rtl8139-limit-processing-of-rin.patch
  0064-audio-intel-hda-check-stream-entry-.patch
  0065-virtio-gpu-fix-memory-leak-in-virti.patch
  0066-9pfs-fix-integer-overflow-issue-in-.patch
  slof_xhci.patch
  * Patches renamed:
  0016-linux-user-Fake-proc-cpuinfo.patch -> 0013-linux-user-Fake-proc-cpuinfo.patch
  0019-linux-user-XXX-disable-fiemap.patch -> 0014-linux-user-XXX-disable-fiemap.patch
  0020-slirp-nooutgoing.patch -> 0015-slirp-nooutgoing.patch
  0021-vnc-password-file-and-incoming-conn.patch -> 0016-vnc-password-file-and-incoming-conn.patch
  0022-linux-user-use-target_ulong.patch -> 0017-linux-user-use-target_ulong.patch
  0023-block-Add-support-for-DictZip-enabl.patch -> 0018-block-Add-support-for-DictZip-enabl.patch
  0024-block-Add-tar-container-format.patch -> 0019-block-Add-tar-container-format.patch
  0025-Legacy-Patch-kvm-qemu-preXX-dictzip.patch -> 0020-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0026-console-add-question-mark-escape-op.patch -> 0021-console-add-question-mark-escape-op.patch
  0027-Make-char-muxer-more-robust-wrt-sma.patch -> 0022-Make-char-muxer-more-robust-wrt-sma.patch
  0028-linux-user-lseek-explicitly-cast-no.patch -> 0023-linux-user-lseek-explicitly-cast-no.patch
  0029-virtfs-proxy-helper-Provide-__u64-f.patch -> 0024-virtfs-proxy-helper-Provide-__u64-f.patch
  0030-configure-Enable-PIE-for-ppc-and-pp.patch -> 0025-configure-Enable-PIE-for-ppc-and-pp.patch
  0031-AIO-Reduce-number-of-threads-for-32.patch -> 0026-AIO-Reduce-number-of-threads-for-32.patch
  0032-dictzip-Fix-on-big-endian-systems.patch -> 0027-dictzip-Fix-on-big-endian-systems.patch
  0033-xen_disk-Add-suse-specific-flush-di.patch -> 0028-xen_disk-Add-suse-specific-flush-di.patch
  0035-qemu-bridge-helper-reduce-security-.patch -> 0029-qemu-bridge-helper-reduce-security-.patch
  0036-qemu-binfmt-conf-use-qemu-ARCH-binf.patch -> 0030-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  0037-configure-Fix-detection-of-seccomp-.patch -> 0031-configure-Fix-detection-of-seccomp-.patch
  0038-linux-user-properly-test-for-infini.patch -> 0032-linux-user-properly-test-for-infini.patch
  0040-linux-user-remove-all-traces-of-qem.patch -> 0033-linux-user-remove-all-traces-of-qem.patch
  0067-dma-rc4030-limit-interval-timer-rel.patch -> 0034-dma-rc4030-limit-interval-timer-rel.patch
  0068-net-imx-limit-buffer-descriptor-cou.patch -> 0035-net-imx-limit-buffer-descriptor-cou.patch
  0069-roms-Makefile-pass-a-packaging-time.patch -> 0036-roms-Makefile-pass-a-packaging-time.patch
  * Patches added:
  0037-Raise-soft-address-space-limit-to-h.patch
  0038-increase-x86_64-physical-bits-to-42.patch
  0039-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0040-i8254-Fix-migration-from-SLE11-SP2.patch
  0041-acpi_piix4-Fix-migration-from-SLE11.patch
  0042-Fix-tigervnc-long-press-issue.patch
  0043-fix-xen-hvm-direct-kernel-boot.patch
  0044-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0045-virtio-gpu-call-cleanup-mapping-fun.patch
  0046-string-input-visitor-Fix-uint64-par.patch
  0047-test-string-input-visitor-Add-int-t.patch
  0048-test-string-input-visitor-Add-uint6.patch
  0049-tests-Add-QOM-property-unit-tests.patch
  0050-tests-Add-scsi-disk-test.patch
  0051-virtio-gpu-fix-information-leak-in-.patch
  0052-display-cirrus-ignore-source-pitch-.patch
  ipxe-use-gcc6-for-more-compact-code.patch
  * SLE patches dropped (accounted for in above listed changes):
  0002-qemu-0.9.0.cvs-binfmt.patch
  0009-block-vmdk-Support-creation-of-SCSI.patch
  0010-linux-user-add-binfmt-wrapper-for-a.patch
  0011-PPC-KVM-Disable-mmu-notifier-check.patch
  0012-linux-user-fix-segfault-deadlock.patch
  0013-linux-user-binfmt-support-host-bina.patch
  0014-linux-user-Ignore-broken-loop-ioctl.patch
  0015-linux-user-lock-tcg.patch
  0016-linux-user-Run-multi-threaded-code-.patch
  0017-linux-user-lock-tb-flushing-too.patch
  0018-linux-user-Fake-proc-cpuinfo.patch
  0019-linux-user-implement-FS_IOC_GETFLAG.patch
  0020-linux-user-implement-FS_IOC_SETFLAG.patch
  0021-linux-user-XXX-disable-fiemap.patch
  0022-slirp-nooutgoing.patch
  0023-vnc-password-file-and-incoming-conn.patch
  0024-linux-user-add-more-blk-ioctls.patch
  0025-linux-user-use-target_ulong.patch
  0026-block-Add-support-for-DictZip-enabl.patch
  0027-block-Add-tar-container-format.patch
  0028-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0029-console-add-question-mark-escape-op.patch
  0030-Make-char-muxer-more-robust-wrt-sma.patch
  0031-linux-user-lseek-explicitly-cast-no.patch
  0032-virtfs-proxy-helper-Provide-_u64-f.patch
  0033-configure-Enable-PIE-for-ppc-and-pp.patch
  0034-Raise-soft-address-space-limit-to-h.patch
  0035-increase-x86_64-physical-bits-to-42.patch
  0036-vnc-provide-fake-color-map.patch
  0037-vga-Raise-VRAM-to-16-MiB-for-pc-0.1.patch
  0038-i8254-Fix-migration-from-SLE11-SP2.patch
  0039-acpi_piix4-Fix-migration-from-SLE11.patch
  0040-qtest-Increase-socket-timeout-to-ac.patch
  0041-dictzip-Fix-on-big-endian-systems.patch
  0043-xen_disk-Add-suse-specific-flush-di.patch
  0044-Split-large-discard-requests-from-b.patch
  0045-fix-xen-hvm-direct-kernel-boot.patch
  0046-xen-introduce-dummy-system-device.patch
  0047-xen-write-information-about-support.patch
  0048-xen-add-pvUSB-backend.patch
  0049-xen-move-xen_sysdev-to-xen_backend..patch
  0050-vnc-add-configurable-keyboard-delay.patch
  0051-xen-SUSE-xenlinux-unplug-for-emulat.patch
  0052-configure-add-echo_version-helper.patch
  0053-configure-support-vte-2.91.patch
  0054-scsi-esp-fix-migration.patch
  0055-hw-arm-virt-mark-the-PCIe-host-cont.patch
  0056-xen-when-removing-a-backend-don-t-r.patch
  0057-xen-drain-submit-queue-in-xen-usb-b.patch
  0058-qcow2-avoid-extra-flushes-in-qcow2.patch
  0059-qemu-bridge-helper-reduce-security-.patch
  0060-xen-use-a-common-function-for-pv-an.patch
  0061-xen_platform-unplug-also-SCSI-disks.patch
  0062-virtio-check-vring-descriptor-buffe.patch
  0063-net-vmxnet3-check-for-device_active.patch
  0064-net-vmxnet-initialise-local-tx-desc.patch
  0065-scsi-pvscsi-avoid-infinite-loop-whi.patch
  0066-ARM-KVM-Enable-in-kernel-timers-wit.patch
  0067-hw-net-Fix-a-heap-overflow-in-xlnx..patch
  0068-vmsvga-correct-bitmap-and-pixmap-si.patch
  0069-usb-xhci-fix-memory-leak-in-usb_xhc.patch
  0070-virtio-add-check-for-descriptor-s-m.patch
  0071-net-mcf-limit-buffer-descriptor-cou.patch
  0072-usb-ehci-fix-memory-leak-in-ehci_pr.patch
  0073-xhci-limit-the-number-of-link-trbs-.patch
  0074-9pfs-allocate-space-for-guest-origi.patch
  0075-9pfs-fix-memory-leak-in-v9fs_link.patch
  0076-9pfs-fix-potential-host-memory-leak.patch
  0077-9pfs-fix-memory-leak-in-v9fs_write.patch
  0078-char-serial-check-divider-value-aga.patch
  0079-net-pcnet-check-rx-tx-descriptor-ri.patch
  0080-net-eepro100-fix-memory-leak-in-dev.patch
  0081-net-rocker-set-limit-to-DMA-buffer-.patch
  0082-net-rtl8139-limit-processing-of-rin.patch
  0083-audio-intel-hda-check-stream-entry-.patch
  0084-virtio-gpu-fix-memory-leak-in-virti.patch
  0085-9pfs-fix-integer-overflow-issue-in-.patch
  0086-dma-rc4030-limit-interval-timer-rel.patch
  0087-net-imx-limit-buffer-descriptor-cou.patch
  0088-target-i386-Implement-CPUID-0xB-Ext.patch
  0089-target-i386-present-virtual-L3-cach.patch
  0090-migration-fix-inability-to-save-VM-.patch
  0091-ui-gtk-Fix-a-runtime-warning-on-vte.patch
  0092-gtk-don-t-leak-the-GtkBorder-with-V.patch
  0093-xen-fix-ioreq-handling.patch
  0094-macio-Use-blk_drain-instead-of-blk_.patch
  0095-rbd-Switch-rbd_start_aio-to-byte-ba.patch
  0096-virtio-blk-Release-s-rq-queue-at-sy.patch
  0097-virtio-blk-Remove-stale-comment-abo.patch
  0098-block-reintroduce-bdrv_flush_all.patch
  0099-qemu-use-bdrv_flush_all-for-vm_stop.patch
  0100-block-backend-remove-blkflush_all.patch
  0101-char-fix-missing-return-in-error-pa.patch
  0102-rbd-shift-byte-count-as-a-64-bit-va.patch
  0103-mirror-use-bdrv_drained_begin-bdrv_.patch
  0104-block-curl-Use-BDRV_SECTOR_SIZE.patch
  0105-block-curl-Fix-return-value-from-cu.patch
  0106-block-curl-Remember-all-sockets.patch
  0107-block-curl-Do-not-wait-for-data-bey.patch
  0108-virtio-allow-per-device-class-legac.patch
  0109-virtio-net-mark-VIRTIO_NET_F_GSO-as.patch
  0110-vhost-adapt-vhost_verify_ring_mappi.patch
  0111-ivshmem-Fix-64-bit-memory-bar-confi.patch
  0112-intel_iommu-fix-incorrect-device-in.patch
  0113-9pfs-fix-information-leak-in-xattr-.patch
  0114-9pfs-fix-memory-leak-in-v9fs_xattrc.patch
  0115-net-mcf-check-receive-buffer-size-r.patch
  0116-virtio-gpu-fix-memory-leak-in-updat.patch
  0117-virtio-gpu-fix-information-leak-in-.patch
  0118-9pfs-adjust-the-order-of-resource-c.patch
  0119-9pfs-add-cleanup-operation-in-FileO.patch
  0120-9pfs-add-cleanup-operation-for-hand.patch
  0121-9pfs-add-cleanup-operation-for-prox.patch
  0122-virtio-gpu-call-cleanup-mapping-fun.patch
  0123-string-input-visitor-Fix-uint64-par.patch
  0124-test-string-input-visitor-Add-int-t.patch
  0125-test-string-input-visitor-Add-uint6.patch
  0126-tests-Add-QOM-property-unit-tests.patch
  0127-tests-Add-scsi-disk-test.patch
  0128-usb-ehci-fix-memory-leak-in-ehci_in.patch
  0129-usbredir-free-vm_change_state_handl.patch
  0130-virtio-gpu-fix-information-leak-in-.patch
  ipxe-ath9k-Fix-buffer-overrun-for-ar9287.patch
  ipxe-ath-Fix-building-with-GCC-6.patch
  ipxe-efi-fix-garbage-bytes-in-device-path.patch
  ipxe-efi-fix-uninitialised-data-in-HII.patch
  ipxe-legacy-Fix-building-with-GCC-6.patch
  ipxe-mucurses-Fix-GCC-6-nonnull-compare-errors.patch
  ipxe-sis190-Fix-building-with-GCC-6.patch
  ipxe-skge-Fix-building-with-GCC-6.patch
  ipxe-util-v5.24-perl-errors-on-redeclare.patch
- SLE CVE, FATE, and bugzilla references not otherwise listed in
  this changelog file. The intent of this list is to indicate that
  the fix or feature continues the line of inheritance in the
  development stream of this package. The list is intended to
  satisfy searches only - refer to the SLE-12-SP2 changelog file
  for additional details.
  * fate#314468 fate#314497 fate#315125 fate#315467 fate#317015
  fate#317741 fate#317763 fate#318349 fate#319660 fate#319979
  fate#321010
  * bnc#812983 bnc#869026 bnc#869746 bnc#874413 bnc#875582 bnc#875870
  bnc#877642 bnc#877645 bnc#878541 bsc#882405 bsc#886378 bnc#893339
  bnc#893892 bnc#895369 bnc#896726 bnc#897654 bnc#905097 bnc#907805
  bnc#908380 bnc#914521 bsc#924018 bsc#929339 bsc#932267 bsc#932770
  bsc#933981 bsc#936537 bsc#937125 bsc#938344 bsc#940929 bsc#942845
  bsc#943446 bsc#944697 bsc#945404 bsc#945987 bsc#945989 bsc#946020
  bsc#947159 bnc#953518 bsc#954864 bsc#956829 bsc#957162 bsc#958491
  bsc#958917 bsc#959005 bsc#959386 bsc#960334 bsc#960708 bsc#960725
  bsc#960835 bsc#961333 bsc#961556 bsc#961691 bsc#962320 bsc#963782
  bsc#964413 bsc#970791 bsc#974141 bsc#978158 bsc#979473 bsc#982365
  bsc#989655 bsc#991466 bsc#994771 bsc#994774 bsc#996441 bsc#997858
  bsc#999212
  bsc#1001151 bsc#1002116 bsc#1005353 boo#1007263 bsc#1007769
  bsc#1008519 bsc#1009109 bsc#1013285 bsc#1013341 bsc#1013764
  bsc#1013767 bsc#1014109 bsc#1014110 bsc#1014111 bsc#1014112
  bsc#1014256 bsc#1014514 bsc#1014702 bsc#1015169 bsc#1016779
  * CVE-2014-0222 CVE-2014-0223 CVE-2014-3461 CVE-2014-3640 CVE-2014-7840
  CVE-2014-8106 CVE-2015-1779 CVE-2015-3209 CVE-2015-4037 CVE-2015-5154
  CVE-2015-5225 CVE-2015-5278 CVE-2015-5279 CVE-2015-5745 CVE-2015-6815
  CVE-2015-6855 CVE-2015-7295 CVE-2015-7512 CVE-2015-7549 CVE-2015-8345
  CVE-2015-8504 CVE-2015-8558 CVE-2015-8567 CVE-2015-8568 CVE-2015-8613
  CVE-2015-8619 CVE-2015-8743 CVE-2015-8744 CVE-2015-8745 CVE-2016-1568
  CVE-2016-1714 CVE-2016-1922 CVE-2016-1981 CVE-2016-2198 CVE-2016-3710
  CVE-2016-6490 CVE-2016-6833 CVE-2016-6888 CVE-2016-7116 CVE-2016-7155
  CVE-2016-7161 CVE-2016-9381 CVE-2016-9776 CVE-2016-9845 CVE-2016-9846
  CVE-2016-9907 CVE-2016-9908 CVE-2016-9911 CVE-2016-9912 CVE-2016-9913
  CVE-2016-9921 CVE-2016-9922
* Fri Jan 13 2017 brogers@suse.com
- Despite the previous entry about re-enabling ceph on Nov 19, 2016
  the change wasn't actually done. Do it now.
* Wed Jan 11 2017 afaerber@suse.de
- sgabios-stable-buildid.patch: Use geeko@buildhost
* Mon Nov 28 2016 afaerber@suse.de
- slof_xhci.patch: XHCI fixes (boo#977027)
* Mon Nov 28 2016 afaerber@suse.de
- Recommend x86 ROMs for emulated PCI cards on ppc, arm, others
  (bsc#1005869, michals)
* Tue Nov 22 2016 afaerber@suse.de
- Tidy SLOF patch boilerplate (michals)
* Mon Nov 21 2016 afaerber@suse.de
- Build with spice on all archs. (boo#1009438, michals)
* Sat Nov 19 2016 brogers@suse.com
- Refine the approach to producing stable builds in our ROM based
  packages. All built roms which have hostname or date calls now
  produce consistent results build to build via patch changes, so
  remove the hostname and date call workarounds. (bsc#1011213)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches added:
  0069-roms-Makefile-pass-a-packaging-time.patch
  sgabios-stable-buildid.patch
* Sat Nov 19 2016 brogers@suse.com
- Re-enable ceph (rbd) functionality in OBS builds as we've been told
  the issues which prompted us to disable it are resolved
- Address various security/stability issues
  * Fix OOB access in VMware SVGA emulation (CVE-2016-7170 bsc#998516)
  0041-vmsvga-correct-bitmap-and-pixmap-si.patch
  * Fix DOS in LSI SAS1068 emulation (CVE-2016-7157 bsc#997860)
  0042-scsi-mptconfig-fix-an-assert-expres.patch
  0043-scsi-mptconfig-fix-misuse-of-MPTSAS.patch
  * Fix DOS in Vmware pv scsi interface (CVE-2016-7156 bsc#997859)
  0044-scsi-pvscsi-limit-loop-to-fetch-SG-.patch
  * Fix DOS in USB xHCI emulation (CVE-2016-7466 bsc#1000345)
  0045-usb-xhci-fix-memory-leak-in-usb_xhc.patch
  * Fix OOB access in LSI SAS1068 emulation (CVE-2016-7423 bsc#1000397)
  0046-scsi-mptsas-use-g_new0-to-allocate-.patch
  * Fix DOS in Vmware pv scsi interface (CVE-2016-7421 bsc#999661)
  0047-scsi-pvscsi-limit-process-IO-loop-t.patch
  * Fix NULL pointer dereference in virtio processing
  (CVE-2016-7422 bsc#1000346)
  0048-virtio-add-check-for-descriptor-s-m.patch
  * Fix DOS in ColdFire Fast Ethernet Controller emulation
  (CVE-2016-7908 bsc#1002550)
  0049-net-mcf-limit-buffer-descriptor-cou.patch
  * Fix DOS in USB EHCI emulation (CVE-2016-7995 bsc#1003612)
  0050-usb-ehci-fix-memory-leak-in-ehci_pr.patch
  * Fix DOS in USB xHCI emulation (CVE-2016-8576 bsc#1003878)
  0051-xhci-limit-the-number-of-link-trbs-.patch
  * Fix DOS in virtio-9pfs (CVE-2016-8578 bsc#1003894)
  0052-9pfs-allocate-space-for-guest-origi.patch
  * Fix DOS in virtio-9pfs (CVE-2016-9105 bsc#1007494)
  0053-9pfs-fix-memory-leak-in-v9fs_link.patch
  * Fix DOS in virtio-9pfs (CVE-2016-8577 bsc#1003893)
  0054-9pfs-fix-potential-host-memory-leak.patch
  * Plug data leak in virtio-9pfs interface (CVE-2016-9103 bsc#1007454)
  0055-9pfs-fix-information-leak-in-xattr-.patch
  * Fix DOS in virtio-9pfs interface (CVE-2016-9102 bsc#1007450)
  0056-9pfs-fix-memory-leak-in-v9fs_xattrc.patch
  * Fix DOS in virtio-9pfs (CVE-2016-9106 bsc#1007495)
  0057-9pfs-fix-memory-leak-in-v9fs_write.patch
  * Fix DOS in 16550A UART emulation (CVE-2016-8669 bsc#1004707)
  0058-char-serial-check-divider-value-aga.patch
  * Fix DOS in PC-Net II emulation (CVE-2016-7909 bsc#1002557)
  0059-net-pcnet-check-rx-tx-descriptor-ri.patch
  * Fix DOS in PRO100 emulation (CVE-2016-9101 bsc#1007391)
  0060-net-eepro100-fix-memory-leak-in-dev.patch
  * Fix OOB access in Rocker switch emulation (CVE-2016-8668 bsc#1004706)
  0061-net-rocker-set-limit-to-DMA-buffer-.patch
  * Plug data leak in vmxnet3 emulation (CVE-2016-6836 bsc#994760)
  0062-net-vmxnet-initialise-local-tx-desc.patch
  * Fix DOS in RTL8139 emulation (CVE-2016-8910 bsc#1006538)
  0063-net-rtl8139-limit-processing-of-rin.patch
  * Fix DOS in Intel HDA controller emulation (CVE-2016-8909 bsc#1006536)
  0064-audio-intel-hda-check-stream-entry-.patch
  * Fix DOS in virtio-gpu (CVE-2016-7994 bsc#1003613)
  0065-virtio-gpu-fix-memory-leak-in-virti.patch
  * Fix DOS in virtio-9pfs (CVE-2016-9104 bsc#1007493)
  0066-9pfs-fix-integer-overflow-issue-in-.patch
  * Fix DOS in JAZZ RC4030 emulation (CVE-2016-8667 bsc#1004702)
  0067-dma-rc4030-limit-interval-timer-rel.patch
  * Fix DOS in i.MX NIC emulation (CVE-2016-7907 bsc#1002549)
  0068-net-imx-limit-buffer-descriptor-cou.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
* Fri Nov 11 2016 ohering@suse.de
- Use fixed timestamps and stable build_id in ipxe and other ROMs
  * Patches added:
  ipxe-stable-buildid.patch
* Mon Nov  7 2016 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patch updated:
  0040-linux-user-skip-0-flag-from-proc-se.patch -> 0040-linux-user-remove-all-traces-of-qem.patch
* Tue Sep 27 2016 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches added:
  0040-linux-user-skip-0-flag-from-proc-se.patch
* Thu Sep 22 2016 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches added:
  0039-Fix-tlb_vaddr_to_host-with-CONFIG_U.patch
* Wed Sep 21 2016 afaerber@suse.de
- Document two new options, but leave jemalloc disabled for now
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches dropped:
  0034-build-link-with-libatomic-on-powerp.patch
  * Patches renamed:
  0035-xen-SUSE-xenlinux-unplug-for-emulat.patch -> 0034-xen-SUSE-xenlinux-unplug-for-emulat.patch
  0036-qemu-bridge-helper-reduce-security-.patch -> 0035-qemu-bridge-helper-reduce-security-.patch
  0037-qemu-binfmt-conf-use-qemu-ARCH-binf.patch -> 0036-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  0038-configure-Fix-detection-of-seccomp-.patch -> 0037-configure-Fix-detection-of-seccomp-.patch
  0039-linux-user-properly-test-for-infini.patch -> 0038-linux-user-properly-test-for-infini.patch
* Sat Sep 10 2016 afaerber@suse.de
- Updated to v2.7.0: See http://wiki.qemu-project.org/ChangeLog/2.7
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches added:
  0039-linux-user-properly-test-for-infini.patch
* Tue Sep  6 2016 brogers@suse.com
- Use new kvm_stat package where available, else provide updated
  kvm_stat script.
* Wed Aug 31 2016 afaerber@suse.de
- Update to v2.7.0-rc5: See http://wiki.qemu-project.org/ChangeLog/2.7
* Tue Aug 23 2016 afaerber@suse.de
- Updated to v2.7.0-rc2: See http://wiki.qemu-project.org/ChangeLog/2.7
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.7
  * Patches dropped:
  0002-qemu-0.9.0.cvs-binfmt.patch (script rewritten upstream)
  0009-block-vmdk-Support-creation-of-SCSI.patch (deprecated)
  0014-linux-user-Ignore-broken-loop-ioctl.patch (implemented upstream)
  0024-linux-user-add-more-blk-ioctls.patch (more implemented upstream)
  0034-qtest-Increase-socket-timeout.patch (increased further upstream)
  0036-configure-Enable-libseccomp-for-ppc.patch (enabled upstream)
  0038-block-split-large-discard-requests-.patch
  0041-xen-introduce-dummy-system-device.patch
  0042-xen-write-information-about-support.patch
  0043-xen-add-pvUSB-backend.patch
  0044-xen-move-xen_sysdev-to-xen_backend..patch
  0045-vnc-add-configurable-keyboard-delay.patch
  0046-configure-add-echo_version-helper.patch
  0047-configure-support-vte-2.91.patch
  0048-hw-arm-virt-mark-the-PCIe-host-cont.patch
  0050-scsi-esp-fix-migration.patch
  0051-xen-when-removing-a-backend-don-t-r.patch
  0052-xen-drain-submit-queue-in-xen-usb-b.patch
  0053-qcow2-avoid-extra-flushes-in-qcow2.patch
  0055-xen-use-a-common-function-for-pv-an.patch
  ipxe-ath9k-Fix-buffer-overrun-for-ar9287.patch
  ipxe-mucurses-Fix-GCC-6-nonnull-compare-errors.patch
  ipxe-sis190-Fix-building-with-GCC-6.patch
  ipxe-skge-Fix-building-with-GCC-6.patch
  ipxe-ath-Fix-building-with-GCC-6.patch
  ipxe-legacy-Fix-building-with-GCC-6.patch
  ipxe-util-v5.24-perl-errors-on-redeclare.patch
  ipxe-efi-fix-garbage-bytes-in-device-path.patch
  ipxe-efi-fix-uninitialised-data-in-HII.patch
  * Patches renamed:
  0010-linux-user-add-binfmt-wrapper-for-a.patch -> 0009-linux-user-add-binfmt-wrapper-for-a.patch
  0011-PPC-KVM-Disable-mmu-notifier-check.patch  -> 0010-PPC-KVM-Disable-mmu-notifier-check.patch
  0012-linux-user-fix-segfault-deadlock.patch    -> 0011-linux-user-fix-segfault-deadlock.patch
  0013-linux-user-binfmt-support-host-bina.patch -> 0012-linux-user-binfmt-support-host-bina.patch
  0015-linux-user-lock-tcg.patch                 -> 0013-linux-user-lock-tcg.patch
  0016-linux-user-Run-multi-threaded-code-.patch -> 0014-linux-user-Run-multi-threaded-code-.patch
  0017-linux-user-lock-tb-flushing-too.patch     -> 0015-linux-user-lock-tb-flushing-too.patch
  0018-linux-user-Fake-proc-cpuinfo.patch        -> 0016-linux-user-Fake-proc-cpuinfo.patch
  0019-linux-user-implement-FS_IOC_GETFLAG.patch -> 0017-linux-user-implement-FS_IOC_GETFLAG.patch
  0020-linux-user-implement-FS_IOC_SETFLAG.patch -> 0018-linux-user-implement-FS_IOC_SETFLAG.patch
  0021-linux-user-XXX-disable-fiemap.patch       -> 0019-linux-user-XXX-disable-fiemap.patch
  0022-slirp-nooutgoing.patch                    -> 0020-slirp-nooutgoing.patch
  0023-vnc-password-file-and-incoming-conn.patch -> 0021-vnc-password-file-and-incoming-conn.patch
  0025-linux-user-use-target_ulong.patch         -> 0022-linux-user-use-target_ulong.patch
  0026-block-Add-support-for-DictZip-enabl.patch -> 0023-block-Add-support-for-DictZip-enabl.patch
  0027-block-Add-tar-container-format.patch      -> 0024-block-Add-tar-container-format.patch
  0028-Legacy-Patch-kvm-qemu-preXX-dictzip.patch -> 0025-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0029-console-add-question-mark-escape-op.patch -> 0026-console-add-question-mark-escape-op.patch
  0030-Make-char-muxer-more-robust-wrt-sma.patch -> 0027-Make-char-muxer-more-robust-wrt-sma.patch
  0031-linux-user-lseek-explicitly-cast-no.patch -> 0028-linux-user-lseek-explicitly-cast-no.patch
  0032-virtfs-proxy-helper-Provide-__u64-f.patch -> 0029-virtfs-proxy-helper-Provide-__u64-f.patch
  0033-configure-Enable-PIE-for-ppc-and-pp.patch -> 0030-configure-Enable-PIE-for-ppc-and-pp.patch
  0035-AIO-Reduce-number-of-threads-for-32.patch -> 0031-AIO-Reduce-number-of-threads-for-32.patch
  0037-dictzip-Fix-on-big-endian-systems.patch   -> 0032-dictzip-Fix-on-big-endian-systems.patch
  0039-xen_disk-Add-suse-specific-flush-di.patch -> 0033-xen_disk-Add-suse-specific-flush-di.patch
  0040-build-link-with-libatomic-on-powerp.patch -> 0034-build-link-with-libatomic-on-powerp.patch
  0049-xen-SUSE-xenlinux-unplug-for-emulat.patch -> 0035-xen-SUSE-xenlinux-unplug-for-emulat.patch
  0054-qemu-bridge-helper-reduce-security-.patch -> 0036-qemu-bridge-helper-reduce-security-.patch
  * Patches added:
  0002-qemu-binfmt-conf-Modify-default-pat.patch
  0037-qemu-binfmt-conf-use-qemu-ARCH-binf.patch
  * Package renamed trace-events-all file and linuxboot_dma.bin
  * Handle building and packaging roms for e1000e and vmxnet3 (Bruce)
  * Remove ipxe patches which are now enabled upstream (Bruce)
  * Enable seccomp for s390x (Mark Post):
  0038-configure-Fix-detection-of-seccomp-.patch
* Wed Aug 17 2016 brogers@suse.com
- Update to v2.6.1 a stable, bug-fix-only release (fate#316228)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches dropped (upstreamed):
  0041-net-mipsnet-check-packet-length-aga.patch
  0042-i386-kvmvapic-initialise-imm32-vari.patch
  0043-esp-check-command-buffer-length-bef.patch
  0044-esp-check-dma-length-before-reading.patch
  0045-scsi-pvscsi-check-command-descripto.patch
  0046-scsi-mptsas-infinite-loop-while-fet.patch
  0047-vga-add-sr_vbe-register-set.patch
  0048-scsi-megasas-use-appropriate-proper.patch
  0049-scsi-megasas-check-read_queue_head-.patch
  0050-scsi-megasas-null-terminate-bios-ve.patch
  0051-vmsvga-move-fifo-sanity-checks-to-v.patch
  0052-vmsvga-don-t-process-more-than-1024.patch
  0053-block-iscsi-avoid-potential-overflo.patch
  0054-scsi-esp-check-TI-buffer-index-befo.patch
  0060-scsi-megasas-initialise-local-confi.patch
  0065-scsi-esp-check-buffer-length-before.patch
  0066-scsi-esp-respect-FIFO-invariant-aft.patch
  0067-pci-assign-Move-Invalid-ROM-error-m.patch
  0068-Xen-PCI-passthrough-fix-passthrough.patch
  0069-scsi-esp-make-cmdbuf-big-enough-for.patch
  0071-virtio-error-out-if-guest-exceeds-v.patch
  * Patches renamed:
  0055-xen-introduce-dummy-system-device.patch
  - > 0041-xen-introduce-dummy-system-device.patch
  0056-xen-write-information-about-support.patch
  - > 0042-xen-write-information-about-support.patch
  0057-xen-add-pvUSB-backend.patch
  - > 0043-xen-add-pvUSB-backend.patch
  0058-xen-move-xen_sysdev-to-xen_backend..patch
  - > 0044-xen-move-xen_sysdev-to-xen_backend..patch
  0059-vnc-add-configurable-keyboard-delay.patch
  - > 0045-vnc-add-configurable-keyboard-delay.patch
  0061-configure-add-echo_version-helper.patch
  - > 0046-configure-add-echo_version-helper.patch
  0062-configure-support-vte-2.91.patch
  - > 0047-configure-support-vte-2.91.patch
  0063-hw-arm-virt-mark-the-PCIe-host-cont.patch
  - > 0048-hw-arm-virt-mark-the-PCIe-host-cont.patch
  0064-xen-SUSE-xenlinux-unplug-for-emulat.patch
  - > 0049-xen-SUSE-xenlinux-unplug-for-emulat.patch
  0070-scsi-esp-fix-migration.patch
  - > 0050-scsi-esp-fix-migration.patch
  0072-xen-when-removing-a-backend-don-t-r.patch
  - > 0051-xen-when-removing-a-backend-don-t-r.patch
  0073-xen-drain-submit-queue-in-xen-usb-b.patch
  - > 0052-xen-drain-submit-queue-in-xen-usb-b.patch
  0074-qcow2-avoid-extra-flushes-in-qcow2.patch
  - > 0053-qcow2-avoid-extra-flushes-in-qcow2.patch
  0075-qemu-bridge-helper-reduce-security-.patch
  - > 0054-qemu-bridge-helper-reduce-security-.patch
  0076-xen-use-a-common-function-for-pv-an.patch
  - > 0055-xen-use-a-common-function-for-pv-an.patch
* Wed Aug  3 2016 brogers@suse.com
- Temporarily disable ceph (rbd) functionality in OBS due to staging
  issues.
* Wed Aug  3 2016 brogers@suse.com
- use upstream solution for building xen-usb.c correctly
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches dropped:
  0058-usb-Fix-conditions-that-xen-usb.c-i.patch
  * Patches added:
  0058-xen-move-xen_sysdev-to-xen_backend..patch
* Wed Aug  3 2016 brogers@suse.com
- Incorporate patch carried in Xen's qemu to get same support
  as Xen switches to use the qemu package (bsc#953339, bsc#953362,
  bsc#953518, bsc#984981)
  0064-xen-SUSE-xenlinux-unplug-for-emulat.patch
- Fix more potential OOB accesses in 53C9X emulation
  (CVE-2016-5238 bsc#982959)
  0065-scsi-esp-check-buffer-length-before.patch
  0066-scsi-esp-respect-FIFO-invariant-aft.patch
- Avoid "Invalid ROM" error message when it is not appropriate
  (bsc#982927)
  0067-pci-assign-Move-Invalid-ROM-error-m.patch
- Fix failure in Xen HVM PCI passthrough (bsc#981925, bsc#989250)
  0068-Xen-PCI-passthrough-fix-passthrough.patch
- Fix OOB access in 53C9X emulation (CVE-2016-6351 bsc#990835)
  0069-scsi-esp-make-cmdbuf-big-enough-for.patch
  0070-scsi-esp-fix-migration.patch
- Avoid potential for guest initiated OOM condition in qemu through
  virtio interface (CVE-2016-5403 bsc#991080)
  0071-virtio-error-out-if-guest-exceeds-v.patch
- Fix potential crashes in qemu from pvusb bugs (bsc#986156)
  0072-xen-when-removing-a-backend-don-t-r.patch
  0073-xen-drain-submit-queue-in-xen-usb-b.patch
- Avoid unneeded flushes in qcow2 which impact performance (bsc#991296)
  0074-qcow2-avoid-extra-flushes-in-qcow2.patch
- Finally get qemu-bridge-helper the permissions it needs for non-
  root usage. The kvm group is leveraged to control access. (boo#988279)
  0075-qemu-bridge-helper-reduce-security-.patch
- Fix pvusb not working for HVM guests (bsc#991785)
  0076-xen-use-a-common-function-for-pv-an.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
- Minor spec file formatting fixes
* Thu Jul 28 2016 agraf@suse.com
- Fix ARM PCIe DMA coherency bug (bsc#991034)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches added:
  0063-hw-arm-virt-mark-the-PCIe-host-cont.patch
* Tue Jul 19 2016 afaerber@suse.de
- Clean up the udev ifdeffery to cover systemd as well (boo#860275)
- Trigger udev rules also under systemd (boo#989655)
- Suppress s390x sysctl in chroot
- Ignore s390x sysctl failures (agraf)
* Thu Jul 14 2016 brogers@suse.com
- Build SLOF for SLE12 now that we have gcc fix (bsc#949000)
- Add script for loading kvm module on s390x
- Enable seccomp and iscsi support in more configurations
- Enable more support for virtio-gpu
- Fix /dev/kvm permissions problem with package install and no
  reboot (bnc#867867)
- Remove libtool dependency
- Disable more aggressive stack protector for performance reasons
- Enable vte to be used again in more configurations (bsc#988855)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches added:
  0061-configure-add-echo_version-helper.patch
  0062-configure-support-vte-2.91.patch
* Thu Jul 14 2016 agraf@suse.com
- Remove deprecated patch "work-around-SA_RESTART-race" (boo#982208)
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches dropped:
  0002-XXX-work-around-SA_RESTART-race-wit.patch
  0003-qemu-0.9.0.cvs-binfmt.patch
  0004-qemu-cvs-alsa_bitfield.patch
  0005-qemu-cvs-alsa_ioctl.patch
  0006-qemu-cvs-alsa_mmap.patch
  0007-qemu-cvs-gettimeofday.patch
  0008-qemu-cvs-ioctl_debug.patch
  0009-qemu-cvs-ioctl_nodirection.patch
  0010-block-vmdk-Support-creation-of-SCSI.patch
  0011-linux-user-add-binfmt-wrapper-for-a.patch
  0012-PPC-KVM-Disable-mmu-notifier-check.patch
  0013-linux-user-fix-segfault-deadlock.patch
  0014-linux-user-binfmt-support-host-bina.patch
  0015-linux-user-Ignore-broken-loop-ioctl.patch
  0016-linux-user-lock-tcg.patch
  0017-linux-user-Run-multi-threaded-code-.patch
  0018-linux-user-lock-tb-flushing-too.patch
  0019-linux-user-Fake-proc-cpuinfo.patch
  0020-linux-user-implement-FS_IOC_GETFLAG.patch
  0021-linux-user-implement-FS_IOC_SETFLAG.patch
  0022-linux-user-XXX-disable-fiemap.patch
  0023-slirp-nooutgoing.patch
  0024-vnc-password-file-and-incoming-conn.patch
  0025-linux-user-add-more-blk-ioctls.patch
  0026-linux-user-use-target_ulong.patch
  0027-block-Add-support-for-DictZip-enabl.patch
  0028-block-Add-tar-container-format.patch
  0029-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0030-console-add-question-mark-escape-op.patch
  0031-Make-char-muxer-more-robust-wrt-sma.patch
  0032-linux-user-lseek-explicitly-cast-no.patch
  0033-virtfs-proxy-helper-Provide-__u64-f.patch
  0034-configure-Enable-PIE-for-ppc-and-pp.patch
  0035-qtest-Increase-socket-timeout.patch
  0036-AIO-Reduce-number-of-threads-for-32.patch
  0037-configure-Enable-libseccomp-for-ppc.patch
  0038-dictzip-Fix-on-big-endian-systems.patch
  0039-block-split-large-discard-requests-.patch
  0040-xen_disk-Add-suse-specific-flush-di.patch
  0041-build-link-with-libatomic-on-powerp.patch
  0042-net-mipsnet-check-packet-length-aga.patch
  0043-i386-kvmvapic-initialise-imm32-vari.patch
  0044-esp-check-command-buffer-length-bef.patch
  0045-esp-check-dma-length-before-reading.patch
  0046-scsi-pvscsi-check-command-descripto.patch
  0047-scsi-mptsas-infinite-loop-while-fet.patch
  0048-vga-add-sr_vbe-register-set.patch
  0049-scsi-megasas-use-appropriate-proper.patch
  0050-scsi-megasas-check-read_queue_head-.patch
  0051-scsi-megasas-null-terminate-bios-ve.patch
  0052-vmsvga-move-fifo-sanity-checks-to-v.patch
  0053-vmsvga-don-t-process-more-than-1024.patch
  0054-block-iscsi-avoid-potential-overflo.patch
  0055-scsi-esp-check-TI-buffer-index-befo.patch
  0056-xen-introduce-dummy-system-device.patch
  0057-xen-write-information-about-support.patch
  0058-xen-add-pvUSB-backend.patch
  0059-usb-Fix-conditions-that-xen-usb.c-i.patch
  0060-vnc-add-configurable-keyboard-delay.patch
  0061-scsi-megasas-initialise-local-confi.patch
  * Patches added:
  0002-qemu-0.9.0.cvs-binfmt.patch
  0003-qemu-cvs-alsa_bitfield.patch
  0004-qemu-cvs-alsa_ioctl.patch
  0005-qemu-cvs-alsa_mmap.patch
  0006-qemu-cvs-gettimeofday.patch
  0007-qemu-cvs-ioctl_debug.patch
  0008-qemu-cvs-ioctl_nodirection.patch
  0009-block-vmdk-Support-creation-of-SCSI.patch
  0010-linux-user-add-binfmt-wrapper-for-a.patch
  0011-PPC-KVM-Disable-mmu-notifier-check.patch
  0012-linux-user-fix-segfault-deadlock.patch
  0013-linux-user-binfmt-support-host-bina.patch
  0014-linux-user-Ignore-broken-loop-ioctl.patch
  0015-linux-user-lock-tcg.patch
  0016-linux-user-Run-multi-threaded-code-.patch
  0017-linux-user-lock-tb-flushing-too.patch
  0018-linux-user-Fake-proc-cpuinfo.patch
  0019-linux-user-implement-FS_IOC_GETFLAG.patch
  0020-linux-user-implement-FS_IOC_SETFLAG.patch
  0021-linux-user-XXX-disable-fiemap.patch
  0022-slirp-nooutgoing.patch
  0023-vnc-password-file-and-incoming-conn.patch
  0024-linux-user-add-more-blk-ioctls.patch
  0025-linux-user-use-target_ulong.patch
  0026-block-Add-support-for-DictZip-enabl.patch
  0027-block-Add-tar-container-format.patch
  0028-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0029-console-add-question-mark-escape-op.patch
  0030-Make-char-muxer-more-robust-wrt-sma.patch
  0031-linux-user-lseek-explicitly-cast-no.patch
  0032-virtfs-proxy-helper-Provide-__u64-f.patch
  0033-configure-Enable-PIE-for-ppc-and-pp.patch
  0034-qtest-Increase-socket-timeout.patch
  0035-AIO-Reduce-number-of-threads-for-32.patch
  0036-configure-Enable-libseccomp-for-ppc.patch
  0037-dictzip-Fix-on-big-endian-systems.patch
  0038-block-split-large-discard-requests-.patch
  0039-xen_disk-Add-suse-specific-flush-di.patch
  0040-build-link-with-libatomic-on-powerp.patch
  0041-net-mipsnet-check-packet-length-aga.patch
  0042-i386-kvmvapic-initialise-imm32-vari.patch
  0043-esp-check-command-buffer-length-bef.patch
  0044-esp-check-dma-length-before-reading.patch
  0045-scsi-pvscsi-check-command-descripto.patch
  0046-scsi-mptsas-infinite-loop-while-fet.patch
  0047-vga-add-sr_vbe-register-set.patch
  0048-scsi-megasas-use-appropriate-proper.patch
  0049-scsi-megasas-check-read_queue_head-.patch
  0050-scsi-megasas-null-terminate-bios-ve.patch
  0051-vmsvga-move-fifo-sanity-checks-to-v.patch
  0052-vmsvga-don-t-process-more-than-1024.patch
  0053-block-iscsi-avoid-potential-overflo.patch
  0054-scsi-esp-check-TI-buffer-index-befo.patch
  0055-xen-introduce-dummy-system-device.patch
  0056-xen-write-information-about-support.patch
  0057-xen-add-pvUSB-backend.patch
  0058-usb-Fix-conditions-that-xen-usb.c-i.patch
  0059-vnc-add-configurable-keyboard-delay.patch
  0060-scsi-megasas-initialise-local-confi.patch
- Enable ceph (rbd) support for aarch64
* Tue Jul 12 2016 brogers@suse.com
- Enable ceph (rbd) support
* Mon Jul  4 2016 glin@suse.com
- Fix OVMF iPXE network menu (bsc#986033, boo#987488)
  ipxe-efi-fix-garbage-bytes-in-device-path.patch
  ipxe-efi-fix-uninitialised-data-in-HII.patch
* Fri Jun 10 2016 brogers@suse.com
- Fix host information leak to guest in MegaRAID SAS 8708EM2 Host
  Bus AdapterMegaRAID SAS 8708EM2 Host Bus Adapter emulation support
  (CVE-2016-5105 bsc#982017)
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  0061-scsi-megasas-initialise-local-confi.patch
* Fri Jun 10 2016 brogers@suse.com
- Address various security/stability issues
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Fix OOB access in megasas emulated device (CVE-2016-5106 bsc#982018)
  0049-scsi-megasas-use-appropriate-proper.patch
  * Fix OOB access in megasas emulated device (CVE-2016-5107 bsc#982019)
  0050-scsi-megasas-check-read_queue_head-.patch
  * Fix OOB access in megasas emulated device (CVE-2016-5337 bsc#983961)
  0051-scsi-megasas-null-terminate-bios-ve.patch
  * Correct the vmvga fifo access checks (CVE-2016-4454 bsc#982222)
  0052-vmsvga-move-fifo-sanity-checks-to-v.patch
  * Fix potential DoS issue in vmvga processing (CVE-2016-4453 bsc#982223)
  0053-vmsvga-don-t-process-more-than-1024.patch
  * Fix heap buffer overflow flaw when iscsi protocol is used
  (CVE-2016-5126 bsc#982285)
  0054-block-iscsi-avoid-potential-overflo.patch
  * Fix OOB access in 53C9X emulation (CVE-2016-5338 bsc#983982)
  0055-scsi-esp-check-TI-buffer-index-befo.patch
- Add support to qemu for pv-usb under Xen (fate#316612)
  0056-xen-introduce-dummy-system-device.patch
  0057-xen-write-information-about-support.patch
  0058-xen-add-pvUSB-backend.patch
  0059-usb-Fix-conditions-that-xen-usb.c-i.patch
- Provide ability to rate limit keyboard events from the vnc server.
  This is part of the solution to an issue affecting openQA testing,
  where characters are lost, resulting in unexpected failures
  (bsc#974914)
  0060-vnc-add-configurable-keyboard-delay.patch
* Fri Jun  3 2016 brogers@suse.com
- Adjust to parallel changes in virglrenderer packages - no longer
  "BuildRequires" virglrenderer directly, just the devel package.
* Wed Jun  1 2016 brogers@suse.com
- Fix build compatibility with gcc6 wrt ipxe rom where compiler
  warnings are treated as errors.
  ipxe-ath9k-Fix-buffer-overrun-for-ar9287.patch
  ipxe-mucurses-Fix-GCC-6-nonnull-compare-errors.patch
  ipxe-sis190-Fix-building-with-GCC-6.patch
  ipxe-skge-Fix-building-with-GCC-6.patch
  ipxe-ath-Fix-building-with-GCC-6.patch
  ipxe-legacy-Fix-building-with-GCC-6.patch
- Fix ipxe build script which fails under perl v5.24
  ipxe-util-v5.24-perl-errors-on-redeclare.patch
- Specify build time disk space requirements for ppc64 and ppc64le
* Wed Jun  1 2016 agraf@suse.com
- Add sysctl script and %%post on s390x to allow kvm usage (bsc#975331)
* Thu May 26 2016 brogers@suse.com
- Address various security/stability issues
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Fix OOB access in MIPSnet emulated controller CVE-2016-4002 (bsc#975136)
  0042-net-mipsnet-check-packet-length-aga.patch
  * Fix possible host data leakage to guest from TPR access
  CVE-2016-4020 (bsc#975700)
  0043-i386-kvmvapic-initialise-imm32-vari.patch
  * Avoid OOB access in 53C9X emulation CVE-2016-4439 (bsc#980711)
  0044-esp-check-command-buffer-length-bef.patch
  * Avoid OOB access in 53C9X emulation CVE-2016-4441 (bsc#980723)
  0045-esp-check-dma-length-before-reading.patch
  * Avoid OOB access in Vmware PV SCSI emulation CVE-2016-4952 (bsc#981266)
  0046-scsi-pvscsi-check-command-descripto.patch
  * Avoid potential DoS in LSI SAS1068 emulation CVE-2016-4964 (bsc#981399)
  0047-scsi-mptsas-infinite-loop-while-fet.patch
  * Fix regression in vga behavior - introduced in v2.6.0 CVE-2016-3712 (bsc#978160)
  0048-vga-add-sr_vbe-register-set.patch
* Wed May 25 2016 brogers@suse.com
- Update to v2.6.0: See http://wiki.qemu-project.org/ChangeLog/2.6
- Enable SDL2, virglrenderer (for use with virtio-gpu), xfsctl, and
  tracing using default log backend
- Build efi pxe roms on x86_64
* Thu Apr 28 2016 afaerber@suse.de
- Check modules for conflicting release versions
- Suggest recently added block modules
* Thu Apr 28 2016 afaerber@suse.de
- Bump copyright in qemu.spec.in
- Enable libiscsi for Factory
- Enable seccomp for ppc64le as well
* Fri Apr 22 2016 afaerber@suse.de
- Update to v2.6.0-rc3: See http://wiki.qemu-project.org/ChangeLog/2.6
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Patches dropped (upstreamed):
  0041-tests-Use-correct-config-param-for-.patch
  * Patches renamed:
  0042-build-link-with-libatomic-on-powerp.patch -> 0041-build-link-with-libatomic-on-powerp.patch
* Wed Apr 20 2016 afaerber@suse.de
- Partially revert the last change's cleanup
- Indicate SUSE version
* Fri Apr  1 2016 olaf@aepfle.de
- Update to v2.6.0-rc0: See http://wiki.qemu-project.org/ChangeLog/2.6
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.6
  * Accept every size in DISCARD request from a guest (bsc#964427)
  0039-block-split-large-discard-requests-.patch
  * Recognize libxl flag to disable flush in block device (bsc#879425)
  0040-xen_disk-Add-suse-specific-flush-di.patch
  * Use correct flag for crypto tests
  0041-tests-Use-correct-config-param-for-.patch
  * Fix build on powerpc:
  0042-build-link-with-libatomic-on-powerp.patch
  * Patches dropped (upstreamed):
  seabios_checkrom_typo.patch
  seabios_avoid_smbios_signature_string.patch
* Tue Feb  9 2016 afaerber@suse.de
- Disable vte for Leap, fixing build
* Wed Jan 27 2016 afaerber@suse.de
- Don't drop u-boot.e500 yet - breaks testsuite
* Thu Jan 21 2016 afaerber@suse.de
- Re-enable libcacard support
- Clean up configured features
* Thu Jan 21 2016 afaerber@suse.de
- Clean up qemu-tools libcacard Provides/Obsoletes - separate again
- Drop u-boot.e500 - being packaged as u-boot-ppce500
* Fri Jan  8 2016 afaerber@suse.de
- Update to v2.5.0: See http://wiki.qemu-project.org/ChangeLog/2.5
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.5
  * Patches dropped (upstreamed):
  0039-tests-Fix-check-report-qtest-target.patch
* Tue Dec 29 2015 stefan.bruens@rwth-aachen.de
- Fix build on openSUSE 13.2
* Tue Dec  1 2015 agraf@suse.com
- Fix testsuite on 32bit systems (bsc#957379)
* Sun Nov 22 2015 afaerber@suse.de
- Update to v2.5.0-rc1: See http://wiki.qemu-project.org/ChangeLog/2.5
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.5
  * Rebase libseccomp enablement:
  0037-Revert-Revert-seccomp-tests-that-al.patch -> 0037-configure-Enable-libseccomp-for-ppc.patch
  * Provide qemu-ga and qemu-ipxe for qemu-testsuite
- Clean up qemu-ksm recommendation
* Sun Nov 22 2015 afaerber@suse.de
- Fix SLE11 build by fixing systemd conditionalization (from olh)
* Thu Nov 19 2015 afaerber@suse.de
- Update to v2.5.0-rc0: See http://wiki.qemu-project.org/ChangeLog/2.5
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.5
  * Patches dropped (upstream):
  0038-tcg-aarch64-Fix-tcg_out_qemu_-ld-st.patch
  0039-tests-Unique-test-path-for-string-v.patch
  gcc5-ipxe-add-missing-const-qualifiers.patch
  gcc5-ipxe-ath9k-Remove-confusing-logic-inversion-in-an-ANI-var.patch
  SLOF_ppc64le.patch
  * Patch renamed:
  0040-dictzip-Fix-on-big-endian-systems.patch -> 0038-dictzip-Fix-on-big-endian-systems.patch
  * --enable-smartcard-nss -> --enable-smartcard
  Needs an external libcacard, so drop it for now.
  * Drop --enable-vnc-tls
  * Require xz-devel for ipxe build
  * Package qemu-ga(8) man page
  * Package ivshmem-{client,server}
  * Patches added:
  0039-tests-Fix-check-report-qtest-target.patch
* Thu Nov 19 2015 tampakrap@opensuse.org
- Add systemd unit file and udev rules for qemu guest agent
  - taken from the SLE12 / Leap package, see boo#955707
* Wed Oct 28 2015 afaerber@suse.de
- Add _constraints file (based on work by kenljohnson)
* Tue Oct 20 2015 afaerber@suse.de
- Enable SLOF build for ppc64le, too, now (bsc#949000, bsc#949016)
* Mon Oct 12 2015 afaerber@suse.de
- Allow building SLOF on ppc64le (bsc#949016)
  SLOF_ppc64le.patch
- Add two checks for DictZip and tar qemu-img behavior (bsc#945778)
  * Clean up qemu-testsuite build/installation
* Thu Oct  8 2015 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.4
  * Fix endianness issues in DictZip block driver (bsc#937572, bsc#945778)
  0027-block-Add-support-for-DictZip-enabl.patch
  0028-block-Add-tar-container-format.patch
  0040-dictzip-Fix-on-big-endian-systems.patch
* Thu Oct  8 2015 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.4
  * Fix qemu-testsuite for glib2-2.46.0 by assuring uniqueness of paths
  0039-tests-Unique-test-path-for-string-v.patch
* Thu Oct  8 2015 afaerber@suse.de
- Build SLOF on ppc64 (bsc#949016, thanks to k0da)
  * Simplify x86 fw logic while at it
- No need to enable KVM for armv6hl
- Add notice about pre_checkin.sh to update_git.sh
* Thu Sep  3 2015 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.4
  * Fix aarch64 TCG:
  0038-tcg-aarch64-Fix-tcg_out_qemu_-ld-st.patch
* Wed Aug 12 2015 afaerber@suse.de
- Update to v2.4.0: See http://wiki.qemu-project.org/ChangeLog/2.4
* Fri Jul 24 2015 afaerber@suse.de
- Update to v2.4.0-rc2: See http://wiki.qemu-project.org/ChangeLog/2.4
  * Provide qemu-img symlink instead of passing QTEST_QEMU_IMG
* Fri Jul 17 2015 afaerber@suse.de
- Update to v2.4.0-rc1: See http://wiki.qemu-project.org/ChangeLog/2.4
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.4
  * Patches dropped:
  0037-linux-user-Allocate-thunk-size-dyna.patch
  0039-s390x-Fix-stoc-direction.patch
  0040-s390x-Add-interlocked-access-facili.patch
  0041-fdc-force-the-fifo-access-to-be-in-.patch
  0042-rules.mak-Force-CFLAGS-for-all-obje.patch
  0043-qcow2-Set-MIN_L2_CACHE_SIZE-to-2.patch
  0044-hw-arm-boot-Increase-fdt-alignment.patch
  * Patches renamed:
  0038-Revert-Revert-seccomp-tests-that-al.patch -> 0037-Revert-Revert-seccomp-tests-that-al.patch
  * Package new vgabios-virtio.bin
  * target-x86_64.conf was dropped
  * Add qemu-block-dmg module sub-package
  * Set QTEST_QEMU_IMG variable for ahci-test
  * --enable-quorum and --enable-vnc-ws are no longer available
* Mon Jul 13 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
- Fix -kernel boot for AArch64
  * Patches added:
  0044-hw-arm-boot-Increase-fdt-alignment.patch
* Sat Jul  4 2015 crrodriguez@opensuse.org
- Use libusb-1_0-devel as buildrequires, not the old
  unused compatibility layer in libusb-devel
* Mon Jun  1 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
- Fix qemu2 cow caching (bsc#933132)
  * Patches added:
  0043-qcow2-Set-MIN_L2_CACHE_SIZE-to-2.patch
* Tue May 26 2015 jslaby@suse.com
- Patch queue updated from git://github.com/jirislaby/qemu.git opensuse-2.3
  * Patches added:
  0042-rules.mak-Force-CFLAGS-for-all-obje.patch
  gcc5-ipxe-add-missing-const-qualifiers.patch
  gcc5-ipxe-ath9k-Remove-confusing-logic-inversion-in-an-ANI-var.patch
* Thu May 14 2015 afaerber@suse.de
- Fix CVE-2015-3456 (boo#929339)
  0041-fdc-force-the-fifo-access-to-be-in-.patch
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
* Tue May 12 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches added:
  0040-s390x-Add-interlocked-access-facili.patch
- Disable dependency on libnuma for s390x (not available in SLE12)
* Wed Apr 29 2015 afaerber@suse.de
- Update to v2.3.0: See http://wiki.qemu-project.org/ChangeLog/2.3
- Disable iotests for now
* Wed Apr 22 2015 afaerber@suse.de
- Update to v2.3.0-rc4: See http://wiki.qemu-project.org/ChangeLog/2.3
* Mon Apr 20 2015 afaerber@suse.de
- Update seabios_avoid_smbios_signature_string.patch with version
  applied upstream
* Wed Apr 15 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
- Fix s390x stoc instructions
  0039-s390x-Fix-stoc-direction.patch
* Tue Apr 14 2015 afaerber@suse.de
- Update to v2.3.0-rc3: See http://wiki.qemu-project.org/ChangeLog/2.3
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches dropped (applied upstream):
  0037-tcg-tcg-op.c-Fix-ld-st-of-64-bit-va.patch
  * Patches renamed:
  0038-linux-user-Allocate-thunk-size-dyna.patch -> 0037-linux-user-Allocate-thunk-size-dyna.patch
  * Revert -rc3 change to disable seccomp on non-x86 architectures
  0038-Revert-Revert-seccomp-tests-that-al.patch
* Tue Apr 14 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
- Fix qemu-linux-user on powerpc
  * Patches added:
  0038-linux-user-Allocate-thunk-size-dyna.patch
* Sat Apr 11 2015 afaerber@suse.de
- Split off qemu-testsuite.spec
  * Package check-report.html and check-report.xml
  * Enable quick iotests
- Dropped 0030-net-Warn-about-default-MAC-address.patch
  The warning is relevant only for bridged setups, not for the
  default SLIRP based -net user / -netdev user setup,
  and it breaks output expectations of some iotests.
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches renamed:
  0031-console-add-question-mark-escape-op.patch -> 0030-console-add-question-mark-escape-op.patch
  0032-Make-char-muxer-more-robust-wrt-sma.patch -> 0031-Make-char-muxer-more-robust-wrt-sma.patch
  0033-linux-user-lseek-explicitly-cast-no.patch -> 0032-linux-user-lseek-explicitly-cast-no.patch
  0034-virtfs-proxy-helper-Provide-__u64-f.patch -> 0033-virtfs-proxy-helper-Provide-__u64-f.patch
  0035-configure-Enable-PIE-for-ppc-and-pp.patch -> 0034-configure-Enable-PIE-for-ppc-and-pp.patch
  0036-qtest-Increase-socket-timeout.patch       -> 0035-qtest-Increase-socket-timeout.patch
  0037-AIO-Reduce-number-of-threads-for-32.patch -> 0036-AIO-Reduce-number-of-threads-for-32.patch
  0038-tcg-tcg-op.c-Fix-ld-st-of-64-bit-va.patch -> 0037-tcg-tcg-op.c-Fix-ld-st-of-64-bit-va.patch
- Re-enable glusterfs on Factory (updated from v3.6.1 to v3.6.2)
- Re-enable seccomp for armv7l (libseccomp submission pending)
* Fri Apr 10 2015 afaerber@suse.de
- Suppress seccomp for Factory armv7l (broken in libseccomp v2.2.0)
- Disable glusterfs explicitly on Factory, SLE12 and before 13.1
* Thu Apr  9 2015 afaerber@suse.de
- Enable glusterfs and package as qemu-block-gluster
  glusterfs post-v3.5.3 and v3.6.1/v3.6.2 have switched the
  glusterfs-api.pc version incompatibly, so only 13.1+13.2 for now
- Use macro for module Conflicts
* Thu Apr  9 2015 afaerber@suse.de
- Tidy configure options:
  * Move --enable-modules to build options
  * Sort libusb alphabetically
  * Explicitly enable attr, bluez, fdt, lzo, tpm, vhdx, vhost-net,
  vnc, xen-pci-passthrough
  * Enable bzip2
  * Enable libssh2 where possible and package as qemu-block-ssh
  * Enable numa where a compatible numactl is available
  * Enable quorum where a compatible gnutls is available
  * Enable snappy where possible
  * Prepare to enable glusterfs
  * Explicitly enable the nop tracing backend (to be revisited)
  * Explicitly disable Archipelago, as we don't have libxseg and it's
  incompatibly GPL-3.0+
  * Explicitly disable libiscsi, libnfs, netmap and rbd
  as we don't have packages
  * Drop deprecated --enable-virtio-blk-data-plane (now default)
* Wed Apr  8 2015 afaerber@suse.de
- Fix 64-bit TCG stores on 32-bit Big Endian hosts (ppc)
  0038-tcg-tcg-op.c-Fix-ld-st-of-64-bit-va.patch
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
* Wed Apr  8 2015 afaerber@suse.de
- Update to v2.3.0-rc2: See http://wiki.qemu-project.org/ChangeLog/2.3
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches dropped (upstreamed):
  0038-fw_cfg-test-Fix-test-path-to-includ.patch
  0039-rcu-tests-fix-compilation-on-32-bit.patch
* Sat Mar 28 2015 brogers@suse.com
- make check was failing due to a bogus SMBIOS signature being
  encountered within SeaBIOS. Avoid having that signature stored
  randomly within the SeaBIOS image.
  * seabios_avoid_smbios_signature_string.patch
* Thu Mar 26 2015 afaerber@suse.de
- Build x86 firmware only from 13.1 on (11.4 was broken, surpassing 128 KB)
- Update to v2.3.0-rc1: See http://wiki.qemu-project.org/ChangeLog/2.3
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches dropped (upstreamed):
  0038-linux-user-Fix-emulation-of-splice-.patch
  0039-ide-fix-cmd_write_pio-when-nsectors.patch
  0040-ide-fix-cmd_read_pio-when-nsectors-.patch
  0041-ahci-Fix-sglist-offset-manipulation.patch
  0042-ahci-test-improve-rw-buffer-pattern.patch
  0045-linux-user-fix-broken-cpu_copy.patch
  * Patches renamed:
  0043-fw_cfg-test-Fix-test-path-to-includ.patch -> 0038-fw_cfg-test-Fix-test-path-to-includ.patch
  0044-rcu-tests-fix-compilation-on-32-bit.patch -> 0039-rcu-tests-fix-compilation-on-32-bit.patch
* Mon Mar 23 2015 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Patches added:
  0045-linux-user-fix-broken-cpu_copy.patch
* Sat Mar 21 2015 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * Make test path for fw_cfg-test unique (including architecture)
  0043-fw_cfg-test-Fix-test-path-to-includ.patch
  * Fix rcu tests build on ppc (undefined reference to `__sync_fetch_and_add_8')
  0044-rcu-tests-fix-compilation-on-32-bit.patch
- Fix typo in SeaBIOS size check
  seabios_checkrom_typo.patch
* Fri Mar 20 2015 afaerber@suse.de
- Update to v2.3.0-rc0: See http://wiki.qemu-project.org/ChangeLog/2.3
  * Updated update_git.sh accordingly
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.3
  * seabios_128kb.patch: Added patch to squeeze SeaBIOS into 128 KB
  with our gcc 4.8.3 (brogers@suse.com)
- Renamed 0030-Legacy-Patch-kvm-qemu-preXX-report-.patch to
  0030-net-Warn-about-default-MAC-address.patch:
  Suppress warning for accel=qtest, to sanitize make check results.
- Added patches to fix ahci-test:
  0039-ide-fix-cmd_write_pio-when-nsectors.patch
  0040-ide-fix-cmd_read_pio-when-nsectors-.patch
  0041-ahci-Fix-sglist-offset-manipulation.patch
  0042-ahci-test-improve-rw-buffer-pattern.patch
* Sun Mar  1 2015 afaerber@suse.de
- Update company name in spec file templates
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.2
  * Patches added:
  0038-linux-user-Fix-emulation-of-splice-.patch
* Sun Feb 22 2015 mpluskal@suse.com
- Add user kvm when installing guest-agent.
- Use macro to update udev_rules when available
* Wed Feb 11 2015 afaerber@suse.de
- Fix packaging of e500 U-Boot
- Don't rely on wildcard with explicit excludes
* Wed Jan 14 2015 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.2
  * Patches added:
  0037-AIO-Reduce-number-of-threads-for-32.patch
* Mon Jan 12 2015 afaerber@suse.de
- Update to v2.2.0: See http://wiki.qemu-project.org/ChangeLog/2.2
  * Updated DictZip and Tar block backends accordingly
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.2
  * Patches dropped:
  0015-target-arm-linux-user-no-tb_flush-o.patch (tb_flush() not called)
  0037-tests-Don-t-run-qom-test-twice.patch (superseded)
  0039-linux-user-Cast-validity-checks-on-.patch (helper function introduced)
  0040-linux-user-Convert-blkpg-to-use-a-s.patch (upstreamed)
  * Patched renumbered:
  0016-linux-user-Ignore-broken-loop-ioctl.patch -> 0015-linux-user-Ignore-broken-loop-ioctl.patch
  0017-linux-user-lock-tcg.patch                 -> 0016-linux-user-lock-tcg.patch
  0018-linux-user-Run-multi-threaded-code-.patch -> 0017-linux-user-Run-multi-threaded-code-.patch
  0019-linux-user-lock-tb-flushing-too.patch     -> 0018-linux-user-lock-tb-flushing-too.patch
  0020-linux-user-Fake-proc-cpuinfo.patch        -> 0019-linux-user-Fake-proc-cpuinfo.patch
  0021-linux-user-implement-FS_IOC_GETFLAG.patch -> 0020-linux-user-implement-FS_IOC_GETFLAG.patch
  0022-linux-user-implement-FS_IOC_SETFLAG.patch -> 0021-linux-user-implement-FS_IOC_SETFLAG.patch
  0023-linux-user-XXX-disable-fiemap.patch       -> 0022-linux-user-XXX-disable-fiemap.patch
  0024-slirp-nooutgoing.patch                    -> 0023-slirp-nooutgoing.patch
  0025-vnc-password-file-and-incoming-conn.patch -> 0024-vnc-password-file-and-incoming-conn.patch
  0026-linux-user-add-more-blk-ioctls.patch      -> 0025-linux-user-add-more-blk-ioctls.patch
  0027-linux-user-use-target_ulong.patch         -> 0026-linux-user-use-target_ulong.patch
  0028-block-Add-support-for-DictZip-enabl.patch -> 0027-block-Add-support-for-DictZip-enabl.patch
  0029-block-Add-tar-container-format.patch      -> 0028-block-Add-tar-container-format.patch
  0030-Legacy-Patch-kvm-qemu-preXX-dictzip.patch -> 0029-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  0031-Legacy-Patch-kvm-qemu-preXX-report-.patch -> 0030-Legacy-Patch-kvm-qemu-preXX-report-.patch
  0032-console-add-question-mark-escape-op.patch -> 0031-console-add-question-mark-escape-op.patch
  0033-Make-char-muxer-more-robust-wrt-sma.patch -> 0032-Make-char-muxer-more-robust-wrt-sma.patch
  0034-linux-user-lseek-explicitly-cast-no.patch -> 0033-linux-user-lseek-explicitly-cast-no.patch
  0035-virtfs-proxy-helper-Provide-__u64-f.patch -> 0034-virtfs-proxy-helper-Provide-__u64-f.patch
  0036-configure-Enable-PIE-for-ppc-and-pp.patch -> 0035-configure-Enable-PIE-for-ppc-and-pp.patch
  0038-qtest-Increase-socket-timeout.patch       -> 0036-qtest-Increase-socket-timeout.patch
* Mon Sep  1 2014 afaerber@suse.de
- Enable RDMA support for SLE12 and later
* Thu Aug 28 2014 afaerber@suse.de
- Copy the freshly built s390-ccw.img over to the location
  from which it is installed (bnc#893535)
* Fri Aug 22 2014 agraf@suse.com
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
  * Patches added:
  0039-linux-user-Cast-validity-checks-on-.patch
  0040-linux-user-Convert-blkpg-to-use-a-s.patch
* Thu Aug 21 2014 afaerber@suse.de
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
- Revert use of %%{version} in Source line as it breaks update_git.sh
* Thu Aug  7 2014 coolo@suse.com
- build libcaca from a different spec file to avoid cycles with
  spice
* Wed Aug  6 2014 coolo@suse.com
- update to v2.1.0: http://wiki.qemu-project.org/ChangeLog/2.1
- Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
  * Patches dropped:
  0039-fix-full-frame-updates-for-VNC-clie.patch
  0040-vnc-update-fix.patch
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Fri Jul 25 2014 afaerber@suse.de
- Backported VNC fixes for openQA (bnc#888142):
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
  * Patches added:
  0039-fix-full-frame-updates-for-VNC-clie.patch
  0040-vnc-update-fix.patch
* Wed Jul 23 2014 afaerber@suse.de
- Update to v2.1.0-rc3: http://wiki.qemu-project.org/ChangeLog/2.1
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
  * Patches dropped:
  0039-module-Simplify-module_load.patch
  0040-module-Don-t-complain-when-a-module.patch
  * Updated update_git.sh script accordingly
* Wed Jul 16 2014 afaerber@suse.de
- Update to v2.1.0-rc2: http://wiki.qemu-project.org/ChangeLog/2.1
  * Patch queue updated from git://github.com/openSUSE/qemu.git opensuse-2.1
  * Patches dropped:
  0041-tests-Fix-unterminated-string-outpu.patch
  0042-libqos-Fix-PC-PCI-endianness-glitch.patch
  0043-qtest-fix-vhost-user-test-compilati.patch
  * Updated update_git.sh accordingly
  * Extended update_git.sh to add generated patch names to change log
* Wed Jul  9 2014 afaerber@suse.de
- Update to v2.1.0-rc0: http://wiki.qemu-project.org/ChangeLog/2.1
  * xen_disk discard support now upstream
  0037-xen_disk-add-discard-support.patch dropped
  * PowerPC ELF v2 support now upstream
  0045-tcg-ppc64-Support-the-ELFv2-ABI.patch dropped
  * Patches renamed during rebase:
  0015-linux-user-arm-no-tb_flush-on-reset.patch -> 0015-target-arm-linux-user-no-tb_flush-o.patch
  * Patches reordered due to rebase:
  0038-tests-Don-t-run-qom-test-twice.patch -> 0037-tests-Don-t-run-qom-test-twice.patch
  0041-qtest-Increase-socket-timeout.patch -> 0038-qtest-Increase-socket-timeout.patch
  0071-module-Simplify-module_load.patch -> 0039-module-Simplify-module_load.patch
  0072-module-Don-t-complain-when-a-module.patch -> 0040-module-Don-t-complain-when-a-module.patch
  * Patches automatically dropped on rebase:
  0039-qtest-Assure-that-init_socket-s-lis.patch
  0040-qtest-Add-error-reporting-to-socket.patch
  0042-qtest-Be-paranoid-about-accept-addr.patch
  0043-arm-translate.c-Fix-smlald-Instruct.patch
  0044-target-arm-A64-fix-unallocated-test.patch
  0046-vmstate-add-VMS_MUST_EXIST.patch
  0047-vmstate-add-VMSTATE_VALIDATE.patch
  0048-virtio-net-fix-buffer-overflow-on-i.patch
  0049-virtio-net-out-of-bounds-buffer-wri.patch
  0050-virtio-out-of-bounds-buffer-write-o.patch
  0051-ahci-fix-buffer-overrun-on-invalid-.patch
  0052-hpet-fix-buffer-overrun-on-invalid-.patch
  0053-hw-pci-pcie_aer.c-fix-buffer-overru.patch
  0054-pl022-fix-buffer-overun-on-invalid-.patch
  0055-vmstate-fix-buffer-overflow-in-targ.patch
  0056-virtio-avoid-buffer-overrun-on-inco.patch
  0057-virtio-validate-num_sg-when-mapping.patch
  0058-pxa2xx-avoid-buffer-overrun-on-inco.patch
  0059-ssd0323-fix-buffer-overun-on-invali.patch
  0060-tsc210x-fix-buffer-overrun-on-inval.patch
  0061-zaurus-fix-buffer-overrun-on-invali.patch
  0062-virtio-scsi-fix-buffer-overrun-on-i.patch
  0063-vmstate-s-VMSTATE_INT32_LE-VMSTATE_.patch
  0064-usb-sanity-check-setup_index-setup_.patch
  0065-savevm-Ignore-minimum_version_id_ol.patch
  0066-ssi-sd-fix-buffer-overrun-on-invali.patch
  0067-openpic-avoid-buffer-overrun-on-inc.patch
  0068-virtio-net-out-of-bounds-buffer-wri.patch
  0069-virtio-validate-config_len-on-load.patch
  0070-virtio-allow-mapping-up-to-max-queu.patch
  * iPXE fixes now included
  ipxe-build-Work-around-bug-in-gcc-4.8.patch dropped
  ipxe-build-Avoid-strict-aliasing-warning.patch dropped
  ipxe-zbin-Fix-size-used-for-memset-in-al.patch dropped
  * SeaVGABIOS fix now included
  vgabios-Make-sure-stdvga_list_modes-doesn-t-overrun-.patch dropped
  * Modified update_git.sh accordingly
- Update to v2.1.0-rc1: http://wiki.qemu-project.org/ChangeLog/2.1
  * 0041-tests-Fix-unterminated-string-outpu.patch: Test fix
  * 0042-libqos-Fix-PC-PCI-endianness-glitch.patch: Test fix for ppc
  * 0043-qtest-fix-vhost-user-test-compilati.patch: Test fix for SP3
  * Modified update_git.sh accordingly
* Mon Jun 23 2014 afaerber@suse.de
- Move block-curl.so to new qemu-block-curl package, avoiding a
  dependency of qemu-tools on qemu for Xen (bnc#882008)
  * Avoid the reported error message about missing modules
  0071-module-Simplify-module_load.patch
  0072-module-Don-t-complain-when-a-module.patch
- Improve update_git.sh performance (backport from SLE12)
* Mon Jun  2 2014 brogers@suse.com
- only build the x86 firmware on x86, ensuring consistent binaries
- remove un-needed pmtools BuildRequires
- Fix vga related problem doing direct kernel boot for SLES 10 and
  SLES 11 guests (bnc#880625)
  vgabios-Make-sure-stdvga_list_modes-doesn-t-overrun-.patch
- Probe vhost-net module on SLE11 (copied from SP3 package)
* Sat May 24 2014 afaerber@suse.de
- Fix CVE-2013-4148 (bnc#864812)
  0048-virtio-net-fix-buffer-overflow-on-i.patch
- Fix CVE-2013-4149 (bnc#864649)
  0068-virtio-net-out-of-bounds-buffer-wri.patch
- Fix CVE-2013-4150 (bnc#864650)
  0049-virtio-net-out-of-bounds-buffer-wri.patch
- Fix CVE-2013-4151 (bnc#864653)
  0050-virtio-out-of-bounds-buffer-write-o.patch
- Fix CVE-2013-4526 (bnc#864671)
  0051-ahci-fix-buffer-overrun-on-invalid-.patch
- Fix CVE-2013-4527 (bnc#864673)
  0052-hpet-fix-buffer-overrun-on-invalid-.patch
- Fix CVE-2013-4529 (bnc#864678)
  0053-hw-pci-pcie_aer.c-fix-buffer-overru.patch
- Fix CVE-2013-4530 (bnc#864682)
  0054-pl022-fix-buffer-overun-on-invalid-.patch
- Fix CVE-2013-4531 (bnc#864796)
  0055-vmstate-fix-buffer-overflow-in-targ.patch
- Fix CVE-2013-4533 (bnc#864655)
  0058-pxa2xx-avoid-buffer-overrun-on-inco.patch
- Fix CVE-2013-4534 (bnc#864811)
  0067-openpic-avoid-buffer-overrun-on-inc.patch
- Fix CVE-2013-4535 / CVE-2013-4536 (bnc#864665)
  0057-virtio-validate-num_sg-when-mapping.patch
- Fix CVE-2013-4537 (bnc#864391)
  0066-ssi-sd-fix-buffer-overrun-on-invali.patch
- Fix CVE-2013-4538 (bnc#864769)
  0059-ssd0323-fix-buffer-overun-on-invali.patch
- Fix CVE-2013-4539 (bnc#864805)
  0060-tsc210x-fix-buffer-overrun-on-inval.patch
- Fix CVE-2013-4540 (bnc#864801)
  0061-zaurus-fix-buffer-overrun-on-invali.patch
- Fix CVE-2013-4541 (bnc#864802)
  0064-usb-sanity-check-setup_index-setup_.patch
- Fix CVE-2013-4542 (bnc#864804)
  0062-virtio-scsi-fix-buffer-overrun-on-i.patch
- Fix CVE-2013-6399 (bnc#864814)
  0067-virtio-avoid-buffer-overrun-on-inco.patch
- Fix CVE-2014-0182 (bnc#874788)
  0069-virtio-validate-config_len-on-load.patch
- Backported patch from stable branch (brogers):
  0070-virtio-allow-mapping-up-to-max-queu.patch
* Wed May 14 2014 afaerber@suse.de
- Fix conflict with libcacard 0.1.2 from project security
  * Adopt description and group for libcacard-devel from there
- Drop libcacard.{a,la} from libcacard-devel
  If needed, libcacard.a should go into a libcacard-devel-static.
- Change qemu-extra to explicitly list qemu-system-* binaries
* Tue May 13 2014 afaerber@suse.de
- ABI fixes for ppc64le TCG. Addresses acpi-test failures.
  0045-tcg-ppc64-Support-the-ELFv2-ABI.patch
* Sat May 10 2014 afaerber@suse.de
- Split 60-kvm.rules into 60-kvm.rules and 60-kvm.x86.rules
- Install udev rules on s390x, ppc and arm, too
  * Clean up KVM vs. qemu-kvm conditionals
- Package qemu-system-ppcemb in qemu-ppc and qemu-system-aarch64
  in qemu-arm
* Fri Apr 18 2014 afaerber@suse.de
- Fix aarch64 emulation issues:
  0043-arm-translate.c-Fix-smlald-Instruct.patch
  0044-target-arm-A64-fix-unallocated-test.patch
* Thu Apr 17 2014 afaerber@suse.de
- Attempt to solve or debug occasional qtest fd assertions
  0039-qtest-Assure-that-init_socket-s-lis.patch
  0040-qtest-Add-error-reporting-to-socket.patch
  0041-qtest-Increase-socket-timeout.patch
  0042-qtest-Be-paranoid-about-accept-addr.patch
* Thu Apr 17 2014 afaerber@suse.de
- Update to v2.0.0: cf. http://wiki.qemu-project.org/ChangeLog/2.0
  * Update update_git.sh script accordingly
* Mon Apr 14 2014 afaerber@suse.de
- Update to v2.0.0-rc3: cf. http://wiki.qemu-project.org/ChangeLog/2.0
  * Update update_git.sh script accordingly
  * Addresses CVE-2014-0150 (bnc#873235), CVE-2013-4544 (bnc#873613)
* Fri Apr 11 2014 afaerber@suse.de
- Update to v2.0.0-rc2: cf. http://wiki.qemu-project.org/ChangeLog/2.0
  * Update update_git.sh script accordingly
  * Resolves Gtk mouse issues (bnc#849587)
  * Fixes endianness-test failures for prep machine on Big Endian host
* Fri Apr  4 2014 afaerber@suse.de
- Fix qemu-kvm script for s390x (bnc#869021) (bfrogers)
- Fix ksm.service file permissions to not be executable w/o shebang
- Re-enable Gtk build on 11.4 (fixes unpackaged qemu.mo files error)
- Fix SLE11 SP3 build by making sub-package "noarch" conditional
  * Do not exclude qemu-ifup from qemu package when not installing
- Speed up %%check by not running qom-test twice for some targets
  0038-tests-Don-t-run-qom-test-twice.patch
* Thu Apr  3 2014 afaerber@suse.de
- Updated to v2.0.0-rc1: cf. http://wiki.qemu-project.org/ChangeLog/2.0
  * Update update_git.sh script accordingly
  * Resolves breakage of live migration (bnc#871302)
  * Addresses CVE-2014-0142, CVE-2014-0143, CVE-2014-0144,
  CVE-2014-0145, CVE-2014-0146, CVE-2014-0147 (bnc#870439)
- Drop 0037-roms-Build-vgabios.bin.patch (unneeded)
* Tue Apr  1 2014 afaerber@suse.de
- Enhance update_git.sh script
  * Fix duplicate .patch for short filenames
  * Read SeaBIOS version from QEMU tarball
* Mon Mar 31 2014 afaerber@suse.de
- Re-create qemu-2.0.0-rc0.tar.bz2 to include SeaBIOS .version
* Fri Mar 28 2014 afaerber@suse.de
- Improve update_git.sh script to use a user-agnostic git symlink
* Wed Mar 26 2014 brogers@suse.com
- Tidy up qemu.spec a bit: white space, line length, use macros
  as appropriate
- Improve update_git.sh to not change files in OBS if the file
  remains unchanged
* Wed Mar 26 2014 afaerber@suse.de
- Fix library directory
- Set default file attributes for qemu-ksm
- Enable Smartcard emulation
  * Reorder package definitions to avoid %%version troubles
* Wed Mar 19 2014 afaerber@suse.de
- Update to v2.0.0-rc0: Cf. http://wiki.qemu-project.org/ChangeLog/2.0
  * Adapt update_git.sh script accordingly
  * Generate package version automatically from VERSION file
  * Switch from LGPL VGABIOS to SeaVGABIOS
  * Enable modules
  * Explicitly enable virtio-blk-data-plane (no functional change)
  * Package new firmware blobs
* Fri Mar  7 2014 speilicke@suse.com
- Add qemu-ksm subpackage providing a systemd service file for
  enabling / disabling Kernel Samepage Merging. It is independent of
  qemu (but recommended by it).
* Fri Feb 28 2014 afaerber@suse.de
- Move target-x86_64.conf to qemu-x86 sub-package
* Thu Feb 20 2014 afaerber@suse.de
- Split out KVM architectures to per-architecture subpackages
- Suggest qemu-lang package
* Tue Feb 18 2014 brogers@suse.com
- enable usb passthrough via --enable-libusb config option
* Sat Feb 15 2014 brogers@suse.com
- Fix improperly formatted wrapper script (bnc#864094)
* Fri Feb 14 2014 afaerber@suse.de
- Enable make check
* Thu Feb 13 2014 brogers@suse.com
- Use Provides/Obsoletes as means to transition kvm users to the
  qemu-kvm package
* Wed Feb 12 2014 brogers@suse.com
- Migrate kvm package contents to a new qemu-kvm sub-package, and
  move the kvm related udev rules to the qemu package. (The kvm
  package is being retired).
  Add qemu-ifup
  Add qemu-kvm.1.gz
  Add kvm_stat
  Add 60-kvm.rules
  Add 80-kvm.rules
* Mon Feb  3 2014 afaerber@suse.de
- Implement discard support for xen_disk (olh) (fate#316071)
  0042-xen_disk-add-discard-support.patch.patch
* Fri Jan 24 2014 afaerber@suse.de
- Simplified VMDK SCSI support handling (backport from 13.1/v1.6.2)
  * Increases the number of heads for SCSI from 16 to 255
* Fri Jan 17 2014 afaerber@suse.de
- Bump copyright in qemu.spec.in
- Use vte-devel instead of vte2-devel and force using Gtk3,
  reported by Takashi and Dirk (bnc#840607, bnc#849587).
* Mon Jan 13 2014 coolo@suse.com
- xen dropped support for i586, so don't buildrequire it
* Thu Jan  2 2014 afaerber@suse.de
- Update version number of SeaBIOS, spotted by BdMdesigN
* Fri Dec  6 2013 afaerber@suse.de
- Update to v1.7.0: See http://wiki.qemu-project.org/ChangeLog/1.7
  * Adapted update_git.sh accordingly
  * Dropped --enable-mixemu (no longer available)
  * Added a work around for roms/Makefile issue
  * patch 0038-gdbstub-Fix-gdb_register_coprocesso.patch dropped
* Wed Oct  9 2013 dmueller@suse.com
- use --enable-pie to fix arm build
* Tue Oct  8 2013 afaerber@suse.de
- Undo workaround for sasl - fixed in Factory
* Wed Oct  2 2013 afaerber@suse.de
- Work around Factory sasl breakage by allowing build w/o vnc-sasl
- Move build_and_copy_vgabios_bin.patch to Git patch queue
  * Clearly mark in-.spec patch queue as for roms/ipxe/ only
- Synchronized qemu.spec.in from qemu.spec:
  * Added ipxe-build-Avoid-strict-aliasing-warning.patch
  * Modified SeaBIOS summary
  * Added Conflicts for firmware subpackages
  * Dropped %%dir
- Add patch enabling PIE support for ppc/ppc64 (k0da)
* Fri Sep 13 2013 brogers@suse.com
- Build x86 firmware from tarball source. The firmware components
  produced are equivalent to the upstream provided binary blobs
  currently being used. They are delivered in noarch subpackages as
  follows (addresses bnc#830002):
  * qemu-seabios v1.7.2.2
  * qemu-vgabios v0.6c
  * qemu-sgabios v8 (svn rev 8)
  * qemu-ipxe v1.0.0
- Add following patches to enable x86 firmware to build:
  ipxe-build-Work-around-bug-in-gcc-4.8.patch
  ipxe-zbin-Fix-size-used-for-memset-in-al.patch
  build_and_copy_vgabios_bin.patch
  ipxe-build-Avoid-strict-aliasing-warning.patch
* Mon Aug 26 2013 rob.verduijn@gmail.com
- Enabled usb-redirection
  * Fixes starting VMs in gnome-boxes (bnc#839703)
* Sat Aug 17 2013 afaerber@suse.de
- Enable Xen support to allow testing our QEMU in place of Xen's
  This prepares for consolidating QEMU packaging further.
* Sat Aug 17 2013 afaerber@suse.de
- Fix gdbstub for arm/m68k/ppc guests (from pending upstream pull)
* Fri Aug 16 2013 afaerber@suse.de
- Update to v1.6.0: cf. http://wiki.qemu.org/ChangeLog/1.6
  * Adapt update_git.sh script accordingly
* Tue Aug 13 2013 afaerber@suse.de
- Update to v1.6.0-rc3: cf. http://wiki.qemu.org/ChangeLog/1.6
  * Adapt update_git.sh script accordingly
- Changed back versioning scheme to 1.6.0rcX (saschpe, brogers).
* Fri Aug  9 2013 afaerber@suse.de
- Update to v1.6.0-rc2: cf. http://wiki.qemu.org/ChangeLog/1.6
  * Adapt update_git.sh script accordingly
- Changed version from 1.6.0rcX to 1.5.9X (reported by lnussel)
* Fri Aug  2 2013 afaerber@suse.de
- Update to v1.6.0-rc1: cf. http://wiki.qemu.org/ChangeLog/1.6
  * Adapt update_git.sh script accordingly
* Thu Aug  1 2013 afaerber@suse.de
- Use libfdt build dependency not just for ppc.
  QEMU 1.6 needs it for ppc, arm and microblaze guests and uses a
  bundled copy if one of those targets is built and the system does
  not have a compatible libfdt.
* Tue Jul 30 2013 afaerber@suse.de
- Update to v1.6.0-rc0: cf. http://wiki.qemu.org/ChangeLog/1.6
  * Fixes build against recent dtc (SLE_11_SP2 ppc64 w/ Base:System)
  * Includes Gtk patches for bnc#830459
  * Adapt update_git.sh script accordingly
* Mon Jul 22 2013 brogers@suse.com
- Fix segfault that occurs from using -vga qxl (bnc#830459)
* Tue Jun 18 2013 afaerber@suse.de
- Clarify through spec file comments that the patch queue is
  auto-generated through update_git.sh.
  Please do not submit SRs that bypass our patch handling.
* Sat May 25 2013 afaerber@suse.de
- Really enable pulseaudio and oss support (bnc#737070)
- Amend licenses list with GPL-2.0 (adopted from kvm package)
- Be explicit in enabling features our packaging relies on
- Disable stripping at QEMU level
- Use %%optflags rather than $QEMU_OPT_FLAGS
* Fri May 24 2013 afaerber@suse.de
- Move /emul/ia32-linux to qemu-linux-user
* Fri May 24 2013 afaerber@suse.de
- Drop dependency on bison
  * Reorder BuildRequires alphabetically
- Fix summary of qemu-lang sub-package
- Drop post-build-checks suppression (qemu-linux-user only)
* Fri May 24 2013 afaerber@suse.de
- Enable brlapi as done for kvm package
* Fri May 24 2013 afaerber@suse.de
- Use %%{?_smp_mflags} rather than %%{?jobs:-j%%jobs}
* Thu May 23 2013 afaerber@suse.de
- Extend virtfs typedef workaround to ppc64 for SLE_11_SP2
* Tue May 21 2013 afaerber@suse.de
- Split off qemu-linux-user package into separate .spec file.
  * Simplified %%build and %%install sections
  * Dropped *-static dependencies
* Mon May 20 2013 afaerber@suse.de
- Update to v1.5.0 final: Cf. http://wiki.qemu.org/ChangeLog/1.5
  * Adapt update_git.sh accordingly
  * Add BuildRequires for gtk2/3 and vte2 to enable new frontend
  * Place translations into new qemu-lang package
  * Really enable SPICE support from 11.4 in configure, too
* Fri May 17 2013 afaerber@suse.de
- Add BuildRequires for pixman, to avoid using internal version
  that fails to build on ppc
* Thu May 16 2013 afaerber@suse.de
- Update to v1.5.0-rc2: Cf. http://wiki.qemu.org/ChangeLog/1.5
  * Adapt update_git.sh accordingly
- Add patch by brogers to fix SLE 11 SP2 build (from kvm package)
* Tue May 14 2013 afaerber@suse.de
- Update to v1.5.0-rc1: Cf. http://wiki.qemu.org/ChangeLog/1.5
  * Adapt update_git.sh accordingly
  * TODO file no longer exists, don't try to package it
  * Package qemu-mips64{,el}
* Tue May 14 2013 ohering@suse.de
- Enable spice support starting from 11.4
* Tue May  7 2013 afaerber@suse.de
- Update to v1.5.0-rc0: Cf. http://wiki.qemu.org/ChangeLog/1.5
  * Adapt update_git.sh script
  * Audio cards are now all enabled by default
* Wed Apr 24 2013 afaerber@suse.de
- Enable pa and oss audio drivers, as in kvm package (bnc#737070)
- Enable hda audio card, as done in kvm package (bnc#801794)
* Mon Apr 22 2013 dimstar@opensuse.org
- Add explicit alsa-devel BuildRequires: this used to (wrongly) be
  pulled in by libSDL-devel.
* Sun Feb 17 2013 afaerber@suse.de
- Update licenses from new format_spec_file
* Sat Feb 16 2013 afaerber@suse.de
- Update to v1.4.0: See http://wiki.qemu.org/ChangeLog/1.4
  * Adapt update_git.sh accordingly
* Sun Feb 10 2013 afaerber@suse.de
- Update to v1.4.0-rc1: See http://wiki.qemu.org/ChangeLog/1.4
  * Adapt update_git.sh accordingly
- Update update_git.sh to reference github.com/openSUSE/qemu.git
* Thu Dec 13 2012 agraf@suse.com
- linux-user: fix lseek with SEEK_END
* Thu Dec 13 2012 agraf@suse.com
- Cherry pick patches from qemu-kvm into the qemu package:
  - 0033-Add-support-for-DictZip-enabled-gzi.patch
  - 0034-Add-tar-container-format.patch.patch
  - 0035-Legacy-Patch-kvm-qemu-preXX-dictzip.patch
  - 0036-Legacy-Patch-kvm-qemu-preXX-report-.patch
  - 0037-console-add-question-mark-escape-op.patch
  - 0038-Make-char-muxer-more-robust-wrt-sma.patch
* Wed Dec  5 2012 afaerber@suse.de
- Revert memory size constraint, the workaround patch got applied
* Wed Dec  5 2012 afaerber@suse.de
- Update to v1.3.0: see http://wiki.qemu.org/ChangeLog/1.3
  * Update update_git.sh script accordingly
* Wed Nov 28 2012 afaerber@suse.de
- Replace -fno-gcse patch with v3
* Tue Nov 27 2012 afaerber@suse.de
- Add patch to workaround GCC PR55489 via -fno-gcse,
  another step to avoid builds failing with out-of-memory
* Tue Nov 27 2012 afaerber@suse.de
- Add _constraints to request adequate memory to succeed building
* Tue Nov 27 2012 afaerber@suse.de
- Update to v1.3.0-rc1: see http://wiki.qemu.org/ChangeLog/1.3
  * Update update_git.sh accordingly
* Tue Nov 20 2012 afaerber@suse.de
- Update to v1.3.0-rc0: see http://wiki.qemu.org/ChangeLog/1.3
  * Update update_git.sh accordingly
  * Disable SPICE for 11.4 since it can no longer be built lacking
  pyparsing
* Wed Oct 10 2012 agraf@suse.com
- use ulong for syscall parameters. fixes lseek with big files
* Wed Oct 10 2012 agraf@suse.com
- Add more block ioctl handlers for kiwi
* Tue Oct  9 2012 afaerber@suse.de
- Sync qemu.spec.in file, please don't forget!
* Fri Sep 14 2012 schwab@linux-m68k.org
- Don't strip binaries
* Thu Sep 13 2012 idonmez@suse.com
- Add explicit dependency on makeinfo for manpage/doc generation
* Fri Sep  7 2012 vuntz@suse.com
- Add libcap-devel BuildRequires since it's needed to enable VirtFS
  support.
- Add libcap-ng-devel BuildRequires to be able to drop privileges
  in qemu-bridge-helper.
- Add libjpeg-devel and libpng-devel BuildRequires to enable VNC
  jpeg and png support.
- Pass --enable-virtfs to configure to detect changes that will
  cause VirtFS support to not be built.
* Wed Sep  5 2012 afaerber@suse.de
- update to v1.2.0: see http://wiki.qemu.org/ChangeLog/1.2
  * adapt update_git.sh script
  * this includes the fix for CVE-2012-3515
* Wed Sep  5 2012 afaerber@suse.de
- add bounds checks in console VT100 emulation (bnc#777084,
  CVE-2012-3515)
* Wed Sep  5 2012 afaerber@suse.de
- update to v1.2.0-rc3: http://wiki.qemu.org/ChangeLog/1.2
  * adapt update_git.sh script
- add two patches from kvm for SUSE Studio, forwarded by Dinar:
  * add -nooutgoing option for slirp networking
  * add allowed-connections= and password-file= options for VNC
* Tue Aug 28 2012 afaerber@suse.de
- update to v1.2.0-rc1: http://wiki.qemu.org/ChangeLog/1.2
  * adapt update_git.sh script
* Tue Aug 21 2012 agraf@suse.com
- fix getdent in linux-user
- fix statfs in linux-user
- disable FIEMAP support in linux-user
* Tue Aug 21 2012 agraf@suse.com
- add support for FS_IOC_[G|S]ETFLAG ioctls
* Fri Aug 17 2012 afaerber@suse.de
- update to v1.2.0-rc0: http://wiki.qemu.org/ChangeLog/1.2
  * adapt update_git.sh script
  * package new qemu-or32 executable into linux-user
* Wed Aug 15 2012 dmueller@suse.com
- avoid installing qemu on a qemu build
* Tue Jul 31 2012 agraf@suse.com
- add hijack for /proc/cpuinfo
- add compatibility patch for glibc 2.16 (Thanks AJ!)
* Wed Jul 11 2012 agraf@suse.com
- fix segfault even better
* Wed Jul 11 2012 agraf@suse.com
- linux-user: improve locking even across tb flushes
* Tue Jul 10 2012 agraf@suse.com
- linux-user: pin multi-threaded applications to a single host cpu
* Tue Jul 10 2012 agraf@suse.com
- linux-user: improve lock
* Thu Jul  5 2012 agraf@suse.com
- linux-user: add tcg lock for multi-threaded guest programs
* Mon Jun 25 2012 afaerber@suse.de
- include qemu-img and qemu-nbd in qemu-tools package
* Mon Jun 25 2012 afaerber@suse.de
- add qemu-guest-agent package
* Mon Jun 25 2012 agraf@suse.com
- add fix for segv in linux-user (fixes java)
* Tue Jun 19 2012 afaerber@suse.de
- revert LIBRARY_PATH patch by Alex
* Mon Jun 18 2012 afaerber@suse.de
- add patch by Alex to force gcc being emulated for LIBRARY_PATH
* Mon Jun 18 2012 dvaleev@suse.com
- add libfdt1 to buildrequires on ppc
* Thu Jun 14 2012 afaerber@suse.de
- revert qemu-bridge-helper mode change (cf. BNC#765948)
* Wed Jun 13 2012 brogers@suse.com
- don't use permissions.d
* Wed Jun 13 2012 agraf@suse.com
- Add fix for bogus losetup ioctl to not warn us about it
* Sat Jun  9 2012 brogers@suse.com
- Set up bridge helper as a setuid executable
* Sat Jun  9 2012 afaerber@suse.de
- Add patch for specifying --libexecdir
  * Fixes having to specify the path to qemu-bridge-helper manually
- Drop superfluous `make qemu-img`
- Move qemu-bridge-helper to its own subpackage, to share with KVM
* Tue Jun  5 2012 afaerber@suse.de
- Update to v1.1.0: see http://wiki.qemu.org/ChangeLog/1.1
  * Adapt update_git.sh script to new tag
* Fri Jun  1 2012 afaerber@suse.de
- Update to v1.1.0-rc4: see http://wiki.qemu.org/ChangeLog/1.1
  * Adapt update_git.sh script to new tag
* Thu May 31 2012 agraf@suse.com
- fix /proc/self/maps faking with secondary threads
* Wed May 30 2012 agraf@suse.de
- revert commit a84fac1426 to fix automoc4 for arm
* Tue May 29 2012 agraf@suse.com
- remove manual interp prefix, which made all linux-user binaries
  point to an i386 LD_PREFIX path
* Tue May 29 2012 agraf@suse.com
- add patch to fix building of go (swi in thumb ignores imm)
* Tue May 22 2012 afaerber@suse.de
- Update to v1.1.0-rc3; see http://wiki.qemu.org/ChangeLog/1.1
  * Adapt update_git.sh script to new tag
* Thu May 17 2012 afaerber@suse.de
- Update to v1.1.0-rc2; see http://wiki.qemu.org/ChangeLog/1.1
  * Adapt update_git.sh script to new tag
* Wed May 16 2012 afaerber@suse.de
- Remove workaround for forcing cURL detection
* Sun May 13 2012 afaerber@suse.de
- Update to v1.1-rc1: see http://wiki.qemu.org/ChangeLog/1.1
  * Add workaround for 11.4: add -lrt after -lglib-2.0
- Adapt update_git.sh script to new tag
* Tue May  8 2012 afaerber@suse.de
- Update to v1.1-rc0; see http://wiki.qemu.org/ChangeLog/1.1
  * Do not try to mv qemu, the executable is gone, there's a dir now
  * Do not try to mv */qemu-*, there's a pc-bios/qemu-icon.bmp
  * Be more specific in temporary copying of files to dynamic/
  * Drop duplicate %%_bindir/qemu_binfmt_misc.sh, only in sbin now
  * Use dynamic version of new executable qemu-bridge-helper
- Update update_git.sh script to pull patches from suse-1.1 branch
* Mon May  7 2012 afaerber@suse.de
- Update URL to project homepage
* Mon May  7 2012 agraf@suse.com
- compile fixes for ppc64abi32
- fix update_fit.sh script if wc -c is 40
- fix stale tbs after mmap
* Wed Mar  7 2012 agraf@suse.com
- cut off patch file names after 40 bytes, support older git versions
  for update_git.sh
* Mon Mar  5 2012 agraf@suse.com
- resolve VMAs downwards, fixes arm git build for real
* Sat Mar  3 2012 agraf@suse.com
- update update_git.sh for 1.0.1
- add fixes for reserved_va mmap(NULL) case, fixes git build on arm
* Tue Feb 28 2012 idonmez@suse.com
- Enable spice support
* Wed Feb 22 2012 brogers@suse.com
- update to latest stable release: 1.0.1. For changes see:
  http://wiki.qemu.org/ChangeLog/1.0
* Mon Feb  6 2012 brogers@suse.com
- avoid buffer overflow in e1000 device emulation (bnc#740165)
* Mon Feb  6 2012 agraf@suse.de
- qemu-user: fix fallocate
* Fri Feb  3 2012 agraf@suse.de
- qemu-user: fix previous patch
* Thu Feb  2 2012 agraf@suse.de
- qemu-user: add host binary support for binfmt
* Thu Feb  2 2012 agraf@suse.de
- qemu-user: add fix for /proc/self/maps to only show mappable regions
* Wed Feb  1 2012 agraf@suse.de
- qemu-user: add wrapper for BLKBSZGET
* Tue Jan 31 2012 agraf@suse.de
- qemu-user: add fix for deadloop with ulimit constraints
- qemu-user: add device mapper and loopback ioctls, enabling kpatkx
* Tue Jan 10 2012 agraf@suse.de
- backport all ppc-1.0 stable patches to our package
- add fix for PPC HV KVM on 3.1
* Tue Jan 10 2012 agraf@suse.de
- add fix for PPC in HV KVM mode
* Fri Jan  6 2012 agraf@suse.de
- add workaround for KVM on PPC to support hugetlbfs
- add upstream patches to fake $0 in /proc/self/maps (fixes ps)
* Wed Dec 14 2011 agraf@suse.com
- add update_git.sh to simplify maintenance of the tree
- use -R automatically in linux-user to gain more address space
- drop MAP_32BIT patch (deprecated by the one above)
* Mon Dec 12 2011 agraf@suse.com
- add linker patch for ppc hosts
* Mon Dec 12 2011 agraf@suse.com
- remove exclusivearch - we should be able to build everywhere!
* Sun Dec 11 2011 agraf@suse.com
- fix compilation for 11.4
* Sun Dec 11 2011 agraf@suse.com
- fix compilation on sle11
- add %%fdupes for duplicate file checking
* Sun Dec 11 2011 agraf@suse.com
- update to 1.0 from upstream. for changelogs please see:
  - 0.14 -> 0.15: http://wiki.qemu.org/ChangeLog/0.15
  - 0.15 -> 1.0:  http://wiki.qemu.org/ChangeLog/1.0
- the binary "qemu" is now called qemu-system-i386
* Tue Nov  8 2011 agraf@suse.com
- only ignore specific timer_create syscall, no all of them
* Sun Nov  6 2011 agraf@suse.com
- don't print out unsupported syscalls but rather silently ignore
  them - some programs catch stderr and get confused
* Thu Nov  3 2011 adrian@suse.de
- add a number of patches to fake /proc entries (from Alex)
* Fri Oct 28 2011 adrian@suse.de
- split linux-user binaries into qemu-linux-user package
  (this static package can be used in cross build in OBS)
* Tue Oct 18 2011 adrian@suse.de
- add xattr support for openSUSE 12.1
- added syscall numbers to fix prlimit64 support (from upstream)
* Wed Oct  5 2011 joop.boonen@opensuse.org
- Fixed glibc arm build issue according to
  https://bugs.meego.com/show_bug.cgi?format=multiple&id=20418
  added a reverse patch
* Tue Oct  4 2011 adrian@suse.de
- add binfmt misc handler binary patch from alex. This is a handler
  which calls qemu with -0 argument and right parameters to avoid
  broken runs due to different set $0 as on real hardware
- move arch specific patches at the end to avoid arch dep conflicts
  with other patches
- enable linux-user build to get binfmt handler
* Thu Sep 29 2011 adrian@suse.de
- add 0021-implement-prlimit64-syscall.patch from upstream to avoid
  output and confused configure scripts when testing gcc on armv7hl
- add 0022-fixing-smp-races.patch from alex to fix some SMP races
* Tue Sep 27 2011 adrian@suse.de
- add 0020-linux-user-implement-reboot-syscall.patch from alex
- extend 0010 mmap patch for files
* Mon Sep 26 2011 adrian@suse.de
- add fix from alex for openat file permission handling
* Mon Jun 20 2011 aj@suse.de
- Add BuildRequires: glibc-devel-static
* Thu May 19 2011 andrea@opensuse.org
- removed un-required vde buildrequires
* Tue May 17 2011 brogers@novell.com
- build correctly for SLE11
- reset revision to zero after version change
* Wed May 11 2011 andrea@opensuse.org
- added 0018-qemu-0.14.1-mcast-udp.patch to enable multicast and
  udp tunneling support
* Tue May 10 2011 andrea@opensuse.org
- New Upstream version 0.14.1
    See http://wiki.qemu.org/Changelog/0.14 for changes in 0.14
- removed 0014-qemu-0.11-git-ioctl_mount.patch not required anymore
- enabled vde support
- some spec clean up
* Mon Feb 21 2011 coolo@novell.com
- disable parallel build for a while, it takes too much memory
  for our workers
* Thu Feb 10 2011 uli@suse.de
- update -> 0.14.0-rc1
  See http://wiki.qemu.org/Changelog/0.14 for changes in 0.14.
  (There is no such page for the 0.13 tree. The ChangeLog file ends at
  0.12.0, http://wiki.qemu.org/ChangeLog at 0.12.5 and suggests to look at
  the git log. High-level information of what has changed in 0.13 is
  apparently not available.)
* Fri May 28 2010 uli@suse.de
- update -> 0.12.4
  see http://wiki.qemu.org/ChangeLog for changes
* Wed May 19 2010 brogers@novell.com
- co-exist with virt-utils, which provides some qemu components
  (bnc#586115)
* Sun Apr 18 2010 crrodriguez@opensuse.org
- requires timezone
* Mon Oct  5 2009 uli@suse.de
- update -> 0.11.0 final
  - mips: fix conditional move off fp conditions codes (Nath Froyd)
  - fix migration to obey -S (Paolo Bonzini)
  - remove pc-0-10 machine type (Mark McLoughlin)
  - vnc: fix copyrect screen corruption (Gerd Hoffman)
  - fix vm state change handlers running order (Markus Armbruster)
  - e1000: fix eerc and ics emulation (Bill Paul)
  - fix sdl zooming with pl110 (Blue Swirl)
  - sparc64: flush pending conditional evaluations (Igor Kovalenko)
  - esp: fix interrupt register read (Blue Swirl)
  - option rom makefile fixes (Paul Brook)
  - fix sparse warnings (Blue Swirl)
  - fix symfind (Laurent Desnogues)
  - win32: fix default prefix (Stefan Weil)
  - fix checksum writing in signboot (Alex Graf)
  - fix sdl window resize (Stefano Stabellini)
  - do not resize the screen on hw_invalidate (Stefano Stabellini)
  - Add checks for -smbios option (Beth Kon)
  - fix do_set_link (Luiz Capitulino)
  - fix do_commit behavior (Luiz Capitulino)
  - make windows notice media change (Gleb Natapov)
  - check for PR_SET_NAME being defined (Nathan Froyd)
  - fix migration for ide devices (Anthony Liguori)
  - Use correct depth in vmware vga (Reimar Doffiner)
  - support 32bpp cursors in sdl (Reimar Doffinger)
  - fix device name completion for eject (Blue Swirl)
  - make screendump use DisplayState properly (Stefano Stabellini)
  - fix autostart with live migration (Avi Kivity)
  - fix detached migration with exec (Chris Lalancette)
  - fix segv when changing vnc password in sdl (Zach Amsden)
  - fix vnc password clearing with stdio monitor (Zach Amsden)
  - clean up VGA type selection (Zach Amsden)
  - add missing linefeed in error message (Stefan Weil)
  - fix rtc polling mode (Bernhard Kauer)
  - qcow2: order concurrent aio requests (Kevin Wolf)
  - qemu-io: port to win32 (Stefan Weil)
  - alpha: fix extlh instruction (Vince Weaver)
  - tcg: fix size of local variables in tcg_gen_bswap64_i64 (Stefan Weil)
  - net: fix send ordering (Jan Kiszka)
  - escc: fix IRQ routing (Aurelien Jarno)
  - versatile: fix Linux task preemption (Aurelien Jarno)
  - curses: reduce memory usage by 250MB (Aurelien Jarno)
- disabled ppc64 host, seems to be very broken
* Thu Sep 10 2009 uli@suse.de
- package missing tools (qemu-nbd, qemu-io)
* Thu Sep  3 2009 uli@suse.de
- disable S/390 target on 32-bit platforms
* Tue Aug 11 2009 uli@suse.de
- update -> 0.11.0 RC1
  - add machine aliasing support (Mark McLoughlin)
  - add getfd/closefd monitor commands (Mark McLoughlin)
  - fix live migration (various)
  - HPET fixes (various)
  - slirp: fix guestfwd for incoming data (Jan Kiszka)
  - fix qemu-img convert to copy unallocated parts of the image
    (Akkarit Sangpetch)
  - vmdk: fix backing file handling (Kevin Wolf)
  - scsi: add save/restore support (Nolan Leake)
  - e1000: ignore reset command (Kevin Wolf)
  - allow monitor interaction when using -incoming exec: (Chris Lalancette)
  - fix -net socket,listen (Jan Kiszka)
  - serial: fix lost characters after sysrq (Jason Wessel)
  - lsi53c895a: Implement additional registers (Sebastian Herbszt)
  - i386: fix cpu reset (Nitin Kamble)
  - Prevent CD-ROM eject while device is locked (Mark McLoughlin)
  - Fix memory leaks (various)
  - Reset PS2 keyboard/mouse on reset (Dinesh Subraveti)
  - Fix -initrd with > 4GB guests (Glauber Costa)
  - qcow2 fixes (various)
  - Enable power button event generation (Gleb Natapov)
  - fix serial option in -drive
  - Fix non-ACPI timer interrupt routing (Beth Kon)
  - Fix keyboard mapping on newer Xords with non-default keymaps (balrog)
  - Make PCI config status register read-only (Anthony Liguori)
  - Fix crash on resolution change -> screen dump -> vga redraw (Avi Kivity)
  - fix savevm/loadvm (various)
  - virtio: fix guest oops with 2.6.25 kernels (Rusty Russell)
  - SH4: add support for -kernel (Takashi Yoshii, Aurelien Jarno)
  - hotplug: fix closing of char devices (Jan Kiszka)
  - hotplug: remove incorrect check for device name (Eduardo Habkost)
  - fix VGA regression (malc)
- added S/390 host and target
- maintaining patches in git
- several linux-user improvements for compatibility and speed
- enabled curl block driver, VNC TLS and SASL, AIO, and Bluetooth
* Wed Apr 15 2009 ro@suse.de
- buildfix: refresh patches
* Fri Mar 27 2009 crrodriguez@suse.de
- BuildRequire zlib-devel-static
* Tue Mar 24 2009 uli@suse.de
- update -> release (0.10.1)
  - fixes bnc #435135 (CVE-2008-4539, SWAMP #22179), #362956
    (CVE-2008-1945, CVE-2008-0928), #461565 (CVE-2008-2382)
  - Kernel Virtual Machine acceleration support
  - GDB XML register description support
  - Intel e1000 emulation
  - HPET emulation
  - VirtIO paravirtual device support
  - Marvell 88w8618 / MusicPal emulation
  - Nokia N-series tablet emulation / OMAP2 processor emulation
  - PCI hotplug support
  - Curses display support
  - qemu-nbd utility to mount supported block formats
  - Altivec support in PPC emulation and new firmware (OpenBIOS)
  - Multiple VNC clients are now supported
  - TLS encryption is now supported in VNC
  - MIPS Magnum R4000 machine (Hervé Poussineau)
  - Braille support (Samuel Thibault)
  - Freecom MusicPal system emulation (Jan Kiszka)
  - OMAP242x and Nokia N800, N810 machines (Andrzej Zaborowski)
  - EsounD audio driver (Frederick Reeve)
  - Gravis Ultrasound GF1 sound card (Tibor "TS" Schütz)
  - Many, many, bug fixes and new features
  - virtio-net: allow masking of notifications on empty queue (Alex
    Williamson)
  - e1000: fix rx descriptor low threshold logic (Alex Willaimson)
  - x86 tcg: add NULL checks to lsl instruction (Jan Kiszka)
  - kvm vga: fix screen corruption with -std-vga and Windows (Avi Kivity)
  - kvm vga: fix screen corruption with Ubuntu installations (Glauber Costa)
  - virtio-net: check right return size on sg list (Alex Williamson)
  - Make qemu_announce_self handle holes (live migration after hotplug)
    (Marcelo Tosatti)
  - Revert r6804-r6808 (qcow2 allocation info).  This series of changes
    added a high cost to startup for large qcow2 images (Anthony Liguori)
  - qemu-img: fix help message (Aurelien Jarno)
  - Fix build for non-default installs of SDL (Anthony Liguori)
  - Fix race condition in env->interrupt_request.  When using TCG and a
    dynticks host timer, this condition could cause TCG to get stuck in an
    infinite loop (Aurelien Jarno)
  - Fix reading encrypted hard disk passwords during early startup (Jan
    Kiszka)
  - Fix encrypted disk reporting in 'info block' (Jan Kiszka)
  - Fix console size with tiny displays (MusicPal) (Jan Kiszka)
  - Improve error handling in bdrv_open2 (Jan Kiszka)
  - Avoid leaking data in mux'ed character devices (Jan Kiszka)
  - Fix initial character device reset (no banner in monitor) (Jan Kiszka)
  - Fix cpuid KVM crash on i386 host (Lubomir Rintel)
  - Fix SLES10sp2 installation by adding ISTAT1 register to LSI SCSI
    emulation (Ryan Harper)
- s390x TCG backend
- i386-linux-user NPTL support
* Wed Oct  8 2008 uli@suse.de
- update -> current SVN
  - fixes PPC hosts
  - fixes SH4 targets (reenabled), adds NPTL support
  - SSSE3, SSE4.* instructions, "unreal" mode fixed
  - Alpha target converted to TCG
  - live migration
  - Bluetooth emulation
  - SCSI tape support
  - OpenBIOS binary updated
  - UHCI emulation rewritten
  - lots of bugfixes
* Mon Aug  4 2008 ro@suse.de
- fix build by adding return statements for two nonvoid functions
  (qemu-nonvoid_return.patch), actually unreached code
* Thu Jul 24 2008 uli@suse.de
- update -> current SVN
  - MIPS Magnum R4000 machine (Hervé Poussineau)
  - Braille support (Samuel Thibault)
  - Freecom MusicPal system emulation (Jan Kiszka)
  - OMAP242x and Nokia N800, N810 machines (Andrzej Zaborowski)
  - EsounD audio driver (Frederick Reeve)
  - Gravis Ultrasound GF1 sound card (Tibor "TS" Schütz)
- added pcap networking
- ditched GCC3 thanks to TCG. Hooray!
  (downside: no PPC and SH4 emulation, no S/390 host)
* Thu May 15 2008 cthiel@suse.de
- use lsilogic instead of buslogic for SCSI VMDK images
* Thu May  8 2008 uli@suse.de
- add format option to disable autodetection of disk image format
  (bnc#380828)
* Fri Apr 25 2008 uli@suse.de
- revert secfix (causes data corruption, no known good patch
  available yet)
- support creation of SCSI VMDK images
* Tue Mar 11 2008 uli@suse.de
- secfix (unchecked block read/write vulnerability, bug #362956)
* Thu Jan 17 2008 uli@suse.de
- update -> 0.9.1
  - TFTP booting from host directory (Anthony Liguori, Erwan Velu)
  - Tap device emulation for Solaris (Sittichai Palanisong)
  - Monitor multiplexing to several I/O channels (Jason Wessel)
  - ds1225y nvram support (Herve Poussineau)
  - CPU model selection support (J. Mayer, Paul Brook, Herve Poussineau)
  - Several Sparc fixes (Aurelien Jarno, Blue Swirl, Robert Reif)
  - MIPS 64-bit FPU support (Thiemo Seufer)
  - Xscale PDA emulation (Andrzej Zaborowski)
  - ColdFire system emulation (Paul Brook)
  - Improved SH4 support (Magnus Damm)
  - MIPS64 support (Aurelien Jarno, Thiemo Seufer)
  - Preliminary Alpha guest support (J. Mayer)
  - Gumstix boards: connex and verdex emulation (Thorsten Zitterell)
  - Intel mainstone II board emulation (Armin Kuster)
  - VMware SVGA II graphics card support (Andrzej Zaborowski)
- revert s390-dis.c to last GPLv2 version
- reenabled qemu-system-ppcemb
* Mon Dec 10 2007 uli@suse.de
- fixed open() usage with O_CREAT
* Tue Nov 13 2007 uli@suse.de
- update -> current CVS:
  - Read-only support for Parallels disk images (Alex Beregszaszi)
  - CRIS emulation (Edgar E. Iglesias)
  - SPARC32PLUS execution support (Blue Swirl)
  - MIPS mipssim pseudo machine (Thiemo Seufer)
  - Strace for Linux userland emulation (Stuart Anderson, Thayne Harbaugh)
  - OMAP310 MPU emulation plus Palm T|E machine (Andrzej Zaborowski)
  - ARM v6, v7, NEON SIMD and SMP emulation (Paul Brook/CodeSourcery)
* Thu Oct 11 2007 ro@suse.de
- hack to fix build: undef DEBUG_BLOCK for now
* Fri Sep 28 2007 agraf@suse.de
- fix SVM support (Alexander Graf)
* Thu Sep 13 2007 agraf@suse.de
- add SVM emulation support (Alexander Graf)
- fix a misassumption in the s390 fix (uli)
- allow more IDE power management (Ben Guthro)
- log any I/O error and perform automatic read retry for CDrom (Ben Guthro)
- fix Coherent guest support (Jan Jezabek)
- fix several Darwin guest issues (Filip Navara)
* Mon Aug 20 2007 agraf@suse.de
- fix ATAPI bug when using libata (Brandon Philips)  (#291775)
* Sat Aug 11 2007 olh@suse.de
- disable only SNDRV_SB_CSP_IOCTL_LOAD_CODE for _IOC_SIZEBITS < 14
* Thu Aug  9 2007 olh@suse.de
- disable some alsa SB ioctl declarations
* Mon Aug  6 2007 olh@suse.de
- remove inclusion of linux/compiler.h
* Mon Jul 30 2007 uli@suse.de
- fixed for S/390
* Tue Jul 10 2007 schwab@suse.de
- Add (incomplete) m68k emulation.
* Mon Jul  9 2007 agraf@suse.de
- included alsa support in qemu-user
- update to current cvs
  - TFTP booting from host directory (Anthony Liguori, Erwan Velu)
  - Tap device emulation for Solaris (Sittichai Palanisong)
  - Monitor multiplexing to several I/O channels (Jason Wessel)
  - ds1225y nvram support (Herve Poussineau)
  - CPU model selection support (J. Mayer, Paul Brook, Herve Poussineau)
  - Several Sparc fixes (Aurelien Jarno, Blue Swirl)
  - MIPS 64-bit FPU support (Thiemo Seufer)
  - Xscale PDA emulation (Andrzei Zaborowski)
  - ColdFire system emulation (Paul Brook)
  - Improved SH4 support (Magnus Damm)
  - MIPS64 support (Aurelien Jarno, Thiemo Seufer)
  - Preliminary Alpha guest support (J. Mayer)
  - IPC fixes
* Wed Jun 20 2007 agraf@suse.de
- applied proper fix for x86_64 and the MAP_32BIT flag
* Wed Jun 20 2007 uli@suse.de
- added secfixes (bug #252519)
* Thu Jun 14 2007 agraf@suse.de
- made wine work (set FS register to 0 on init)
- suppressed robust_list warnings
* Wed Jun 13 2007 agraf@suse.de
- made flash player 9 work on ppc
- fixed FUTEX_WAKE_OP on machines where endianness differs
- made mmap on x86_64 use the MAP_32BIT flag
- removed a useless spin_lock
- removed an annoying debug message for forking
- implemented sched_getaffinity syscall
- fixed configure call so it takes gcc3 again
* Wed Jun 13 2007 uli@suse.de
- support "vga=" parameter (Pascal Terjan)
- direct jump support for x86-64 (Gwenole Beauchesne)
- fix chaining of CPU instances (Gwenole Beauchesne)
- live migration support (Anthony Liguori)
- fix fprem/fprem1 insns (Julian Seward)
- KVM support
- Z80/ZX Spectrum emulation (Stuart Brady)
- GCC4 support postponed (breaks x86-64 on i386)
* Mon Jun 11 2007 agraf@suse.de
- implemented TLS support on i386 so qemu-user can be used to run
  with current libc versions (partly done by David Woodhouse,
  fixed by Alexander Graf)
- added a dirty hack for an mmap page table bug on qemu-user x86
  emulation
- disable AF_NETLINK in qemu-user (endianness problems)
- applied fast path mangling patch from Kirill A. Shutemov
- applied strace patch for debugging (by Stuart R. Anderson)
* Wed Apr  4 2007 agraf@suse.de
- fixed initrd loading on x86
* Thu Mar 29 2007 ro@suse.de
- added bison to BuildRequires
* Tue Feb 20 2007 uli@suse.de
- added better fix by Robert Schiele (bug #241950)
- update -> 0.9.0
  - Support for relative paths in backing files for disk images
  - Async file I/O API
  - New qcow2 disk image format
  - Support of multiple VM snapshots
  - Linux: specific host CDROM and floppy support
  - SMM support
  - Moved PCI init, MP table init and ACPI table init to Bochs BIOS
  - Support for MIPS32 Release 2 instruction set (Thiemo Seufer)
  - MIPS Malta system emulation (Aurelien Jarno, Stefan Weil)
  - Darwin userspace emulation (Pierre d'Herbemont)
  - m68k user support (Paul Brook)
  - several x86 and x86_64 emulation fixes
  - Mouse relative offset VNC extension (Anthony Liguori)
  - PXE boot support (Anthony Liguori)
  - '-daemonize' option (Anthony Liguori)
* Tue Feb  6 2007 uli@suse.de
- added fix by Robert Schiele to work without usbdevfs
  (bug #241950)
* Thu Feb  1 2007 ro@suse.de
- remove -fstack-protector from CFLAGS
* Fri Oct 27 2006 schwab@suse.de
- Fix char signedness.
* Mon Sep 11 2006 uli@suse.de
- re-added ARM FPE patch
- fixed SPARC on PPC
- install missing openbios-sparc32
* Sat Sep  9 2006 dmueller@suse.de
- update to 0.8.2:
  - ACPI support
  - PC VGA BIOS fixes
  - MIPS FPU support (Marius Groeger)
  - PPC breakpoints and single stepping (Jason Wessel)
  - USB updates (Paul Brook)
  - UDP/TCP/telnet character devices (Jason Wessel)
  - Windows sparse file support (Frediano Ziglio)
  - RTL8139 NIC TCP segmentation offloading (Igor Kovalenko)
  - PCNET NIC support (Antony T Curtis)
  - Support for variable frequency host CPUs
  - Workaround for win32 SMP hosts
  - Support for AMD Flash memories (Jocelyn Mayer)
  - Audio capture to WAV files support (malc)
* Tue May 30 2006 uli@suse.de
- fixed to build on PPC with new glibc
* Mon May 29 2006 uli@suse.de
- fixed to build with new kernel headers
* Wed Mar  8 2006 uli@suse.de
- split giant patch
- added NWFPE glue code fix
* Tue Mar  7 2006 schwab@suse.de
- More fixes for ia64 port.
* Mon Mar  6 2006 schwab@suse.de
- Remove obsolete hunk from ia64 patch.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 uli@suse.de
- update -> 0.8.0
* Thu Dec  8 2005 uli@suse.de
- update to current CVS (MIPS userspace, ARM system, SMP, USB,
  NX, VLAN, serial, parallel, ES1370, ALSA backend)
- build i386 and AMD64 emus with kqemu support if possible
- install missing PPC video driver, SPARC boot ROM
- install missing keymaps
* Mon Nov  7 2005 uli@suse.de
- updated linker scripts for new binutils release
* Sat Sep 17 2005 dmueller@suse.de
- update to 0.7.2
* Mon Aug 15 2005 schwab@suse.de
- Don't package /emul/ia32-linux on ia64.
* Mon Aug 15 2005 schwab@suse.de
- Fix compilation on ia64.
* Mon Aug  1 2005 uli@suse.de
- update -> 0.7.1
- enabled x86_64-system
* Mon Jul 11 2005 uli@suse.de
- update -> CVS (MIPS emulation)
- build with throwaway GCC3 (still no GCC4-compatible QEMU in
  sight)
- enabled armeb-user
- link *-user statically (necessary for chrooting into non-native
  systems)
- disabled s390, alpha, armv4l build (broken and unmaintained)
- disabled qemu-fast (broken and deprecated)
- disabled i386-user on x86_64 (useless)
- build with %%jobs
* Wed Jun  1 2005 ro@suse.de
- update to 0.7.0, still no success with gcc-4
* Thu Jan 27 2005 uli@suse.de
- baselibs-x86 link is unnecessary on x86/AMD64
- two ARM emulation fixes (RRX operand fix by Paul Brook, shifter
  carry fix by me)
- SDL 1.2.8 can be linked statically -> enabled qemu-fast
* Mon Nov 29 2004 uli@suse.de
- update -> 0.6.1
- build softmmu binaries on s390 (still doesn't work though)
- pack /emul/ia32-linux directory and symlink from /usr/share/qemu
  so it's possible to use the IA64 baselibs-x86 packages
* Wed Sep 15 2004 uli@suse.de
- removed unnecessary dependency on private glibc symbol
  (bug #44864)
* Fri Aug  6 2004 uli@suse.de
- update -> 0.6.0 (fixes for several OSs, improvements in emulated
  hardware (IDE, PCI, network, VGA, APM, PowerMac), minor fixes,
  tool for conversion of VMware images)
* Tue May 11 2004 uli@suse.de
- update -> 0.5.5 (contains ARM, utime() fixes and several others)
- make uname() return target machine name (fixes config.guess,
  rpm etc.)
- fake sigaltstack() (fixes m4)
- enabled x86-64
* Wed May  5 2004 uli@suse.de
- fixed ARM emulation bug
* Wed Apr 28 2004 uli@suse.de
- build with -fno-unit-at-a-time (fixes PPC system emulator)
* Wed Apr 28 2004 uli@suse.de
- update -> 0.5.4 (runs Linux/PPC, several fixes)
* Mon Apr 19 2004 uli@suse.de
- initial package
